import { Entity } from '../../services/model/entity.model';
import { AbstractControl, AbstractControlOptions, UntypedFormArray, UntypedFormBuilder, UntypedFormGroup, ValidatorFn } from '@angular/forms';
export interface FormArrayHelperOptions {
    allowEmptyArray: boolean;
    allowManyNullValues?: boolean;
    allowDuplicatedValues?: boolean;
    validators?: ValidatorFn[];
}
export declare class FormArrayHelper<T = Entity<any>, C extends AbstractControl = AbstractControl> {
    private readonly _formArray;
    private createControl;
    private equals;
    private isEmpty;
    static getOrCreateArray(formBuilder: UntypedFormBuilder, form: UntypedFormGroup, arrayName: string): UntypedFormArray;
    private _allowEmptyArray;
    private _allowManyNullValues;
    private _allowDuplicatedValues;
    private readonly _validators;
    get allowEmptyArray(): boolean;
    set allowEmptyArray(value: boolean);
    get allowManyNullValues(): boolean;
    set allowManyNullValues(value: boolean);
    get allowDuplicatedValues(): boolean;
    set allowDuplicatedValues(value: boolean);
    get formArray(): UntypedFormArray;
    constructor(_formArray: UntypedFormArray, createControl: (value?: T) => C, equals: (v1: T, v2: T) => boolean, isEmpty: (value: T) => boolean, options?: FormArrayHelperOptions);
    /**
     * @param value
     * @param options
     */
    add(value?: T, options?: {
        emitEvent: boolean;
        insertAt?: number;
    }): boolean;
    removeAt(index: number): boolean;
    resize(length: number, options?: {
        emitEvent?: boolean;
    }): boolean;
    clearAt(index: number): boolean;
    isLast(index: number): boolean;
    removeAllEmpty(): void;
    size(): number;
    at(index: number): C;
    /**
     * Resize the FormArray, then set values
     *
     * @param values
     * @param options
     */
    setValue(values: T[], options?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    /**
     * Resize the FormArray, then patch values
     *
     * @param values
     * @param options
     */
    patchValue(values: T[], options?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    disable(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    enable(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    forEach(ite: (control: C) => void): void;
    protected setAllowEmptyArray(value: boolean): void;
}
export declare interface AppFormArrayOptions extends AbstractControlOptions {
    allowEmptyArray?: boolean;
    allowReuseControls?: boolean;
    allowManyNullValues?: boolean;
    allowDuplicateValue?: boolean;
}
export declare class AppFormArray<T = Entity<any>, C extends AbstractControl = AbstractControl> extends UntypedFormArray {
    createControl: (value?: T) => C;
    private equals;
    private isEmpty;
    private readonly options;
    get allowEmptyArray(): boolean;
    set allowEmptyArray(value: boolean);
    get allowManyNullValues(): boolean;
    set allowManyNullValues(value: boolean);
    get allowDuplicateValue(): boolean;
    set allowDuplicateValue(value: boolean);
    constructor(createControl: (value?: T) => C, equals: (v1: T, v2: T) => boolean, isEmpty: (value: T) => boolean, options?: AppFormArrayOptions | undefined | null);
    /**
     * WIll rebuild the array, using the given values
     *
     * @param values
     * @param options
     */
    setValue(values: any[], options?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    patchValue(values: any[] | null | undefined, options?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    resize(length: number, options?: {
        emitEvent?: boolean;
    }): boolean;
    disable(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    enable(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    forEach(ite: (control: C) => void): void;
    /**
     * @param value
     * @param options
     */
    add(value?: T, options?: {
        emitEvent: boolean;
        insertAt?: number;
    }): void;
    removeAt(index: number, options?: {
        emitEvent: boolean;
    }): boolean;
    clearAt(index: number, options?: {
        emitEvent: boolean;
    }): void;
    isLast(index: number): boolean;
    removeAllEmpty(): void;
    clone(): AppFormArray<T, C>;
    protected setAllowEmptyArray(value: boolean): void;
}
