import { AfterViewInit, OnDestroy, OnInit } from '@angular/core';
import { ActivatedRoute, Params, Router } from '@angular/router';
import { AlertController, IonContent, NavController, ToastController } from '@ionic/angular';
import { TranslateService } from '@ngx-translate/core';
import { BehaviorSubject } from 'rxjs';
import { FormButtonsBarToken } from '../buttons/form-buttons-bar.component';
import { CanLeave, CanSave, IAppForm, IAppFormGetter } from '../form.utils';
import { ShowToastOptions } from '../../../shared/toast/toasts';
import { ToolbarToken } from '../../../shared/toolbar/toolbar';
import { AppFormContainer, IAppFormContainer } from '../form-container.class';
import * as i0 from "@angular/core";
export interface IAppEditor<T> extends IAppFormContainer<T>, CanSave, CanLeave {
    save(event?: Event, options?: any): Promise<boolean>;
    cancel(event?: Event): Promise<void>;
}
export declare abstract class AppEditor<T = any, ID = number, O = any> extends AppFormContainer<T> implements IAppEditor<T>, OnInit, OnDestroy, AfterViewInit {
    protected route: ActivatedRoute;
    protected router: Router;
    protected navController: NavController;
    protected alertCtrl: AlertController;
    protected translate: TranslateService;
    protected toastController: ToastController;
    readonly savingSubject: BehaviorSubject<boolean>;
    submitted: boolean;
    queryParams: Params;
    i18nContext: {
        prefix: string;
        suffix: string;
    };
    get saving(): boolean;
    toolbar: ToolbarToken | null;
    formButtonsBar: FormButtonsBarToken | null;
    content: IonContent;
    abstract get isNewData(): boolean;
    protected constructor(route: ActivatedRoute, // Modal editor give 'null'
    router: Router, navController: NavController, alertCtrl: AlertController, translate: TranslateService);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    /**
     * @deprecated Use addForm(path, form)
     * @param form
     */
    addChildForm(form: IAppForm | IAppFormGetter): void;
    /**
     * @deprecated Use addForms()
     * @param forms
     */
    addChildForms(forms: (IAppForm | IAppFormGetter)[]): void;
    /**
     * @deprecated Use removeForm()
     * @param form
     */
    removeChildForm(form: IAppForm | IAppFormGetter): IAppForm | IAppFormGetter;
    markAsSaving(opts?: {
        emitEvent?: boolean;
    }): void;
    markAsSaved(opts?: {
        emitEvent?: boolean;
    }): void;
    cancel(event?: Event): Promise<void>;
    /**
     * Unload the page (remove all data). Useful when reusing angular cache a cancelled page
     *
     * @param opts
     */
    unload(opts?: {
        emitEvent?: boolean;
    }): Promise<void>;
    reloadWithConfirmation(confirm?: boolean): Promise<void>;
    goBack(event?: Event): Promise<void | boolean>;
    abstract load(id?: ID, options?: O): Promise<void>;
    abstract save(event?: Event, options?: any): Promise<boolean>;
    abstract reload(): Promise<void>;
    protected scrollToTop(duration?: number): Promise<void>;
    protected saveIfDirtyAndConfirm(event?: Event, opts?: {
        emitEvent?: boolean;
        confirmed?: boolean;
    }): Promise<boolean>;
    protected saveDirtyChildren(): Promise<boolean>;
    protected showToast(opts: ShowToastOptions): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<AppEditor<any, any, any>, [{ optional: true; }, null, null, null, null]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<AppEditor<any, any, any>, never, never, {}, {}, never, never, false, never>;
}
