import { AfterViewInit, ChangeDetectorRef, Injector, OnDestroy, OnInit } from '@angular/core';
import { ModalController } from '@ionic/angular';
import { BehaviorSubject, Subject } from 'rxjs';
import { LocalSettingsService } from '../../services/local-settings.service';
import { Entity } from '../../services/model/entity.model';
import { UsageMode } from '../../services/model/settings.model';
import { FormGroup } from '@angular/forms';
import { AppTabEditor, AppTabEditorOptions } from './tab-editor.class';
import { AppErrorWithDetails } from '../../services/errors';
import { DateFormatService } from '../../../shared/pipes/date-format.pipe';
import { WaitForOptions } from '../../../shared/observables';
import { FormErrorTranslator } from '../../../shared/validator/form-error-adapter.class';
import * as i0 from "@angular/core";
export interface IEntityEditorModalOptions<T extends Entity<T, ID> = Entity<any, any>, ID = number> {
    isNew: boolean;
    data: T;
    disabled: boolean;
    onAfterModalInit?: <M extends AppEntityEditorModal<T, ID>>(modal: M) => void | Promise<void>;
    onDelete?: (event: Event, data: T) => Promise<boolean>;
    usageMode: UsageMode;
    mobile: boolean;
    i18nSuffix?: string;
}
export declare class AppEntityEditorModalOptions extends AppTabEditorOptions {
    i18nPrefix?: string;
}
export declare abstract class AppEntityEditorModal<T extends Entity<T, ID>, ID = number, O extends AppEntityEditorModalOptions = AppEntityEditorModalOptions> extends AppTabEditor<T, ID> implements OnInit, OnDestroy, AfterViewInit, IEntityEditorModalOptions<T, ID> {
    protected dataType: new () => T;
    protected _logPrefix: string;
    protected _isNew: boolean;
    protected readonly dateFormat: DateFormatService;
    protected readonly cd: ChangeDetectorRef;
    protected readonly settings: LocalSettingsService;
    protected readonly modalCtrl: ModalController;
    protected errorTranslator: FormErrorTranslator;
    readonly savingSubject: BehaviorSubject<boolean>;
    readonly titleSubject: BehaviorSubject<string>;
    data: T;
    mobile: boolean;
    usageMode: UsageMode;
    onAfterModalInit: <M extends AppEntityEditorModal<T, ID>>(modal: M) => void | Promise<void>;
    onDelete: (event: Event, data: T) => Promise<boolean>;
    i18nSuffix: string;
    /**
     * @deprecated
     */
    protected get $title(): Subject<string>;
    set isNew(value: boolean);
    get isNew(): boolean;
    /**
     * @deprecated use isNew instead
     */
    get isNewData(): boolean;
    /**
     * @deprecated use isNew instead
     */
    set isNewData(value: boolean);
    set disabled(value: boolean);
    get disabled(): boolean;
    get isOnFieldMode(): boolean;
    protected constructor(injector: Injector, dataType: new () => T, options?: O);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    waitIdle(opts?: WaitForOptions): Promise<void>;
    load(): Promise<void>;
    reload(): Promise<void>;
    unload(opts?: {
        emitEvent?: boolean;
    }): Promise<void>;
    updateView(data: T, opts?: {
        emitEvent?: boolean;
        openTabIndex?: number;
    }): Promise<void>;
    /**
     * Enable or disable state
     */
    updateViewState(data: T, opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    saveAndClose(event?: Event | Event): Promise<boolean>;
    close(event: Event | Event): Promise<void>;
    /**
     * Save the editor, by calling the dataService.save().
     * Ensure that editor if valid. If not, display an error
     *
     * @param event
     * @param opts
     */
    save(event?: Event | Event, opts?: any): Promise<boolean>;
    /**
     * Save data (if dirty and valid), and return it. Otherwise, return nil value.
     */
    saveAndGetDataIfValid(): Promise<T | undefined>;
    delete(event?: Event | Event): Promise<boolean>;
    resetError(opts?: {
        emitEvent?: boolean;
    }): void;
    setError(err: string | AppErrorWithDetails, opts?: {
        emitEvent?: boolean;
        detailsCssClass?: string;
    }): void;
    abstract setValue(data: T): Promise<void> | void;
    protected abstract registerForms(): void;
    protected abstract computeTitle(data: T): Promise<string>;
    protected abstract get form(): FormGroup;
    protected abstract getFirstInvalidTabIndex(): number;
    protected waitWhilePending(opts?: WaitForOptions): Promise<void>;
    protected getValue(): Promise<T>;
    protected getJsonValueToSave(): Promise<any>;
    /**
     * Compute the title
     *
     * @param data
     */
    protected updateTitle(data?: T): Promise<void>;
    protected scrollToTop(duration?: number): Promise<void>;
    protected markForCheck(): void;
    /**
     * Open the first tab that is invalid
     */
    private openFirstInvalidTab;
    static ɵfac: i0.ɵɵFactoryDeclaration<AppEntityEditorModal<any, any, any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<AppEntityEditorModal<any, any, any>, never, never, { "data": { "alias": "data"; "required": false; }; "mobile": { "alias": "mobile"; "required": false; }; "usageMode": { "alias": "usageMode"; "required": false; }; "onAfterModalInit": { "alias": "onAfterModalInit"; "required": false; }; "onDelete": { "alias": "onDelete"; "required": false; }; "i18nSuffix": { "alias": "i18nSuffix"; "required": false; }; "isNew": { "alias": "isNew"; "required": false; }; "isNewData": { "alias": "isNewData"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; }, {}, never, never, false, never>;
}
