import { EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { MatTabChangeEvent, MatTabGroup } from '@angular/material/tabs';
import { AlertController, NavController } from '@ionic/angular';
import { TranslateService } from '@ngx-translate/core';
import { HammerSwipeEvent } from '../../../shared/gesture/hammer.utils';
import { AppEditor, IAppEditor } from './editor.class';
import * as i0 from "@angular/core";
export interface IAppTabEditor<T = any> extends IAppEditor<T> {
    selectedTabIndex: number;
    setSelectedTabIndex(value: number, opts?: {
        emitEvent?: boolean;
        realignInkBar?: boolean;
    }): void;
    unload(opts?: {
        emitEvent?: boolean;
    }): Promise<void>;
    realignInkBar(): void;
}
export declare class AppTabEditorOptions {
    /**
     * Number of tab. 1 by default
     */
    tabCount?: number;
    /**
     * '200ms' by default
     */
    tabGroupAnimationDuration?: string;
    /**
     * Should enable swipe between tab, on touch screen
     */
    enableSwipe?: boolean;
}
export declare abstract class AppTabEditor<T = any, ID = number, O = any> extends AppEditor<T, ID, O> implements IAppTabEditor<T>, OnInit, OnDestroy {
    protected _selectedTabIndex: number;
    protected tabCount: number;
    protected enableSwipe: boolean;
    protected tabGroupAnimationDuration: string;
    queryTabIndexParamName: string;
    set selectedTabIndex(value: number);
    get selectedTabIndex(): number;
    readonly selectedTabIndexChange: EventEmitter<number>;
    tabGroup: MatTabGroup;
    protected constructor(route: ActivatedRoute, // Modal editor give 'null'
    router: Router, navController: NavController, alertCtrl: AlertController, translate: TranslateService, options?: AppTabEditorOptions);
    ngOnInit(): void;
    ngOnDestroy(): void;
    setSelectedTabIndex(value: number, opts?: {
        emitEvent?: boolean;
        realignInkBar?: boolean;
    }): void;
    realignInkBar(): void;
    onTabChange(event: MatTabChangeEvent, queryTabIndexParamName?: string): boolean;
    /**
     * Action triggered when user swipes
     */
    onSwipeTab(event: HammerSwipeEvent): boolean;
    onSubTabChange(event: MatTabChangeEvent): void;
    unload(opts?: {
        emitEvent?: boolean;
    }): Promise<void>;
    protected abstract getFirstInvalidTabIndex(): number;
    protected updateRoute(): Promise<boolean>;
    static ɵfac: i0.ɵɵFactoryDeclaration<AppTabEditor<any, any, any>, [{ optional: true; }, null, null, null, null, { optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<AppTabEditor<any, any, any>, never, never, { "queryTabIndexParamName": { "alias": "queryTabIndexParamName"; "required": false; }; "selectedTabIndex": { "alias": "selectedTabIndex"; "required": false; }; }, { "selectedTabIndexChange": "selectedTabIndexChange"; }, never, never, false, never>;
}
