import { OnDestroy, OnInit } from '@angular/core';
import { BehaviorSubject, Subject, Subscription } from 'rxjs';
import { IAppForm, IAppFormGetter } from './form.utils';
import { WaitForOptions } from '../../shared/observables';
import { AppTable } from '../table/table.class';
import { AppForm } from './form.class';
import { AppEditor } from './entity/editor.class';
import { AbstractControl } from '@angular/forms';
import { AppAsyncTable } from '../table/async-table.class';
import * as i0 from "@angular/core";
export interface IAppFormContainer<T = any> extends IAppForm<T> {
    children: IAppForm[];
    tables: AppTable<any>[];
    asyncTables: AppAsyncTable<any>[];
    forms: AppForm<any>[];
    editors: AppEditor<any>[];
    addForm(path: string, form?: IAppForm | IAppFormGetter): void;
    addForms(forms: (IAppForm | IAppFormGetter)[]): void;
    removeForm(form: string | IAppForm | IAppFormGetter): IAppForm | IAppFormGetter;
}
export declare abstract class AppFormContainer<T = any> implements IAppFormContainer<T>, OnInit, OnDestroy {
    private _children;
    private _childrenPath;
    private _subscription;
    protected _logPrefix: string;
    protected _enabled: boolean;
    protected readonly destroySubject: Subject<void>;
    readonly enabledSubject: BehaviorSubject<boolean>;
    readonly readySubject: BehaviorSubject<boolean>;
    readonly loadingSubject: BehaviorSubject<boolean>;
    readonly dirtySubject: BehaviorSubject<boolean>;
    readonly touchedSubject: BehaviorSubject<boolean>;
    readonly errorSubject: BehaviorSubject<string>;
    get children(): IAppForm[];
    get tables(): AppTable<any>[];
    get asyncTables(): AppAsyncTable<any>[];
    get forms(): AppForm<any>[];
    get editors(): AppEditor<any>[];
    get error(): string;
    set error(error: string);
    get loading(): boolean;
    get loaded(): boolean;
    get dirty(): boolean;
    get valid(): boolean;
    get invalid(): boolean;
    get pending(): boolean;
    get empty(): boolean;
    get touched(): boolean;
    get untouched(): boolean;
    get enabled(): boolean;
    get disabled(): boolean;
    get destroyed(): boolean;
    debug: boolean;
    protected constructor();
    ngOnInit(): void;
    ngOnDestroy(): void;
    addForm(path: string, form?: IAppForm | IAppFormGetter): void;
    addForms(forms: (IAppForm | IAppFormGetter)[]): void;
    removeForm(form: string | IAppForm | IAppFormGetter): IAppForm | IAppFormGetter;
    disable(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    enable(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    markAsPristine(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    markAsUntouched(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    /**
     * @deprecated prefer to use markAllAsTouched()
     * @param opts
     */
    markAsTouched(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    markAllAsTouched(opts?: {
        emitEvent?: boolean;
    }): void;
    markAsDirty(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    markAsLoading(opts?: {
        emitEvent?: boolean;
    }): void;
    markAsLoaded(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    markAsReady(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    /**
     * Wait form is ready
     *
     * @param opts
     */
    ready(opts?: WaitForOptions): Promise<void>;
    /**
     * Wait form is not busy (=loaded)
     *
     * @param opts
     */
    waitIdle(opts?: WaitForOptions): Promise<void>;
    logFormErrors(prefix?: string): void;
    protected registerSubscription(sub: Subscription): void;
    protected unregisterSubscription(sub: Subscription): void;
    protected setError(value: string, opts?: {
        emitEvent?: boolean;
    }): void;
    protected resetError(opts?: {
        emitEvent?: boolean;
    }): void;
    protected markForCheck(): void;
    protected logChildrenErrors(c: IAppForm | AbstractControl, prefix?: string, path?: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AppFormContainer<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<AppFormContainer<any>, never, never, { "debug": { "alias": "debug"; "required": false; }; }, {}, never, never, false, never>;
}
