import { EventEmitter, Injector, OnDestroy, OnInit } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { BehaviorSubject, Subject, Subscription } from 'rxjs';
import { IAppForm } from './form.utils';
import { LocalSettingsService } from '../services/local-settings.service';
import { WaitForOptions } from '../../shared/observables';
import { FormErrorTranslateOptions, FormErrorTranslator, IFormPathTranslator } from '../../shared/validator/form-error-adapter.class';
import { TranslateService } from '@ngx-translate/core';
import { MatAutocompleteConfigHolder, MatAutocompleteFieldAddOptions, MatAutocompleteFieldConfig } from '../../shared/material/autocomplete/material.autocomplete.config';
import * as i0 from "@angular/core";
export declare class AppForm<T> implements IAppForm<T>, OnInit, OnDestroy, IFormPathTranslator {
    private _subscription;
    protected _form: UntypedFormGroup;
    protected _enabled: boolean;
    protected errorTranslator: FormErrorTranslator;
    protected i18nFieldPrefix: string;
    protected readonly translate: TranslateService;
    protected readonly settings: LocalSettingsService;
    protected readonly destroySubject: Subject<void>;
    readonly readySubject: BehaviorSubject<boolean>;
    readonly loadingSubject: BehaviorSubject<boolean>;
    readonly errorSubject: BehaviorSubject<string>;
    readonly autocompleteHelper: MatAutocompleteConfigHolder;
    readonly autocompleteFields: {
        [key: string]: MatAutocompleteFieldConfig;
    };
    get error(): string;
    set error(error: string);
    get loading(): boolean;
    get loaded(): boolean;
    get value(): any;
    set value(data: any);
    get dirty(): boolean;
    get invalid(): boolean;
    get pending(): boolean;
    get valid(): boolean;
    get empty(): boolean;
    get touched(): boolean;
    get untouched(): boolean;
    get enabled(): boolean;
    get disabled(): boolean;
    disable(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    enable(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    get destroyed(): boolean;
    debug: boolean;
    tabindex: number;
    errorTranslateOptions: FormErrorTranslateOptions;
    set form(value: UntypedFormGroup);
    get form(): UntypedFormGroup;
    onCancel: EventEmitter<any>;
    onSubmit: EventEmitter<any>;
    constructor(injector: Injector, form?: UntypedFormGroup);
    ngOnInit(): void;
    ngOnDestroy(): void;
    cancel(): Promise<void>;
    /**
     *
     * @param event
     * @param opts allow to skip validation check, using {checkValid: false}
     */
    doSubmit(event: any, opts?: {
        checkValid?: boolean;
    }): Promise<void>;
    setForm(form: UntypedFormGroup): void;
    getValue(): Promise<T> | T;
    setValue(data: T, opts?: {
        emitEvent?: boolean;
        onlySelf?: boolean;
    }): Promise<void> | void;
    reset(data?: T, opts?: {
        emitEvent?: boolean;
        onlySelf?: boolean;
    }): void;
    markAsPristine(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    markAsUntouched(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    /**
     * @deprecated prefer to use markAllAsTouched()
     * @param opts
     */
    markAsTouched(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    markAllAsTouched(opts?: {
        emitEvent?: boolean;
    }): void;
    markAsDirty(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    markAsLoading(opts?: {
        emitEvent?: boolean;
    }): void;
    markAsLoaded(opts?: {
        emitEvent?: boolean;
    }): void;
    markAsReady(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    /**
     * Wait form is ready
     *
     * @param opts
     */
    ready(opts?: WaitForOptions): Promise<void>;
    /**
     * Wait form is not busy (=loaded)
     *
     * @param opts
     */
    waitIdle(opts?: WaitForOptions): Promise<void>;
    updateValueAndValidity(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    translateFormPath(path: string): any;
    protected getFormError(form?: UntypedFormGroup, opts?: FormErrorTranslateOptions): string;
    protected getI18nFieldName(path: string): string;
    protected registerSubscription(sub: Subscription): void;
    protected unregisterSubscription(sub: Subscription): void;
    protected registerAutocompleteField<E = any, EF = any>(fieldName: string, opts?: MatAutocompleteFieldAddOptions<E, EF>): MatAutocompleteFieldConfig<E, EF>;
    protected setError(value: string, opts?: {
        emitEvent?: boolean;
    }): void;
    protected markForCheck(): void;
    private setLoading;
    static ɵfac: i0.ɵɵFactoryDeclaration<AppForm<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<AppForm<any>, never, never, { "debug": { "alias": "debug"; "required": false; }; "tabindex": { "alias": "tabindex"; "required": false; }; "errorTranslateOptions": { "alias": "errorTranslateOptions"; "required": false; }; "form": { "alias": "form"; "required": false; }; }, { "onCancel": "onCancel"; "onSubmit": "onSubmit"; }, never, never, false, never>;
    static ngAcceptInputType_debug: unknown;
    static ngAcceptInputType_tabindex: unknown;
}
