import { ChangeDetectorRef, EventEmitter, Injector, OnInit } from '@angular/core';
import { AbstractControl, FormGroupDirective, UntypedFormArray, UntypedFormBuilder, UntypedFormGroup } from '@angular/forms';
import { DateAdapter } from '@angular/material/core';
import { Moment } from 'moment';
import { LocalSettingsService } from '../../services/local-settings.service';
import { AppForm } from '../form.class';
import { SelectionModel } from '@angular/cdk/collections';
import { Observable } from 'rxjs';
import { Color } from '@ionic/core';
import { FormArrayHelper, FormArrayHelperOptions } from '../array/form-array';
import * as i0 from "@angular/core";
export declare interface ItemButton<T = any> {
    title?: string;
    click: (event: Event, item: T, index: number) => void;
    icon: string;
    color?: Color;
    disabled?: Observable<boolean>;
}
export declare type AppListFormOptions<T> = FormArrayHelperOptions & {
    allowMultipleSelection?: boolean;
    buttons?: ItemButton<T>[];
};
export declare class AppListForm<T = any> extends AppForm<T[]> implements OnInit {
    protected injector: Injector;
    protected formBuilder: UntypedFormBuilder;
    protected dateAdapter: DateAdapter<Moment>;
    protected settings: LocalSettingsService;
    protected cd: ChangeDetectorRef;
    private formGroupDir;
    helper: FormArrayHelper<T>;
    selection: SelectionModel<T>;
    formArrayName: string;
    formArray: UntypedFormArray;
    options: AppListFormOptions<T>;
    displayWithFn: (item: any) => string;
    equalsFn: (v1: T, v2: T) => boolean;
    onNewItem: EventEmitter<Event>;
    selectionChanges: EventEmitter<T[]>;
    set value(data: T[]);
    get value(): T[];
    get itemControls(): UntypedFormGroup[];
    get length(): number;
    get empty(): boolean;
    get touched(): boolean;
    get untouched(): boolean;
    get dirty(): boolean;
    get invalid(): boolean;
    get valid(): boolean;
    get pending(): boolean;
    markAsTouched(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    markAllAsTouched(opts?: {
        emitEvent?: boolean;
    }): void;
    constructor(injector: Injector, formBuilder: UntypedFormBuilder, dateAdapter: DateAdapter<Moment>, settings: LocalSettingsService, cd: ChangeDetectorRef, formGroupDir: FormGroupDirective);
    ngOnInit(): void;
    ngOnDestroy(): void;
    setValue(data: T[] | any): void;
    /** Whether the number of selected elements matches the total number of rows. */
    isAllSelected(): boolean;
    masterToggle(opts?: {
        emitEvent?: boolean;
    }): Promise<void>;
    onItemClick(event: MouseEvent, item: T, opts?: {
        emitEvent?: boolean;
    }): Promise<void>;
    onItemButtonClick(button: ItemButton, event: MouseEvent, item: T, index: number): Promise<void>;
    hasSelection(): boolean;
    onNewClick(event: any): void;
    add(value: T, opts?: {
        emitEvent?: boolean;
    }): void;
    removeAt(index: number): void;
    displayWith(value: T): string;
    protected createControl(data?: any): AbstractControl;
    protected markForCheck(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AppListForm<any>, [null, null, null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AppListForm<any>, "app-list-form", never, { "formArrayName": { "alias": "formArrayName"; "required": false; }; "formArray": { "alias": "formArray"; "required": false; }; "options": { "alias": "options"; "required": false; }; "displayWithFn": { "alias": "displayWith"; "required": false; }; "equalsFn": { "alias": "equals"; "required": false; }; }, { "onNewItem": "onNewItem"; "selectionChanges": "selectionChanges"; }, never, never, false, never>;
}
