import { ChangeDetectorRef, Injector, OnInit } from '@angular/core';
import { FormGroupDirective, UntypedFormArray, UntypedFormBuilder, UntypedFormGroup } from '@angular/forms';
import { FormFieldDefinition, FormFieldDefinitionMap } from '../../../shared/form/field.model';
import { DateAdapter, ThemePalette } from '@angular/material/core';
import { Moment } from 'moment';
import { AppForm } from '../form.class';
import { Property, PropertyMap } from '../../../shared/types';
import { PropertyValidator } from './property.validator';
import { PredefinedColors } from '@ionic/core';
import { FormArrayHelper, FormArrayHelperOptions } from '../array/form-array';
import { MatFormFieldAppearance, SubscriptSizing } from '@angular/material/form-field';
import { MatAutocompleteFieldConfig } from '../../../shared/material/autocomplete/material.autocomplete.config';
import { LoadResult } from '../../../shared/services/entity-service.class';
import { RxState } from '@rx-angular/state';
import { SortDirection } from '@angular/material/sort';
import * as i0 from "@angular/core";
export interface AppPropertiesFormState {
    definitions: FormFieldDefinition[];
    definitionKeys: Property[];
}
export declare class AppPropertiesForm<O = any, T extends Property<O> = Property<O>, S extends AppPropertiesFormState = AppPropertiesFormState> extends AppForm<T[]> implements OnInit {
    protected injector: Injector;
    protected formBuilder: UntypedFormBuilder;
    protected dateAdapter: DateAdapter<Moment>;
    protected cd: ChangeDetectorRef;
    protected validator: PropertyValidator;
    private formGroupDir;
    protected readonly _state: RxState<S>;
    protected _definitions$: import("rxjs").Observable<S["definitions"]>;
    protected _definitionKeys$: import("rxjs").Observable<S["definitionKeys"]>;
    protected set _definitionKeys(value: Property[]);
    protected get _definitionKeys(): Property[];
    protected _definitionByKey: FormFieldDefinitionMap;
    protected _definitionsByIndex: {
        [index: number]: FormFieldDefinition;
    };
    protected _helper: FormArrayHelper<Property>;
    protected _autocompleteConfig: MatAutocompleteFieldConfig;
    protected _focusedControlIndex: number;
    formArrayName: string;
    formArray: UntypedFormArray;
    options: FormArrayHelperOptions;
    chipColor: ThemePalette | PredefinedColors;
    mobile: boolean;
    appearance: MatFormFieldAppearance;
    subscriptSizing: SubscriptSizing;
    showHintKey: boolean;
    hintKeyPrefix: string;
    showMoreButton: boolean;
    addButtonText: string;
    addButtonTitle: string;
    showAddButton: boolean;
    panelClass: string;
    panelWidth: string;
    /**
     * @deprecated Use addButtonTitle instead
     * @param value
     */
    set showMoreButtonTitle(value: string);
    get showMoreButtonTitle(): string;
    set definitions(value: FormFieldDefinition[]);
    get definitions(): FormFieldDefinition[];
    set value(data: T[]);
    get value(): T[];
    get length(): number;
    get fieldForms(): UntypedFormGroup[];
    constructor(injector: Injector, formBuilder: UntypedFormBuilder, dateAdapter: DateAdapter<Moment>, cd: ChangeDetectorRef, validator: PropertyValidator, formGroupDir: FormGroupDirective);
    ngOnInit(): void;
    protected processDefinitions(definitions: FormFieldDefinition[]): any[];
    getDefinitionAt(index: number): FormFieldDefinition;
    updateDefinitionAt(index: number, opts?: {
        emitEvent?: boolean;
    }): FormFieldDefinition;
    removeAt(index: number): void;
    setValue(data: PropertyMap | T[]): Promise<void>;
    getValueAsJson(): PropertyMap;
    clear(): void;
    protected clearTemplateCache(): void;
    protected suggestDefinitionKeys(value: any, filter?: any, sortBy?: string | keyof Property, sortDirection?: SortDirection, opts?: {
        offset?: number;
        size?: number;
        [key: string]: any;
    }): Promise<LoadResult<Property>>;
    protected markForCheck(): void;
    protected isEmptyProperty(obj: Property): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<AppPropertiesForm<any, any, any>, [null, null, null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AppPropertiesForm<any, any, any>, "app-properties-form", never, { "formArrayName": { "alias": "formArrayName"; "required": false; }; "formArray": { "alias": "formArray"; "required": false; }; "options": { "alias": "options"; "required": false; }; "chipColor": { "alias": "chipColor"; "required": false; }; "mobile": { "alias": "mobile"; "required": false; }; "appearance": { "alias": "appearance"; "required": false; }; "subscriptSizing": { "alias": "subscriptSizing"; "required": false; }; "showHintKey": { "alias": "showHintKey"; "required": false; }; "hintKeyPrefix": { "alias": "hintKeyPrefix"; "required": false; }; "showMoreButton": { "alias": "showMoreButton"; "required": false; }; "addButtonText": { "alias": "addButtonText"; "required": false; }; "addButtonTitle": { "alias": "addButtonTitle"; "required": false; }; "showAddButton": { "alias": "showAddButton"; "required": false; }; "panelClass": { "alias": "panelClass"; "required": false; }; "panelWidth": { "alias": "panelWidth"; "required": false; }; "showMoreButtonTitle": { "alias": "showMoreButtonTitle"; "required": false; }; "definitions": { "alias": "definitions"; "required": false; }; }, {}, never, never, false, never>;
    static ngAcceptInputType_mobile: unknown;
    static ngAcceptInputType_showHintKey: unknown;
    static ngAcceptInputType_showMoreButton: unknown;
    static ngAcceptInputType_showAddButton: unknown;
}
