import { Property, PropertyMap } from '../../../shared/types';
import { FormFieldDefinition } from '../../../shared/form/field.model';
import { EntitiesServiceLoadOptions, SuggestFn } from '../../../shared/services/entity-service.class';
export declare class AppPropertiesUtils {
    /**
     * Converts an array of `Property` objects into a `PropertiesMap` object.
     *
     * @param {Property[]} [sources] - An optional array of properties to be converted.
     * @param {FormFieldDefinition[]} [definitions] - An optional array of form field definitions to help with the conversion.
     * @param {Object} [opts] - Optional configurations.
     * @param {boolean} [opts.omitNilOrBlank] - If true, properties with nil or blank values will be omitted. Defaults to true.
     * @return {PropertyMap} - The resulting `PropertiesMap` object.
     */
    static arrayAsObject<T = any>(sources?: Property<T>[], definitions?: FormFieldDefinition[], opts?: {
        omitNilOrBlank: boolean;
    }): PropertyMap;
    /**
     * Generates an array of properties from the given object, optionally applying definitions to the properties.
     *
     * @param {PropertyMap} [sources] - The source object from which properties are to be extracted.
     * @param {FormFieldDefinition[]} [definitions] - An optional array of definitions to be applied to the extracted properties.
     * @param opts
     * @return {Property[] | Promise<Property[]>} An array of properties generated from the source object, or a promise resolving to that array.
     */
    static arrayFromObject<T>(sources?: PropertyMap | Property<T>[], definitions?: FormFieldDefinition[], opts?: {
        keepOrphan?: boolean;
    }): Property<T>[] | Promise<Property<T>[]>;
    static sanitize(source: PropertyMap | Property[], opts?: {
        definitions?: FormFieldDefinition[];
        includedKeys?: string[];
    }): PropertyMap | Property[];
}
export declare class AppPropertyUtils {
    static key(key: any): string;
    static getPropertyKey(source: Property | any): string;
    /**
     * Converts the given source to an object that contains a key-value pair.
     *
     * @param {Property<any> | any} source - The source property or any value to be converted.
     * @param {FormFieldDefinition} [def] - The form field definition used for serialization.
     * @param {Object} [opts] - Additional options for serialization.
     * @param {string} [opts.defaultSerializeAttribute='id'] - The attribute to be used for default serialization.
     * @return {{ key: string, value: string } | undefined} An object containing the serialized key-value pair, or undefined if the source is not provided.
     */
    static asObject(source: Property<any> | any, def?: FormFieldDefinition, opts?: {
        defaultSerializeAttribute?: string;
    }): {
        key: string;
        value: string;
    } | undefined;
    static fromObject<T = string>(source: Property | Property<T>, def: FormFieldDefinition, opts?: {
        defaultSuggestFn: SuggestFn<any, any>;
        defaultSuggestOptions?: EntitiesServiceLoadOptions;
        defaultSerializeAttribute?: string;
    }): Property<T> | Promise<Property<T>>;
    private static resolveEntity;
    private static resolveEntityBySuggest;
    private static toString;
}
