import { AfterViewInit, OnDestroy, OnInit } from '@angular/core';
import { PopoverController, PopoverOptions } from '@ionic/angular';
import { Subscription } from 'rxjs';
import { TranslateService } from '@ngx-translate/core';
import { TextForm } from '../../../shared/material/text/text-form.component';
import { ValidatorFn } from '@angular/forms';
import { Color, OverlayEventDetail } from '@ionic/core';
import * as i0 from "@angular/core";
export interface TextPopoverOptions {
    title?: string;
    text?: string;
    placeholder?: string;
    editing?: boolean;
    multiline?: boolean;
    autoHeight?: boolean;
    maxLength?: number;
    autofocus?: boolean;
    validator?: ValidatorFn;
    showHeader?: boolean;
    headerColor?: Color;
    headerButtons?: TextPopoverButton[];
    showFooter?: boolean;
}
export interface TextPopoverButton {
    text?: string;
    icon?: string;
    color?: Color;
    fill?: 'outline' | 'clear' | 'solid';
    side?: 'start' | 'end';
    role?: 'cancel' | string;
    cssClass?: string | string[];
    handler?: (value: string) => boolean | void | Promise<boolean | void>;
}
export declare class TextPopover implements OnInit, AfterViewInit, OnDestroy, TextPopoverOptions {
    protected popoverController: PopoverController;
    protected translate: TranslateService;
    /**
     * Displays a popover using the provided controller, event, and options.
     *
     * @param {PopoverController} ctrl - The popover controller used to create and manage the popover.
     * @param {Event} event - The event that triggers the display of the popover.
     * @param {TextPopoverOptions} opts - The options specific to the text popover component.
     * @param {Partial<PopoverOptions>} [popoverOpts] - Optional additional options for the popover.
     * @return {Promise<OverlayEventDetail>} A promise that resolves with the details of the overlay event once the popover is dismissed.
     */
    static show(ctrl: PopoverController, event: Event, opts: TextPopoverOptions, popoverOpts?: Partial<PopoverOptions>): Promise<OverlayEventDetail>;
    form: TextForm;
    showHeader: boolean;
    headerColor: Color;
    showFooter: boolean;
    title: string;
    text: string;
    placeholder: string;
    editing: boolean;
    multiline: boolean;
    autoHeight: boolean;
    maxLength: number;
    autofocus: boolean;
    validator: ValidatorFn;
    headerButtons: TextPopoverButton[];
    mobile: boolean;
    subscription: Subscription;
    get disabled(): boolean;
    get enabled(): boolean;
    get valid(): boolean;
    get value(): any;
    constructor(popoverController: PopoverController, translate: TranslateService);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    onValidate(event: any): Promise<any>;
    disable(): void;
    enable(): void;
    cancel(): void;
    ngOnDestroy(): void;
    protected clickButton(button: TextPopoverButton): Promise<boolean>;
    protected isStartSide(button: TextPopoverButton): boolean;
    protected isEndSide(button: TextPopoverButton): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<TextPopover, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TextPopover, "app-text-popover", never, { "showHeader": { "alias": "showHeader"; "required": false; }; "headerColor": { "alias": "headerColor"; "required": false; }; "showFooter": { "alias": "showFooter"; "required": false; }; "title": { "alias": "title"; "required": false; }; "text": { "alias": "text"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "editing": { "alias": "editing"; "required": false; }; "multiline": { "alias": "multiline"; "required": false; }; "autoHeight": { "alias": "autoHeight"; "required": false; }; "maxLength": { "alias": "maxLength"; "required": false; }; "autofocus": { "alias": "autofocus"; "required": false; }; "validator": { "alias": "validator"; "required": false; }; "headerButtons": { "alias": "headerButtons"; "required": false; }; "mobile": { "alias": "mobile"; "required": false; }; }, {}, never, never, false, never>;
}
