import { ChangeDetectorRef, InjectionToken, OnDestroy } from '@angular/core';
import { ModalController, ToastController } from '@ionic/angular';
import { BehaviorSubject } from 'rxjs';
import { AccountService } from '../services/account.service';
import { Account } from '../services/model/account.model';
import { Configuration } from '../services/model/config.model';
import { Department } from '../services/model/department.model';
import { LocaleConfig, LocalSettings } from '../services/model/settings.model';
import { TranslateService } from '@ngx-translate/core';
import { ConfigService } from '../services/config.service';
import { PlatformService } from '../services/platform.service';
import { LocalSettingsService } from '../services/local-settings.service';
import { NetworkService } from '../services/network.service';
import { IMenuItem } from '../menu/menu.model';
import { ShowToastOptions } from '../../shared/toast/toasts';
import { Environment } from '../../../environments/environment.class';
import { HistoryPageReference } from '../services/model/history.model';
import { RxState } from '@rx-angular/state';
import { ImagesUtils } from '../../shared/file/images.utils';
import * as i0 from "@angular/core";
/**
 * @param files
 * @deprecated use `getRandomImageWithCredit()` instead
 **/
export declare const getRandomImage: typeof ImagesUtils.getRandomImage;
export declare const getRandomImageWithCredit: typeof ImagesUtils.getRandomImageWithCredit;
export declare const APP_HOME_BUTTONS: InjectionToken<IMenuItem[]>;
export interface HomePageState {
    loading: boolean;
    showSpinner: boolean;
    showPartnerBanner: boolean;
    showLegalInformation: boolean;
    showInstallLinks: boolean;
    pageHistory: HistoryPageReference[];
    darkMode: boolean;
}
export declare class HomePage extends RxState<HomePageState> implements OnDestroy {
    private accountService;
    private modalCtrl;
    private translate;
    private toastController;
    private configService;
    private platform;
    private cd;
    network: NetworkService;
    settings: LocalSettingsService;
    protected environment: Environment;
    locales: LocaleConfig[];
    buttons: IMenuItem[];
    private readonly _debug;
    private _subscription;
    private _config;
    protected darkMode$: import("rxjs").Observable<boolean>;
    protected pageHistory$: import("rxjs").Observable<HistoryPageReference[]>;
    protected loading$: import("rxjs").Observable<boolean>;
    protected readonly mobile: boolean;
    waitingNetwork: boolean;
    accountName: string;
    isLogin: boolean;
    $partners: BehaviorSubject<Department[]>;
    logo: string;
    description: string;
    appName: string;
    isWeb: boolean;
    canRegister: boolean;
    contentStyle: any;
    contentCredits: string;
    legalInformation: IMenuItem[];
    offline: boolean;
    $filteredButtons: BehaviorSubject<IMenuItem[]>;
    readonly showAccountButton: boolean;
    set pageHistory(value: HistoryPageReference[]);
    get pageHistory(): HistoryPageReference[];
    set loading(value: boolean);
    get loading(): boolean;
    set showSpinner(value: boolean);
    get showSpinner(): boolean;
    set showPartnerBanner(value: boolean);
    get showPartnerBanner(): boolean;
    set showLegalInformation(value: boolean);
    get showLegalInformation(): boolean;
    set showInstallLinks(value: boolean);
    get showInstallLinks(): boolean;
    set darkMode(value: boolean);
    get darkMode(): boolean;
    get currentLocaleCode(): string;
    get partnerBannerSize(): number;
    constructor(accountService: AccountService, modalCtrl: ModalController, translate: TranslateService, toastController: ToastController, configService: ConfigService, platform: PlatformService, cd: ChangeDetectorRef, network: NetworkService, settings: LocalSettingsService, environment: Environment, locales: LocaleConfig[], buttons: IMenuItem[]);
    ngOnDestroy(): void;
    login(): Promise<void>;
    register(): Promise<void>;
    logout(event: any): Promise<void>;
    changeLanguage(locale: string): void;
    getPagePath(index: number, page: HistoryPageReference): string;
    tryOnline(): void;
    protected start(): Promise<void>;
    protected showToast(opts: ShowToastOptions): Promise<void>;
    protected onConfigLoaded(config: Configuration): void;
    protected onSettingsChanged(settings: LocalSettings): void;
    protected onLogin(account: Account): void;
    protected onLogout(): void;
    protected refreshButtons(account?: Account): void;
    openMarkdownModal(event?: Event, item?: IMenuItem): Promise<void>;
    protected toggleDarkMode(): Promise<void>;
    protected removePageHistory(path: string): Promise<void>;
    protected markForCheck(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<HomePage, [null, null, null, null, null, null, null, null, null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<HomePage, "app-page-home", never, {}, {}, never, never, false, never>;
}
