import { UserProfileLabel } from '../services/model/person.model';
import { Configuration } from '../services/model/config.model';
import { AppColors, IconRef } from '../../shared/types';
import { BehaviorSubject } from 'rxjs';
import { MenuPathParam } from './menu.service';
import { Account } from '../services/model/account.model';
import { Entity, EntityAsObjectOptions } from '../services/model/entity.model';
import { ITreeItemEntity } from '../services/model/tree-item-entity.model';
export interface IMenuItem extends IconRef {
    id?: number;
    parent?: IMenuItem;
    children?: IMenuItem[];
    title: string;
    path?: string;
    after?: string;
    before?: string;
    static?: boolean;
    action?: string | any;
    profile?: UserProfileLabel;
    exactProfile?: UserProfileLabel;
    color?: string | AppColors;
    cssClass?: string;
    ifProperty?: string;
    titleProperty?: string;
    titleArgs?: {
        [key: string]: string;
    };
    pathParams?: {
        [key: string]: string;
    };
    parentPath?: string;
    parentPathParams?: {
        [key: string]: string;
    };
    pinned?: boolean;
}
export declare class MenuItem extends Entity<MenuItem> implements IMenuItem, ITreeItemEntity<MenuItem> {
    static fromObject: (source: any, opts?: {
        withChildren?: boolean;
    }) => MenuItem;
    parent: MenuItem;
    parentId: number;
    $children: BehaviorSubject<MenuItem[]>;
    static: boolean;
    $title: BehaviorSubject<string>;
    titleProperty?: string;
    titleArgs?: {
        [key: string]: string;
    };
    path?: string;
    pathParams?: {
        [key: string]: string;
    };
    parentPath?: string;
    parentPathParams?: {
        [key: string]: string;
    };
    after?: string;
    before?: string;
    action?: string | any;
    profile?: UserProfileLabel;
    exactProfile?: UserProfileLabel;
    color?: string | AppColors;
    cssClass?: string;
    ifProperty?: string;
    pinned?: boolean;
    icon?: string;
    matIcon?: string;
    matSvgIcon?: string;
    fromObject(source: any, opts?: {
        withChildren?: boolean;
    }): void;
    asObject(opts?: {
        withChildren?: boolean;
    } & EntityAsObjectOptions): any;
    get children(): MenuItem[];
    set children(value: MenuItem[]);
    get title(): string;
    set title(value: string);
    get detached(): boolean;
    get visible(): boolean;
    get expanded(): boolean;
    get ancestor(): MenuItem;
    get divider(): boolean;
    get pinnable(): boolean;
    isPinned(): any;
}
export declare class MenuItems {
    /**
     * Compare, without checking the children
     *
     * @param mainItem
     * @param otherItem
     */
    static isSame(mainItem: IMenuItem, otherItem: IMenuItem): boolean;
    /**
     * Compare, without checking the children and the title
     *
     * @param mainItem
     * @param otherItem
     */
    static isSameIdOrPathAndParams(mainItem: IMenuItem, otherItem: IMenuItem): boolean;
    /**
     * Compare, without checking the children
     *
     * @param mainItem
     * @param otherItem
     */
    static isSamePathAndParams(mainItem: IMenuItem, otherItem: IMenuItem): boolean;
    /**
     * All key/value of the mainParams should exist (and be equals) in the other params
     *
     * @param mainParams
     * @param otherParams
     */
    static isSameParams(mainParams: {
        [key: string]: string;
    }, otherParams: {
        [key: string]: string;
    }): boolean;
    static isParent(child: IMenuItem, parent: IMenuItem | MenuPathParam): boolean;
    static checkIfVisible(item: IMenuItem, account: Account, config: Configuration, opts?: {
        isLogin?: boolean;
        debug?: boolean;
        logPrefix?: string;
    }): boolean;
    static checkIfSubMenuVisible(item: MenuItem, currentPathParam: MenuPathParam): boolean;
    static parsePathWithQuery(pathWithQuery: string): MenuPathParam;
    static getUrl(item: IMenuItem): string;
    static getUrlFromPathAndParams(path: string, params?: any): string;
    static sortByParamOrIdComparator(paramName?: string): (n1: IMenuItem, n2: IMenuItem) => number;
    static sortByTabOrId: (n1: IMenuItem, n2: IMenuItem) => number;
}
/**
 * Options to configure specific behavior on projects
 */
export declare class MenuOptions {
    subMenu?: {
        enable?: boolean;
        showPinButton?: boolean;
        disableIcon?: boolean;
        savePinned?: boolean;
    };
}
