import { EventEmitter, InjectionToken } from '@angular/core';
import { Router } from '@angular/router';
import { AlertController, ModalController, NavController } from '@ionic/angular';
import { TranslateService } from '@ngx-translate/core';
import { BehaviorSubject, Observable } from 'rxjs';
import { Environment } from '../../../environments/environment.class';
import { StartableObservableService } from '../../shared/services/startable-observable-service.class';
import { AccountService } from '../services/account.service';
import { ConfigService } from '../services/config.service';
import { LocalSettingsService } from '../services/local-settings.service';
import { Account } from '../services/model/account.model';
import { IMenuItem, MenuItem, MenuOptions } from './menu.model';
import * as i0 from "@angular/core";
export type SplitPaneShowWhen = boolean | 'lg';
export declare const DEFAULT_MENU_SHOW_WHEN: SplitPaneShowWhen;
export declare const APP_MENU_ITEMS: InjectionToken<IMenuItem[]>;
export declare const APP_MENU_OPTIONS: InjectionToken<MenuOptions>;
export interface MenuPathParam {
    path: string;
    params: {
        [key: string]: string;
    };
}
export declare class MenuService extends StartableObservableService<MenuItem[]> {
    protected settings: LocalSettingsService;
    protected configService: ConfigService;
    protected accountService: AccountService;
    protected router: Router;
    protected modalCtrl: ModalController;
    protected alertController: AlertController;
    protected navController: NavController;
    protected translate: TranslateService;
    protected environment: Environment;
    readonly accountChanges: BehaviorSubject<Account>;
    readonly onPinned: EventEmitter<MenuItem>;
    private _staticItems;
    private _detachedSubItems;
    private _itemCounter;
    private readonly _options;
    private readonly _logPrefix;
    private readonly _$opened;
    private readonly _$splitPaneWhen;
    private readonly _$enabled;
    private readonly _$enableSubMenu;
    constructor(settings: LocalSettingsService, configService: ConfigService, accountService: AccountService, router: Router, modalCtrl: ModalController, alertController: AlertController, navController: NavController, translate: TranslateService, environment: Environment, options?: MenuOptions, staticItems?: IMenuItem[]);
    get opened(): Observable<boolean>;
    get splitPaneWhen(): Observable<SplitPaneShowWhen>;
    get enabled(): Observable<boolean>;
    get subMenuEnabled(): boolean;
    get subItems(): MenuItem[];
    private get _staticSubItems();
    enable(value: boolean): void;
    enableSubMenu(value: boolean): void;
    setSplitPaneShowWhen(value: SplitPaneShowWhen): void;
    toggleSplitPaneWhen(): void;
    fromObject(source: any, opts?: {
        withChildren?: boolean;
        computeId?: boolean;
        fillParent?: boolean;
        fillDefaultFromParent?: boolean;
    }): MenuItem;
    createSubMenu(source: Partial<IMenuItem>): MenuItem;
    addSubMenuItems(sources: IMenuItem[], opts?: {
        skipIfExists?: boolean;
    }): Promise<MenuItem[]>;
    addSubMenuItem(item: IMenuItem, opts?: {
        skipIfExists?: boolean;
    }): Promise<MenuItem>;
    removeSubMenuItems(items: IMenuItem[]): Promise<MenuItem[]>;
    removeSubMenuItem(item: IMenuItem): Promise<MenuItem>;
    togglePinned(source: IMenuItem): void;
    executeAction(event: Event, item: MenuItem): Promise<void>;
    logout(): Promise<void>;
    openAboutModal(): Promise<void>;
    toggleExpandableItem(item: MenuItem): Promise<void>;
    _markAsOpened(): void;
    _markAsClosed(): void;
    close(): Promise<void>;
    open(): Promise<void>;
    protected ngOnStart(): Promise<MenuItem[]>;
    private _loadMenuItems;
    private _addSubMenuItems;
    private _addSubMenuItem;
    private _computeNewId;
    private _removeSubMenuItem;
    private _detachSubMenuItems;
    private _detachToParent;
    private _findExistingItem;
    private _findParent;
    private _attachMenuToParent;
    static ɵfac: i0.ɵɵFactoryDeclaration<MenuService, [null, null, null, null, null, null, null, null, null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<MenuService>;
}
