import { ChangeDetectorRef, EventEmitter, OnDestroy } from '@angular/core';
import { IonSearchbar, ModalController, PopoverController } from '@ionic/angular';
import { Peer } from '../services/model/peer.model';
import { HttpClient } from '@angular/common/http';
import { Environment } from '../../../environments/environment.class';
import { TextPopoverOptions } from '../form/text-popover/text-popover.component';
import { TranslateService } from '@ngx-translate/core';
import { ILoggingService } from '../../shared/logging/logger.model';
import { RxState } from '@rx-angular/state';
import { NodeFeature } from '../services/model/node-feature.model';
import * as i0 from "@angular/core";
export interface ISelectPeerModalOptions {
    canCancel: boolean;
    allowSelectDownPeer: boolean;
    onRefresh: EventEmitter<Event>;
    showSetManuallyButton: boolean;
    selectedPeer?: string;
    title?: string;
    defaultPeers: Peer[];
    showSearchBar?: boolean;
}
export interface ISelectPeerModalState {
    defaultPeers: Peer[];
    peers: Peer[];
    filteredPeers: Peer[];
    filteredPeersByFeatures: Peer[];
    filteredPeerCount: number;
    filteredFeaturesCount: number;
    searchText: string;
    selectedTabIndex: number;
}
export declare class SelectPeerModal extends RxState<ISelectPeerModalState> implements OnDestroy, ISelectPeerModalOptions {
    private modalCtrl;
    private popoverController;
    private translate;
    private http;
    private cd;
    protected environment: Environment;
    protected loggingService?: ILoggingService;
    private _subscription;
    private readonly _logger;
    protected defaultPeers$: import("rxjs").Observable<Peer[]>;
    protected peers$: import("rxjs").Observable<Peer[]>;
    protected filteredPeers$: import("rxjs").Observable<Peer[]>;
    protected filteredPeersByFeatures$: import("rxjs").Observable<Peer[]>;
    protected filteredPeerCount$: import("rxjs").Observable<number>;
    protected filteredFeaturesCount$: import("rxjs").Observable<number>;
    protected loading: boolean;
    protected mobile: boolean;
    protected peerMinVersion: string;
    protected peerDefaultPrefix: string;
    protected enableSelectPeerByFeature: boolean;
    protected collapsedPeers: {
        [key: string]: boolean;
    };
    set peers(value: Peer[]);
    get peers(): Peer[];
    set searchText(value: string);
    get searchText(): string;
    set filteredPeers(value: Peer[]);
    get filteredPeers(): Peer[];
    set selectedTabIndex(value: number);
    get selectedTabIndex(): number;
    selectedPeer: string;
    title: string;
    canCancel: boolean;
    allowSelectDownPeer: boolean;
    showSetManuallyButton: boolean;
    showSearchBar: boolean;
    tabGroupAnimationDuration: '200ms';
    onRefresh: EventEmitter<Event>;
    set defaultPeers(value: Peer[]);
    searchbar: IonSearchbar;
    constructor(modalCtrl: ModalController, popoverController: PopoverController, translate: TranslateService, http: HttpClient, cd: ChangeDetectorRef, environment: Environment, loggingService?: ILoggingService);
    cancel(): void;
    ngOnDestroy(): void;
    selectPeer(peer: Peer): void;
    toggleSearchBar(): Promise<void>;
    togglePeerFeatures(peerUrl: string): void;
    /**
     *  Check the min pod version, defined by the app
     *
     * @param peer
     */
    isCompatible(peer: Peer): boolean;
    refresh(event: Event): void;
    clickSetManually(event?: Event): Promise<void>;
    protected clearLogo(peer: Peer | NodeFeature): void;
    refreshPeers(peers: Peer[]): Promise<void>;
    protected refreshPeer(peer: Peer): Promise<Peer>;
    protected openPeerUrlPopover(event: Event, opts?: Partial<TextPopoverOptions>): Promise<any>;
    protected updateFilteredPeer(event: any): void;
    protected markForCheck(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SelectPeerModal, [null, null, null, null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SelectPeerModal, "select-peer-modal", never, { "selectedTabIndex": { "alias": "selectedTabIndex"; "required": false; }; "selectedPeer": { "alias": "selectedPeer"; "required": false; }; "title": { "alias": "title"; "required": false; }; "canCancel": { "alias": "canCancel"; "required": false; }; "allowSelectDownPeer": { "alias": "allowSelectDownPeer"; "required": false; }; "showSetManuallyButton": { "alias": "showSetManuallyButton"; "required": false; }; "showSearchBar": { "alias": "showSearchBar"; "required": false; }; "tabGroupAnimationDuration": { "alias": "tabGroupAnimationDuration"; "required": false; }; "onRefresh": { "alias": "onRefresh"; "required": false; }; "defaultPeers": { "alias": "defaultPeers"; "required": false; }; }, {}, never, never, false, never>;
    static ngAcceptInputType_selectedTabIndex: unknown;
    static ngAcceptInputType_canCancel: unknown;
    static ngAcceptInputType_allowSelectDownPeer: unknown;
    static ngAcceptInputType_showSetManuallyButton: unknown;
    static ngAcceptInputType_showSearchBar: unknown;
}
