import { Observable } from 'rxjs';
import { ApolloCache, InternalRefetchQueriesInclude, MutationUpdaterFn, MutationUpdaterFunction, WatchQueryFetchPolicy } from '@apollo/client/core';
import { SortDirection } from '@angular/material/sort';
import { BaseGraphqlService } from './base-graphql-service.class';
import { EntitiesServiceLoadOptions, EntitiesServiceWatchOptions, EntityServiceListenChangesOptions, IEntitiesService, IEntityService, LoadResult } from '../../shared/services/entity-service.class';
import { GraphqlService } from '../graphql/graphql.service';
import { PlatformService } from './platform.service';
import { Entity, EntityAsObjectOptions } from './model/entity.model';
import { FetchResult } from '@apollo/client/link/core';
import { EntityFilter } from './model/filter.model';
import { DocumentNode } from 'graphql';
import * as i0 from "@angular/core";
export type MutableWatchQueriesUpdatePolicy = 'update-cache' | 'refetch-queries';
export interface BaseEntityGraphqlQueries {
    load?: any;
    loadAll: any;
    loadAllWithTotal?: any;
    countAll?: any;
}
export interface BaseEntityGraphqlMutations {
    save?: any;
    delete?: any;
    saveAll?: any;
    deleteAll?: any;
}
export interface BaseEntityGraphqlSubscriptions {
    listenChanges?: any;
}
export interface BaseEntityServiceOptions<T extends Entity<any, ID>, ID = number, Q extends BaseEntityGraphqlQueries = BaseEntityGraphqlQueries, M extends BaseEntityGraphqlMutations = BaseEntityGraphqlMutations, S extends BaseEntityGraphqlSubscriptions = BaseEntityGraphqlSubscriptions> {
    queries: Q;
    mutations?: Partial<M>;
    subscriptions?: Partial<S>;
    equals?: (e1: T, e2: T) => boolean;
    /**
     * @deprecated Use 'equals' instead
     */
    equalsFn?: (e1: T, e2: T) => boolean;
    isNew?: (e: T) => boolean;
    /**
     * @deprecated Use 'isNew' instead
     */
    isNewFn?: (e: T) => boolean;
    defaultSortBy?: keyof T;
    defaultSortDirection?: SortDirection;
    watchQueriesUpdatePolicy?: MutableWatchQueriesUpdatePolicy;
}
export interface EntitySaveOptions<T = any, V = any> {
    refetchQueries?: ((result: FetchResult<{
        data: T;
    }>) => InternalRefetchQueriesInclude) | InternalRefetchQueriesInclude;
    awaitRefetchQueries?: boolean;
    update?: MutationUpdaterFn<{
        data: any;
    }> | MutationUpdaterFunction<{
        data: any;
    }, V, any, ApolloCache<{
        data: any;
    }>>;
}
export declare abstract class BaseEntityService<T extends Entity<T, ID>, F extends EntityFilter<F, T, ID>, ID = number, WO extends EntitiesServiceWatchOptions = EntitiesServiceWatchOptions<T>, LO extends EntitiesServiceLoadOptions = EntitiesServiceLoadOptions<T>, Q extends BaseEntityGraphqlQueries = BaseEntityGraphqlQueries, M extends BaseEntityGraphqlMutations = BaseEntityGraphqlMutations, S extends BaseEntityGraphqlSubscriptions = BaseEntityGraphqlSubscriptions> extends BaseGraphqlService<T, F, ID> implements IEntitiesService<T, F, WO>, IEntityService<T, ID, LO> {
    protected graphql: GraphqlService;
    protected platform: PlatformService;
    protected dataType: new () => T;
    protected filterType: new () => F;
    protected readonly _typename: string;
    protected readonly _logTypeName: string;
    protected readonly queries: Q;
    protected readonly mutations: Partial<M>;
    protected readonly subscriptions: Partial<S>;
    protected readonly _equalsFn: (e1: T, e2: T) => boolean;
    protected readonly _isNewFn: (e: T) => boolean;
    protected readonly defaultSortBy: keyof T;
    protected readonly defaultSortDirection: SortDirection;
    protected readonly watchQueriesUpdatePolicy: MutableWatchQueriesUpdatePolicy;
    get defaultFetchPolicy(): WatchQueryFetchPolicy;
    protected constructor(graphql: GraphqlService, platform: PlatformService, dataType: new () => T, filterType: new () => F, options: BaseEntityServiceOptions<T, ID, Q, M, S>);
    watch(id: number, opts?: WO): Observable<T>;
    load(id: ID, opts?: LO): Promise<T>;
    watchAll(offset: number, size: number, sortBy?: string, sortDirection?: SortDirection, dataFilter?: F, opts?: WO): Observable<LoadResult<T>>;
    loadAll(offset: number, size: number, sortBy?: keyof T | string, sortDirection?: SortDirection, filter?: Partial<F>, opts?: LO & {
        debug?: boolean;
    }): Promise<LoadResult<T>>;
    countAll(filter?: Partial<F>, opts?: LO): Promise<number>;
    canUserWrite(data: T, opts?: any): boolean;
    saveAll(entities: T[], opts?: EntitySaveOptions): Promise<T[]>;
    /**
     * Save a referential entity
     *
     * @param entity
     * @param opts
     */
    save(entity: T, opts?: EntitySaveOptions): Promise<T>;
    /**
     * Delete referential entities
     */
    deleteAll(entities: T[], opts?: Partial<{
        update: MutationUpdaterFn<any>;
    }> | any): Promise<any>;
    /**
     * Delete a referential entity
     */
    delete(entity: T, opts?: EntitySaveOptions | any): Promise<any>;
    listenChanges(id: ID, opts?: EntityServiceListenChangesOptions<T>): Observable<T>;
    copyIdAndUpdateDate(source: T, target: T): void;
    fromObject(source: any, opts?: {
        toEntity?: boolean | ((source: any, opts?: any) => T);
        [key: string]: any;
    }): T;
    asFilter(source: any): F;
    equals(d1: T, d2: T): boolean;
    isNew(data: T): boolean;
    /**
     * @deprecated Use equals() instead
     */
    equalsFn(d1: T, d2: T): boolean;
    /**
     * @deprecated Use isNew() instead
     * @param data
     */
    isNewFn(data: T): boolean;
    protected ngOnStart(): Promise<void>;
    protected fillDefaultProperties(source: T): void;
    protected fromObjects(sources: any[], opts?: {
        toEntity?: boolean | ((source: any, opts?: any) => T);
        [key: string]: any;
    }): T[];
    protected asObject(source: T, opts?: EntityAsObjectOptions): any;
    protected getRefetchQueriesForMutation(opts?: EntitySaveOptions): ((result: FetchResult<{
        data: any;
    }>) => InternalRefetchQueriesInclude) | InternalRefetchQueriesInclude;
    protected getLoadQueries(): DocumentNode[];
    protected getLoadQueryNames(): string[];
    static ɵfac: i0.ɵɵFactoryDeclaration<BaseEntityService<any, any, any, any, any, any, any, any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaseEntityService<any, any, any, any, any, any, any, any>, never, never, {}, {}, never, never, false, never>;
}
