import { GraphqlService, MutateQueryOptions, WatchQueryOptions } from '../graphql/graphql.service';
import { Page } from '../../shared/services/entity-service.class';
import { Observable } from 'rxjs';
import { FetchResult } from '@apollo/client/link/core';
import { ApolloCache, InternalRefetchQueriesInclude } from '@apollo/client/core';
import { QueryRef } from 'apollo-angular';
import { PureQueryOptions } from '@apollo/client/core/types';
import { DocumentNode } from 'graphql';
import { StartableService } from '../../shared/services/startable-service.class';
import { TypedDocumentNode } from '@graphql-typed-document-node/core';
import { EmptyObject } from '../graphql/graphql.utils';
import * as i0 from "@angular/core";
export interface QueryVariables<F = any> extends Partial<Page> {
    filter?: F;
    [key: string]: any;
}
export interface MutateQueryWithCacheUpdateOptions<T = any, V = EmptyObject> extends MutateQueryOptions<T, V> {
    cacheInsert?: {
        query: any;
        fetchData: (variables: V, mutationResult: FetchResult<T>) => any;
    }[];
    cacheRemove?: {
        query: any;
        fetchIds: (variables: V) => number | number[];
    }[];
}
export interface MutableWatchQueryOptions<D, T = any, V = EmptyObject> extends WatchQueryOptions<V> {
    queryName: string;
    arrayFieldName: keyof D;
    totalFieldName?: keyof D;
    insertFilterFn?: (data: T) => boolean;
    sortFn?: (a: T, b: T) => number;
}
export interface MutableWatchQueryDescription<TData, TEntityClass = any, TVariables = EmptyObject> extends PureQueryOptions<TVariables, TData> {
    id?: string;
    query: DocumentNode | TypedDocumentNode<TData, TVariables>;
    queryRef: QueryRef<TData, TVariables>;
    variables: TVariables;
    arrayFieldName: keyof TData;
    totalFieldName?: keyof TData;
    insertFilterFn?: (data: TEntityClass) => boolean;
    sortFn?: (a: TEntityClass, b: TEntityClass) => number;
    counter: number;
}
export interface FindMutableWatchQueriesOptions {
    query?: DocumentNode;
    queries?: DocumentNode[];
    queryName?: string;
    queryNames?: string[];
}
export declare class BaseGraphqlServiceOptions {
    production?: boolean;
}
export declare abstract class BaseGraphqlService<T = any, F = any, ID = any, S = void> extends StartableService<S> {
    protected graphql: GraphqlService;
    protected _logPrefix: string;
    protected _mutableWatchQueries: MutableWatchQueryDescription<any>[];
    protected _mutableWatchQueriesMaxCount: number;
    protected constructor(graphql: GraphqlService, options?: BaseGraphqlServiceOptions);
    mutableWatchQuery<D, V = EmptyObject>(opts: MutableWatchQueryOptions<D, T, V>): Observable<D>;
    insertIntoMutableCachedQueries(cache: ApolloCache<any>, opts: FindMutableWatchQueriesOptions & {
        data: T[] | T;
    }): void;
    removeFromMutableCachedQueriesByIds(cache: ApolloCache<any>, opts: FindMutableWatchQueriesOptions & {
        ids: ID | ID[];
    }): number;
    refetchMutableWatchQueries(opts: FindMutableWatchQueriesOptions & {
        variables?: any;
    }): Promise<void>;
    protected computeMutableWatchQueryId<D, T, V = EmptyObject>(opts: MutableWatchQueryOptions<D, T, V>): string;
    protected findMutableWatchQueries(opts: FindMutableWatchQueriesOptions): MutableWatchQueryDescription<any>[];
    protected registerNewMutableWatchQuery(mutableQuery: MutableWatchQueryDescription<any>): void;
    protected findRefetchQueries(opts: FindMutableWatchQueriesOptions): InternalRefetchQueriesInclude;
    protected ngOnStart(): Promise<S>;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaseGraphqlService<any, any, any, any>, [null, { optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaseGraphqlService<any, any, any, any>, never, never, {}, {}, never, never, false, never>;
}
