import { ScryptParams } from '@polkadot/util-crypto/scrypt/types';
import { Keypair } from '@polkadot/util-crypto/types';
import * as i0 from "@angular/core";
export declare const ED25519_SEED_LENGTH = 32;
export declare const SCRYPT_PARAMS: {
    SIMPLE: ScryptParams;
    DEFAULT: ScryptParams;
    SECURE: ScryptParams;
    HARDEST: ScryptParams;
    EXTREME: ScryptParams;
};
export { Keypair };
export declare class CryptoService {
    private static _ready;
    private static get started();
    private static ready;
    /**
     * Generate a sign keypair, using scrypt, from a salt and a password
     *
     * @param salt
     * @param password
     * @param scryptParams
     */
    static scryptKeypair(salt: string, password: string, scryptParams?: ScryptParams): Promise<Keypair>;
    /**
     * Sign a message, from a key pair
     */
    static sign(message: string, keypair: Keypair): Promise<string>;
    /**
     * Sign a message, from a key pair
     */
    static verify(message: string, signature: string, publicKey: string): Promise<boolean>;
    /**
     * Hash (using SHA256) a message, as Hex
     */
    static sha256(message: string): string;
    /**
     * Hash (using SHA512) a message, as Hex
     */
    static sha512(message: string): string;
    static encodeBase64(message: string): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<CryptoService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CryptoService>;
}
