import { InjectionToken } from '@angular/core';
import { LocalSettings, OfflineFeature, UsageMode } from './model/settings.model';
import { TranslateService } from '@ngx-translate/core';
import { Storage } from '@ionic/storage-angular';
import { Subject } from 'rxjs';
import { Platform } from '@ionic/angular';
import { FormFieldDefinition, FormFieldDefinitionMap } from '../../shared/form/field.model';
import { Moment } from 'moment';
import { LatLongPattern } from '../../shared/material/latlong/latlong.utils';
import { Environment } from '../../../environments/environment.class';
import { HistoryPageReference } from './model/history.model';
import { StartableService } from '../../shared/services/startable-service.class';
import * as i0 from "@angular/core";
export declare const SETTINGS_STORAGE_KEY = "settings";
export declare const SETTINGS_TRANSIENT_PROPERTIES: string[];
export interface LocalSettingsOptions {
    serializeAsString?: boolean;
    options: FormFieldDefinitionMap;
}
export declare interface AddToPageHistoryOptions {
    removePathQueryParams?: boolean;
    removeTitleSmallTag?: boolean;
    emitEvent?: boolean;
}
export declare const APP_LOCAL_SETTINGS: InjectionToken<Partial<LocalSettings>>;
export declare const APP_LOCAL_SETTINGS_OPTIONS: InjectionToken<LocalSettingsOptions>;
export declare class LocalSettingsService extends StartableService<LocalSettings> {
    private translate;
    private storage;
    protected readonly environment: Environment;
    private readonly defaultSettings;
    onChange: Subject<LocalSettings>;
    darkMode$: import("rxjs").Observable<boolean>;
    private readonly _optionDefs;
    private readonly _serializeAsString;
    private _$persist;
    get settings(): LocalSettings;
    get locale(): string;
    get latLongFormat(): LatLongPattern;
    get usageMode(): UsageMode;
    set usageMode(value: UsageMode);
    get mobile(): boolean;
    set mobile(value: boolean);
    get pageHistory(): HistoryPageReference[];
    get allowDarkMode(): boolean;
    get isDarkMode(): boolean;
    constructor(platform: Platform, translate: TranslateService, storage: Storage, environment: Environment, defaultSettings: LocalSettings, options: LocalSettingsOptions);
    ngOnStart(): Promise<LocalSettings>;
    isUsageMode(mode: UsageMode): boolean;
    isOnFieldMode(value?: UsageMode): boolean;
    restoreLocally(): Promise<LocalSettings | undefined>;
    setProperty<T = string>(keyOrDef: string | FormFieldDefinition, value: T, opts?: {
        emitEvent?: boolean;
        immediate?: boolean;
    }): void;
    getProperty(keyOrDef: string | FormFieldDefinition, defaultValue?: any): any;
    getPropertyAsBoolean(definition: FormFieldDefinition, defaultValue?: boolean): boolean;
    getPropertyAsInt(definition: FormFieldDefinition, defaultValue?: number): number;
    getPropertyAsNumbers(definition: FormFieldDefinition, defaultValue?: number[]): number[];
    getPropertyAsStrings(definition: FormFieldDefinition, defaultValue?: string[]): string[];
    getPropertyAsObjects(definition: FormFieldDefinition, defaultValue?: any[]): any[];
    apply(settings: Partial<LocalSettings>, opts?: {
        emitEvent?: boolean;
        persistImmediate?: boolean;
        sanitize?: boolean;
    }): Promise<void>;
    applyProperty(key: keyof LocalSettings, value: any, opts?: {
        emitEvent?: boolean;
        persistImmediate?: boolean;
    }): Promise<void>;
    getPageSettings<T = any>(pageId: string, propertyName?: string): T;
    savePageSetting(pageId: string, value: any, propertyName?: string): Promise<void>;
    getOfflineFeature<F = any>(featureName: string): OfflineFeature<F>;
    getOfflineFeatureLastSyncDate(featureName: string): Moment;
    hasOfflineFeature(featureName?: string): boolean;
    saveOfflineFeature(feature: OfflineFeature): void;
    markOfflineFeatureAsSync(featureName: string): void;
    removeOfflineFeatures(): void;
    getFieldDisplayAttributes(fieldName: string, defaultAttributes?: string[]): string[];
    getPageFieldDefaultValue(pageId: string, fieldName: string): any;
    get optionDefs(): FormFieldDefinition[];
    registerOption(def: FormFieldDefinition, opts?: {
        replaceIfExists?: boolean;
    }): void;
    registerOptions(defs: FormFieldDefinition[]): void;
    addToPageHistory(page: HistoryPageReference, opts?: AddToPageHistoryOptions, pageHistory?: HistoryPageReference[]): Promise<void>;
    removePageHistory(path: string, opts?: {
        emitEvent?: boolean;
        persistImmediate?: boolean;
    }, pageHistory?: HistoryPageReference[], // used for recursive call to children)
    depth?: number): any;
    clearPageHistory(): Promise<void>;
    protected ngOnStop(): Promise<void>;
    private resetData;
    private persistLocally;
    private fillPageHistoryDefaults;
    static ɵfac: i0.ɵɵFactoryDeclaration<LocalSettingsService, [null, null, null, null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<LocalSettingsService>;
}
