import { LocalSettings } from './settings.model';
import { Person, UserProfileLabel } from './person.model';
import { Entity, EntityAsObjectOptions } from './entity.model';
import { LatLongPattern } from '../../../shared/material/latlong/latlong.utils';
import { UserToken } from './token.model';
import { FormFieldDefinition } from '../../../shared/form/field.model';
/**
 * A user account
 */
export declare class Account extends Person<Account> {
    static fromObject: (source: any, opts?: any) => Account;
    settings: UserSettings;
    tokens: UserToken[];
    constructor();
    asObject(opts?: EntityAsObjectOptions): any;
    fromObject(source: any): void;
    /**
     * Convert into a Person. This will fill __typename with a right value, for data cache
     */
    asPerson(): Person;
    get displayName(): string;
}
export declare abstract class AccountUtils {
    static accountToString: typeof accountToString;
    static hasMinProfile(account: Account | null, userProfile: UserProfileLabel): boolean;
    static hasExactProfile(account: Account | null, label: UserProfileLabel): boolean;
    static hasProfileAndIsEnable(account: Account | null, userProfile: UserProfileLabel): boolean;
}
export declare class UserSettings extends Entity<UserSettings> {
    static SETTINGS_PROPERTIES: string[];
    static fromObject: (source: any, opts?: any) => UserSettings;
    locale: string;
    latLongFormat: LatLongPattern;
    content: any;
    nonce: string;
    constructor();
    asObject(opts?: EntityAsObjectOptions): any;
    fromObject(source: any, opts?: any): void;
    /**
     * Merges the given source object into the current instance.
     *
     * @param {S} source - The source object containing properties to merge.
     * @param {Array<keyof S | string | number>} [includedProperties] - Optional array of property keys to be merged into the content map.
     * @param {boolean} [resetContent] - Optional flag to reset existing content. False by default
     * @return {boolean} - Returns true if any changes were made; otherwise, false.
     */
    merge<S = LocalSettings>(source: S, includedProperties: (keyof S | string | number)[], resetContent?: boolean): boolean;
    /**
     * Transform user settings into local settings
     * @param opts
     */
    asLocalSettings(opts?: {
        definitions?: FormFieldDefinition[];
    }): Partial<LocalSettings>;
}
export declare function accountToString(data: Account): string;
