import { Entity, EntityAsObjectOptions, IEntity } from './entity.model';
import { FilterFn } from '../../../shared/types';
export interface IEntityFilter<F extends IEntityFilter<F, T, ID, AO, FO>, T extends IEntity<T, any>, ID = number, AO extends EntityAsObjectOptions = EntityAsObjectOptions, FO = any> extends IEntity<F, ID, AO, FO> {
    asPodObject(): any;
    asFilterFn(): FilterFn<T>;
    isEmpty(): boolean;
    countNotEmptyCriteria(): number;
}
export declare abstract class EntityFilter<F extends IEntityFilter<F, T, ID, AO, FO>, T extends IEntity<T, any>, ID = number, AO extends EntityAsObjectOptions = EntityAsObjectOptions, FO = any> extends Entity<F, ID, AO, FO> implements IEntityFilter<F, T, ID, AO, FO> {
    /**
     * Compose some filter functions: all should return true
     *
     * @param filterFns
     */
    static composeFilters<T extends IEntity<T, any>>(filterFns: FilterFn<T>[]): FilterFn<T>;
    static compose<F extends EntityFilter<F, T>, T extends IEntity<T, any>>(filters: F[]): FilterFn<T>;
    /**
     * Compose some filter functions: all should return true
     *
     * @param filterFns
     */
    static composeFns<T extends IEntity<T, any>>(filterFns: FilterFn<T>[]): FilterFn<T>;
    constructor(__typename?: string);
    /**
     * Clean a filter, before sending to the pod (e.g convert dates, remove internal properties, etc.)
     */
    asPodObject(): any;
    isEmpty(): boolean;
    countNotEmptyCriteria(): number;
    asFilterFn(): FilterFn<T>;
    protected buildFilter(): FilterFn<T>[];
    protected isCriteriaNotEmpty(key: string, value: any): boolean;
}
export declare abstract class EntityFilterUtils {
    static isEntityFilter<F extends EntityFilter<F, any>>(obj: Partial<F>): obj is F;
    static fromObject<F>(source: any, filterType: new () => F): F;
}
