import { Moment } from 'moment';
import { Entity, EntityAsObjectOptions, IEntity } from './entity.model';
import { IconRef } from '../../../shared/types';
export declare function referentialToString(obj: Referential | any, properties?: string[], separator?: string): string | undefined;
export declare function referentialsToString(values: Referential[], properties?: string[], valueSeparator?: string, propertySeparator?: string): string;
export declare interface IStatus {
    id: number;
    icon?: string;
    label: string;
}
export declare const StatusList: Readonly<IStatus[]>;
export declare const StatusById: Readonly<import("../../../shared/types").KeyValueType<IStatus>>;
export declare interface IReferentialRef<T extends IEntity<T, ID> = IEntity<any, any>, ID = number> extends IEntity<T, ID> {
    label: string;
    name: string;
    description?: string;
    levelId?: number;
    statusId: number;
    entityName: string;
    icon?: IconRef;
}
export declare abstract class BaseReferential<T extends BaseReferential<T, ID, AO>, ID = number, AO extends ReferentialAsObjectOptions = ReferentialAsObjectOptions, FO = any> extends Entity<T, ID, AO, FO> implements IReferentialRef<T, ID> {
    label: string;
    name: string;
    description: string;
    comments: string;
    creationDate: Date | Moment;
    statusId: number;
    validityStatusId: number;
    levelId: number;
    parentId: number;
    entityName: string;
    icon?: IconRef;
    protected constructor(__typename?: string);
    asObject(opts?: AO): any;
    fromObject(source: any, opts?: FO): void;
    equals(other: T): boolean;
}
export declare class Referential<T extends Referential<T, any> = Referential<any>, ID = number> extends BaseReferential<T, ID> {
    static fromObject: (source: any, opts?: any) => Referential;
    properties?: {
        [key: string]: any;
    };
    constructor();
    fromObject(source: any, opts?: any): void;
    asObject(opts?: ReferentialAsObjectOptions): any;
}
export declare class ReferentialUtils {
    static fromObject(source: any, opts?: any): Referential;
    static isNotEmpty<T extends IReferentialRef<T>>(obj: T | any): boolean;
    static isEmpty<T extends IReferentialRef<T>>(obj: T | any): boolean;
    static equals<T extends IReferentialRef<T>>(o1: T | any, o2: T | any): boolean;
    static isNotDisabled<T extends IReferentialRef<T>>(obj: T | any): boolean;
}
export interface ReferentialAsObjectOptions extends EntityAsObjectOptions {
    keepEntityName?: boolean;
    keepIcon?: boolean;
    keepProperties?: boolean;
}
/**
 * Used to store an entity locally
 */
export declare const MINIFY_ENTITY_FOR_LOCAL_STORAGE: ReferentialAsObjectOptions;
/**
 * Used to send an entity to a pod
 */
export declare const MINIFY_ENTITY_FOR_POD: ReferentialAsObjectOptions;
export declare class ReferentialRef<T extends ReferentialRef<any, ID> = ReferentialRef<any, any>, ID = number, O extends ReferentialAsObjectOptions = ReferentialAsObjectOptions, FO = any> extends Entity<T, ID, O, FO> implements IReferentialRef<T, ID> {
    static fromObject: (source: any, opts?: any) => ReferentialRef;
    static clone(source: any): ReferentialRef;
    label: string;
    name: string;
    description: string;
    statusId: number;
    levelId: number;
    entityName: string;
    icon?: IconRef;
    properties?: {
        [key: string]: any;
    };
    constructor();
    asObject(opts?: O): any;
    fromObject(source: any, opts?: FO): void;
}
