import { IEntity } from './entity.model';
import { EntityFilter } from './filter.model';
import { FilterFn } from '../../../shared/types';
export declare interface ITreeItemEntity<T extends IEntity<T, ID>, ID = number> {
    parentId: ID;
    parent: T;
    children: T[];
}
export declare class TreeItemEntityUtils {
    static forward<T extends ITreeItemEntity<any>>(node: T, filterFn?: FilterFn<T>, loopCount?: number): T;
    static backward<T extends ITreeItemEntity<any>, ID = number>(node: T, filterFn?: FilterFn<T>, loopCount?: number): T;
    static first<T extends ITreeItemEntity<any>>(node: T, filterFn?: FilterFn<T>): T;
    static lastLeaf<T extends ITreeItemEntity<any>>(node: T, filterFn?: FilterFn<T>): T;
    static findByFilter<T extends ITreeItemEntity<T> & IEntity<T>>(node: T, filter: EntityFilter<any, T>): T[];
    /**
     * Delete matches batches
     *
     * @param node
     * @param filter
     */
    static deleteByFilter<T extends ITreeItemEntity<T> & IEntity<T>>(node: T, filter: EntityFilter<any, T>): T[];
    static filterRecursively<T extends ITreeItemEntity<any>>(node: T, filterFn: (n: T) => boolean): T[];
    static deleteRecursively<T extends ITreeItemEntity<any>>(node: T, filterFn: (n: T) => boolean): T[];
    /**
     * Visit each node, from root to leaf
     *
     * @param node
     * @param action
     */
    static visit<T extends ITreeItemEntity<any>>(node: T, action: (item: T) => void): void;
    /**
     * Visit each node, from leaf to root
     *
     * @param node
     * @param action
     */
    static visitInverse<T extends ITreeItemEntity<any>>(node: T, action: (T: any) => void): void;
    /**
     * Transform a batch entity tree into a array list. This method keep links parent/children.
     *
     * Method used to find batch without id (e.g. before local storage)
     *
     * @param source
     */
    static treeToArray<T extends ITreeItemEntity<any>>(source: T): T[];
    static listOfTreeToArray<T extends ITreeItemEntity<any>>(sources: T[]): T[];
    /**
     * Fill parent attribute, of all children found in the tree
     *
     * @param source
     */
    static treeFillParent<T extends ITreeItemEntity<any>>(source: T): any;
    /**
     * Converts an array of objects into a tree hierarchy based on parent-child relationships.
     *
     * @param {T[]} sources - The array of source objects to be converted into tree structure.
     * @param {new () => T} [dataType] - An optional class constructor used to shape the objects within the tree.
     * @return {T[] | undefined} An array of root elements representing the tree structure, or undefined if the input is empty.
     */
    static fromObjectArrayAsTrees<T extends ITreeItemEntity<T> & IEntity<T>>(sources: T[], dataType?: new () => T): T[];
}
