import { EventEmitter } from '@angular/core';
import { TranslateService } from '@ngx-translate/core';
import { Storage } from '@ionic/storage-angular';
import { Peer } from './model/peer.model';
import { ModalController, Platform, ToastController } from '@ionic/angular';
import { ISelectPeerModalOptions } from '../peer/select-peer.modal';
import { BehaviorSubject, Subscription } from 'rxjs';
import { ConnectionType } from '@capacitor/network';
import { LocalSettingsService } from './local-settings.service';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { CacheService } from 'ionic-cache';
import { ShowToastOptions } from '../../shared/toast/toasts';
import { OverlayEventDetail } from '@ionic/core';
import { AppManifest, NodeInfo } from './network.utils';
import { Environment } from '../../../environments/environment.class';
import { StartableObservableService } from '../../shared/services/startable-observable-service.class';
import { NetworkEventType } from './network.types';
import { ILoggingService } from '../../shared/logging/logger.model';
import * as i0 from "@angular/core";
export declare const PEER_URL_REGEXP: RegExp;
export declare const NETWORK_DEFAULT_CONNECTION_TIMEOUT = 10000;
export declare class NetworkService extends StartableObservableService<Peer, Peer> {
    private _document;
    private modalCtrl;
    private storage;
    private settings;
    private cache;
    private http;
    protected environment: Environment;
    private loggingService;
    private translate;
    private toastController;
    onPeerChanges: import("rxjs").Observable<string>;
    onNetworkStatusChanges: BehaviorSubject<ConnectionType>;
    onResetNetworkCache: EventEmitter<any>;
    private readonly _mobile;
    private readonly _logger;
    private _timerSubscription;
    private readonly _timerRefreshPeriod;
    private readonly _timerRefreshCondition;
    private _deviceConnectionType;
    private _forceOffline;
    private readonly _connectionTimeout;
    private _listeners;
    get online(): boolean;
    get offline(): boolean;
    get forceOffline(): boolean;
    get connectionType(): ConnectionType;
    get peer(): Peer;
    set peer(peer: Peer);
    get connectionTimeout(): number;
    constructor(_document: any, platform: Platform, modalCtrl: ModalController, storage: Storage, settings: LocalSettingsService, cache: CacheService, http: HttpClient, environment: Environment, loggingService: ILoggingService, translate: TranslateService, toastController: ToastController);
    /**
     * Register to network event
     *
     * @param eventType
     * @param callback
     */
    on<T = any>(eventType: NetworkEventType, callback: (data?: T) => Promise<any>): Subscription;
    tryOnline(opts?: {
        showOfflineToast?: boolean;
        showOnlineToast?: boolean;
        showLoadingToast?: boolean;
        afterRetryDelay?: number;
        afterRetryPromise?: () => Promise<any>;
    }): Promise<boolean>;
    showOfflineToast(opts?: {
        message?: string;
        showCloseButton?: boolean;
        showRetryButton?: boolean;
        showRetrySuccessToast?: boolean;
        showRetryLoadingToast?: boolean;
        onRetrySuccess?: () => void;
    }): Promise<boolean>;
    /**
     * Check if the peer is alive
     *
     * @param peer
     */
    checkPeerAlive(peer?: string | Peer): Promise<NodeInfo>;
    /**
     * Checks whether a peer is compatible based on its software version and the required minimum version.
     * Optionally displays a toast notification if the peer is not compatible.
     *
     * @param {NodeInfo} peerInfo - Information about the peer, including its software version.
     * @param {Object} [opts] - Additional options for the compatibility check.
     * @param {boolean} [opts.showToast] - Whether to show a toast notification if the peer is not compatible. Defaults to true.
     * @return {Promise<boolean>} - A promise that resolves to `true` if the peer is compatible, otherwise `false`.
     */
    checkPeerCompatible(peerInfo: NodeInfo, opts?: {
        showToast?: boolean;
    }): Promise<boolean>;
    getNodeInfo(peer?: string | Peer, opts?: {
        nocache?: boolean;
        timeout?: number;
    }): Promise<NodeInfo>;
    getAppManifest(peer?: string | Peer, opts?: {
        nocache?: boolean;
    }): Promise<AppManifest | undefined>;
    getAppVersion(peer?: string | Peer, opts?: {
        nocache: boolean;
    }): Promise<string | undefined>;
    computePeerPath(peer: string | Peer | undefined, path: string): string | undefined;
    /**
     * Allow to force offline mode
     */
    setForceOffline(value?: boolean, opts?: {
        showToast?: boolean;
    }): void;
    showSelectPeerModal(opts?: Partial<ISelectPeerModalOptions>): Promise<Peer | undefined>;
    clearCache(opts?: {
        emitEvent?: boolean;
    }): Promise<void>;
    protected ngOnStart(peer?: Peer): Promise<Peer>;
    protected ngOnAfterStart(peer: Peer): Promise<void>;
    protected ngOnStop(): void;
    /**
     * Try to restore peer from the local storage
     */
    protected restoreLocally(): Promise<Peer | undefined>;
    /**
     * Stop to network state
     *
     * @protected
     */
    protected stopRefreshTimer(): void;
    /**
     * Refresh the network state
     *
     * @protected
     */
    protected startRefreshTimer(): void;
    protected getText(path: string, opts?: {
        headers?: HttpHeaders | {
            [header: string]: string | string[];
        };
        responseType?: 'text';
        nocache?: boolean;
    }): Promise<string>;
    protected get<T>(path: string, opts?: {
        headers?: HttpHeaders | {
            [header: string]: string | string[];
        };
        responseType?: 'json';
        nocache?: boolean;
        timeout?: number;
    }): Promise<T>;
    protected getUri(path: string): string;
    protected onDeviceConnectionChanged(connectionType?: ConnectionType): void;
    /**
     * Get default peers, from environment
     */
    protected getDefaultPeers(): Promise<Peer[]>;
    protected showToast<T = any>(opts: ShowToastOptions): Promise<OverlayEventDetail<T>>;
    protected addListener<T = any>(name: NetworkEventType, callback: (data?: T) => Promise<void>): Subscription;
    protected emit<T = any>(name: NetworkEventType, data?: T): Promise<void[]>;
    static ɵfac: i0.ɵɵFactoryDeclaration<NetworkService, [null, null, null, null, null, null, null, null, { optional: true; }, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<NetworkService>;
}
