import { Platform, ToastController } from '@ionic/angular';
import { NetworkService } from './network.service';
import { Platforms } from '@ionic/core';
import { LocalSettingsService } from './local-settings.service';
import { CacheService } from 'ionic-cache';
import { AudioProvider } from '../../shared/audio/audio';
import { Platform as CdkPlatform } from '@angular/cdk/platform';
import { EntitiesStorage } from './storage/entities-storage.service';
import { ShowToastOptions } from '../../shared/toast/toasts';
import { TranslateService } from '@ngx-translate/core';
import { AccountService } from './account.service';
import { BehaviorSubject, Observable } from 'rxjs';
import { Environment } from '../../../environments/environment.class';
import { ConfigService } from './config.service';
import { MomentDateAdapter } from '@angular/material-moment-adapter';
import { Downloader, DownloadRequest } from '@awesome-cordova-plugins/downloader/ngx';
import { StartableService } from '../../shared/services/startable-service.class';
import { OpenOptions } from '@capacitor/browser';
import { ILoggingService } from '../../shared/logging/logger.model';
import { Clipboard as CdkClipboard } from '@angular/cdk/clipboard';
import { WriteOptions } from '@capacitor/clipboard/dist/esm/definitions';
import * as i0 from "@angular/core";
export declare const AndroidOsEnvironment: Readonly<{
    DIRECTORY_DOWNLOADS: "Download";
    DIRECTORY_DOWNLOADS_OLD: "Downloads";
}>;
export declare class PlatformService extends StartableService {
    private ionicPlatform;
    private cdkPlatform;
    private cdkClipboard;
    private toastController;
    private translate;
    private dateAdapter;
    private entitiesStorage;
    private settings;
    private networkService;
    private accountService;
    private configService;
    private cache;
    private audioProvider;
    protected environment: Environment;
    private downloader;
    private _logger;
    private _mobile;
    private _desktop;
    private _cordova;
    private _capacitor;
    private _android;
    private _ios;
    busySubject: BehaviorSubject<boolean>;
    constructor(ionicPlatform: Platform, cdkPlatform: CdkPlatform, cdkClipboard: CdkClipboard, toastController: ToastController, translate: TranslateService, dateAdapter: MomentDateAdapter, entitiesStorage: EntitiesStorage, settings: LocalSettingsService, networkService: NetworkService, accountService: AccountService, configService: ConfigService, cache: CacheService, audioProvider: AudioProvider, environment: Environment, loggingService: ILoggingService, downloader: Downloader);
    private _downloadingJobs;
    private checkAppVersionTimer;
    is(platformName: Platforms): boolean;
    get mobile(): boolean;
    /**
     * Say if opened has been opened inside an Android or iOs App.
     * This is used to known if there is cordova features
     */
    isCapacitor(): boolean;
    /**
     * Say if opened has been opened inside an Android or iOs App.
     * This is used to known if there is cordova features
     */
    isCordova(): boolean;
    isAndroidCordova(): boolean;
    isIOSCordova(): boolean;
    isAndroid(): boolean;
    isIOS(): boolean;
    isMacOSDesktop(): boolean;
    /**
     * Is a native App (and NOT a mobile web)
     */
    isApp(): boolean;
    isWeb(): boolean;
    isMobileWeb(): boolean;
    get canDownload(): boolean;
    get canOpenFile(): boolean;
    width(): number;
    height(): number;
    protected ngOnStart(): Promise<any>;
    /**
     * Used to show a backdrop when platform is busy (e.g. from the app.component.ts)
     */
    markAsBusy(): void;
    markAsNotBusy(): void;
    open(url: string, opts?: Omit<OpenOptions, 'url'>): Promise<void>;
    getDownloadingJob(uri: string): Observable<string>;
    download(request: {
        uri: string;
        filename?: string;
    } & Partial<DownloadRequest>): Observable<string | undefined>;
    copyToClipboard(data: string | WriteOptions, opts?: ShowToastOptions): Promise<void>;
    toggleDarkTheme(enable: boolean): void;
    toggleHighContrast(enable: boolean): void;
    showToast(opts: ShowToastOptions): Promise<HTMLIonToastElement>;
    closeToast(id?: string): Promise<boolean>;
    protected configureTheme(mobile: boolean, win?: any): Promise<void>;
    protected configureCapacitorPlugins(): Promise<void>;
    protected configureTranslate(): void;
    protected applyLocale(locale: string): void;
    protected configureCache(online?: boolean): void;
    protected checkAppVersion(opts?: {
        canReload?: boolean;
        silent?: boolean;
    }): Promise<void>;
    protected onStartupError(err: any): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<PlatformService, [null, null, null, null, null, null, null, null, null, null, null, null, null, null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<PlatformService>;
}
