import { Observable } from 'rxjs';
import { InjectionToken } from '@angular/core';
import { Platform } from '@ionic/angular';
import { Entity, IEntity } from '../model/entity.model';
import { LoadResult } from '../../../shared/services/entity-service.class';
import { EntityStorageLoadOptions, EntityStore, EntityStoreTypePolicy } from './entity-store.class';
import { IProgressBarService } from '../../../shared/services/progress-bar.service';
import { Environment } from '../../../../environments/environment.class';
import { StartableService } from '../../../shared/services/startable-service.class';
import { IStorage } from '../../../shared/storage/storage.utils';
import * as i0 from "@angular/core";
export interface EntitiesStorageTypePolicies {
    [__typename: string]: EntityStoreTypePolicy;
}
export declare const APP_LOCAL_STORAGE_TYPE_POLICIES: InjectionToken<EntitiesStorageTypePolicies>;
declare interface EntityStorageMap {
    [key: string]: EntityStore<any, any>;
}
export declare class EntitiesStorage extends StartableService<EntityStorageMap> {
    private platform;
    private storage;
    protected environment: Environment;
    private progressBarService?;
    static readonly TRASH_PREFIX = "Trash#";
    static readonly REMOTE_PREFIX = "Remote#";
    private readonly _typePolicies;
    private readonly _saveTimerPeriod;
    private _$save;
    private _dirty;
    private _saving;
    get dirty(): boolean;
    constructor(platform: Platform, storage: IStorage, environment: Environment, progressBarService?: IProgressBarService, typePolicies?: EntitiesStorageTypePolicies);
    ngOnStart(): Promise<EntityStorageMap>;
    protected ngOnStop(): Promise<void>;
    watchAll<T extends Entity<T>>(entityName: string, variables: {
        offset?: number;
        size?: number;
        sortBy?: keyof T | string;
        sortDirection?: string;
        trash?: boolean;
        filter?: (data: T) => boolean;
    }, opts?: EntityStorageLoadOptions): Observable<LoadResult<T>>;
    loadAll<T extends Entity<T>>(entityName: string, variables?: {
        offset?: number;
        size?: number;
        sortBy?: keyof T | string;
        sortDirection?: string;
        filter?: (data: T) => boolean;
    }, opts?: EntityStorageLoadOptions): Promise<LoadResult<T>>;
    load<T extends Entity<T>>(id: number, entityName: string, opts?: EntityStorageLoadOptions): Promise<T>;
    nextValue(entityOrName: string | any): Promise<number>;
    nextValues(entityOrName: string | any, entityCount: number): Promise<number>;
    currentValue(entityOrName: string | any): Promise<number>;
    save<T extends Entity<T>>(entity: T, opts?: {
        entityName?: string;
        emitEvent?: boolean;
    }): Promise<T>;
    saveAll<T extends Entity<T>>(entities: T[], opts?: {
        entityName?: string;
        reset?: boolean;
        emitEvent?: boolean;
    }): Promise<T[]>;
    delete<T extends Entity<T, ID>, ID = number>(entity: T, opts?: {
        entityName?: string;
    }): Promise<T>;
    deleteById<T extends IEntity<T, ID>, ID = number>(id: ID, opts: {
        entityName: string;
        emitEvent?: boolean;
    }): Promise<T>;
    deleteMany<T extends Entity<T>>(ids: number[], opts: {
        entityName: string;
        emitEvent?: boolean;
    }): Promise<T[]>;
    deleteFromTrash<T extends Entity<T>>(entity: T, opts?: {
        entityName?: string;
    }): Promise<T>;
    deleteFromTrashById<T extends Entity<T>>(id: number, opts: {
        entityName: string;
        emitEvent?: boolean;
    }): Promise<T>;
    moveToTrash<T extends Entity<T>>(entity: T, opts?: {
        entityName?: string;
        emitEvent?: boolean;
    }): Promise<T>;
    moveManyToTrash<T extends Entity<T>>(ids: number[], opts: {
        entityName: string;
        emitEvent?: boolean;
    }): Promise<T[]>;
    saveToTrash<T extends Entity<T>>(entity: T, opts?: {
        entityName?: string;
        emitEvent?: boolean;
    }): Promise<T>;
    clearTrash(entityName: string): Promise<void>;
    persist(opts?: {
        skipIfPristine: boolean;
    }): Promise<void>;
    protected getEntityStore<T extends IEntity<T, ID>, ID = number>(name: string, opts?: {
        create?: boolean;
    }): EntityStore<T, ID>;
    protected detectEntityName(entityOrName: string | Entity<any, any>): string;
    protected restoreLocally(): Promise<void>;
    protected storeLocally(opts?: {
        skipIfPristine: boolean;
    }): Promise<void>;
    static ɵfac: i0.ɵɵFactoryDeclaration<EntitiesStorage, [null, null, null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<EntitiesStorage>;
}
export {};
