import { Observable } from 'rxjs';
import { Entity, IEntity } from '../model/entity.model';
import { LoadResult } from '../../../shared/services/entity-service.class';
import { IStorage } from '../../../shared/storage/storage.utils';
export declare const ENTITIES_STORAGE_KEY_PREFIX = "entities";
export type EntityStoreTypePolicyMode = 'default' | 'by-id';
export declare interface EntityStoreTypePolicy<T extends Entity<T, any> = Entity<any, any>, K = keyof T> {
    mode?: EntityStoreTypePolicyMode;
    skipNonLocalEntities?: boolean;
    lightFieldsExcludes?: K[];
}
export declare interface EntityStorageLoadOptions {
    fullLoad?: boolean;
}
export declare class EntityStore<T extends IEntity<T, ID>, ID = number, O extends EntityStorageLoadOptions = EntityStorageLoadOptions> {
    protected readonly name: string;
    protected readonly storage: IStorage;
    private readonly _storageKey;
    private readonly _onChange;
    private readonly _mapToLightEntity;
    private _cache;
    private _statusById;
    private _sequence;
    private _dirty;
    private _loaded;
    readonly policy: EntityStoreTypePolicy<T>;
    get length(): number;
    get cache(): T[];
    get dirty(): boolean;
    protected get isByIdMode(): boolean;
    protected get storageKeyById(): string;
    constructor(name: string, storage: IStorage, policy?: EntityStoreTypePolicy<T>);
    nextValue(): ID;
    currentValue(): number;
    load(id: ID, opts?: EntityStorageLoadOptions): Promise<T>;
    /**
     * Watch a set of entities
     *
     * @param variables
     * @param opts
     */
    watchAll(variables: {
        offset?: number;
        size?: number;
        sortBy?: keyof T | string;
        sortDirection?: string;
        filter?: (data: T) => boolean;
    }, opts?: O): Observable<LoadResult<T>>;
    /**
     * WIll apply a filter, then a sort, then a page slice
     *
     * @param variables
     * @param opts
     */
    loadAll(variables: {
        offset?: number;
        size?: number;
        sortBy?: keyof T | string;
        sortDirection?: string;
        filter?: (data: T) => boolean;
    }, opts?: O): Promise<LoadResult<T>>;
    save(entity: T, opts?: {
        emitEvent?: boolean;
    }): T;
    saveAll(entities: T[], opts?: {
        emitEvent?: boolean;
        reset?: boolean;
    }): T[];
    delete(id: ID, opts?: {
        emitEvent?: boolean;
    }): T | undefined;
    deleteMany(ids: ID[], opts?: {
        emitEvent?: boolean;
    }): T[];
    reset(opts?: {
        emitEvent?: boolean;
    }): void;
    /**
     *
     * @param opts
     *  opts.skipIfPristine = false persist all entities, even if not dirty
     */
    persist(opts?: {
        skipIfPristine: boolean;
    }): Promise<number>;
    restore(opts?: {
        emitEvent?: boolean;
    }): Promise<number>;
    markAsDirty(opts?: {
        emitEvent?: boolean;
    }): void;
    markAsPristine(opts?: {
        emitEvent?: boolean;
    }): void;
    private loadCachedEntity;
    private loadFullEntity;
    private setEntities;
    /**
     * WIll apply a filter, then a sort, then a page slice
     *
     * @param data
     * @param variables
     */
    private reduceAndSort;
    private createLightEntityMapFn;
    /**
     * Update the entitiesSubject.
     *
     * Before wending items, a filter is apply, to remove null value.
     * This filter will create a array copy.
     */
    private emitEvent;
}
