import { ChangeDetectorRef, InjectionToken, Injector, OnDestroy, OnInit } from '@angular/core';
import { AccountService } from '../services/account.service';
import { LocaleConfig, LocalSettings, UsageMode } from '../services/model/settings.model';
import { UntypedFormArray, UntypedFormBuilder } from '@angular/forms';
import { AppForm } from '../form/form.class';
import { CanLeave } from '../form/form.utils';
import { TranslateService } from '@ngx-translate/core';
import { LocalSettingsValidatorService } from '../services/validator/local-settings.validator';
import { PlatformService } from '../services/platform.service';
import { NetworkService } from '../services/network.service';
import { LocalSettingsService } from '../services/local-settings.service';
import { FormFieldDefinition } from '../../shared/form/field.model';
import { AlertController, NavController } from '@ionic/angular';
import { ISelectPeerModalOptions } from '../peer/select-peer.modal';
import { IMenuItem } from '../menu/menu.model';
import { AppPropertiesForm } from '../form/properties/properties.form';
import * as i0 from "@angular/core";
export declare const APP_SETTINGS_MENU_ITEMS: InjectionToken<IMenuItem[]>;
export declare class SettingsPage extends AppForm<LocalSettings> implements OnInit, OnDestroy, CanLeave {
    protected platform: PlatformService;
    protected navController: NavController;
    protected validatorService: LocalSettingsValidatorService;
    protected alertCtrl: AlertController;
    protected translate: TranslateService;
    protected formBuilder: UntypedFormBuilder;
    protected accountService: AccountService;
    protected settings: LocalSettingsService;
    protected cd: ChangeDetectorRef;
    network: NetworkService;
    locales: LocaleConfig[];
    private data;
    protected mobile: boolean;
    protected isAdmin: boolean;
    protected saving: boolean;
    protected usageModes: UsageMode[];
    protected menuItems: IMenuItem[];
    protected showOptionKeys: boolean;
    protected propertyDefinitions: FormFieldDefinition[];
    protected latLongFormats: string[];
    get accountInheritance(): boolean;
    get isLogin(): boolean;
    get propertiesFormArray(): UntypedFormArray;
    get darkMode(): boolean;
    set darkMode(value: boolean);
    propertiesForm: AppPropertiesForm;
    constructor(injector: Injector, platform: PlatformService, navController: NavController, validatorService: LocalSettingsValidatorService, alertCtrl: AlertController, translate: TranslateService, formBuilder: UntypedFormBuilder, accountService: AccountService, settings: LocalSettingsService, cd: ChangeDetectorRef, network: NetworkService, locales: LocaleConfig[], menuItems?: IMenuItem[]);
    ngOnInit(): Promise<void>;
    protected loadPropertyDefinitions(): void;
    load(): Promise<void>;
    updateView(data: LocalSettings): Promise<void>;
    save(event?: Event, options?: any): Promise<boolean>;
    setAccountInheritance(enable: boolean, opts?: {
        emitEvent?: boolean;
    }): void;
    showSelectPeerModal(opts?: Partial<ISelectPeerModalOptions>): Promise<void>;
    protected setForceOffline(value: boolean): void;
    cancel(event?: Event): Promise<void>;
    close(_?: Event): Promise<boolean>;
    clearCache(event?: Event): Promise<void>;
    executeAction(event: Event, item: IMenuItem): Promise<void>;
    getValue(): Promise<LocalSettings>;
    markAsLoading(): void;
    markAsLoaded(opts?: {
        emitEvent?: boolean;
    }): void;
    get loading(): boolean;
    get loaded(): boolean;
    enable(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    disable(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    markAsPristine(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    handleRefresh(event: BeforeUnloadEvent): void;
    protected openAccountPage(): Promise<boolean>;
    protected toggleDarkMode(enable?: boolean): Promise<void>;
    protected toggleShowOptionKeys(): void;
    protected devToggleDebug(): void;
    protected markForCheck(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SettingsPage, [null, null, null, null, null, null, null, null, null, null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SettingsPage, "page-settings", never, {}, {}, never, never, false, never>;
}
