import { AsyncTableDataSource, AsyncTableElement, TableDataSourceConfig, ValidatorService } from '@e-is/ngx-material-table';
import { BehaviorSubject, Observable, Subject } from 'rxjs';
import { IEntity } from '../services/model/entity.model';
import { OnDestroy } from '@angular/core';
import { SortDirection } from '@angular/material/sort';
import { CollectionViewer } from '@angular/cdk/collections';
import { EntitiesServiceWatchOptions, FetchMoreFn, IEntitiesService, LoadResult } from '../../shared/services/entity-service.class';
import { FirstOptions } from '../../shared/observables';
import { IEntitiesTableDataSource } from './table.model';
import * as i0 from "@angular/core";
export interface EntitiesAsyncTableDataSourceConfig<T extends IEntity<T, ID>, ID = number, WO extends EntitiesServiceWatchOptions = EntitiesServiceWatchOptions, SO = any> extends TableDataSourceConfig {
    onRowCreated?: (row: AsyncTableElement<T>) => Promise<void> | void;
    saveOnlyDirtyRows?: boolean;
    readOnly?: boolean;
    /**
     * @deprecated
     */
    dataServiceOptions?: WO & SO;
    watchAllOptions?: WO;
    saveAllOptions?: SO;
    [key: string]: any;
}
export declare class EntitiesAsyncTableDataSource<T extends IEntity<T, ID>, F = any, ID = number, WO extends EntitiesServiceWatchOptions = EntitiesServiceWatchOptions, SO = any, V extends ValidatorService = ValidatorService, C extends EntitiesAsyncTableDataSourceConfig<T, ID, WO, SO> = EntitiesAsyncTableDataSourceConfig<T, ID, WO, SO>, R extends AsyncTableElement<T> = AsyncTableElement<T>> extends AsyncTableDataSource<T, V, C, R> implements IEntitiesTableDataSource<R>, OnDestroy {
    readonly dataService: IEntitiesService<T, F, WO>;
    private readonly _entityName;
    protected _debug: boolean;
    protected _creating: boolean;
    protected _saving: boolean;
    protected _fetchMoreFn: FetchMoreFn<LoadResult<T>>;
    protected _waitingNetworkResult: boolean;
    protected _stopWatchSubject: Subject<void>;
    loadingSubject: BehaviorSubject<boolean>;
    get watchAllOptions(): WO;
    set watchAllOptions(value: WO);
    get saveAllOptions(): SO;
    set saveAllOptions(value: SO);
    get loaded(): boolean;
    get loading(): boolean;
    /**
     * Creates a new TableDataSource instance, that can be used as datasource of `@angular/cdk` data-table.
     *
     * @param dataService A service to load and save data
     * @param dataType Type of data contained by the Table. If not specified, then `data` with at least one element must be specified.
     * @param validatorService Service that create instances of the FormGroup used to validate row fields.
     * @param options Additional options
     */
    constructor(dataType: new () => T, dataService: IEntitiesService<T, F, WO>, validatorService?: V, options?: C);
    ngOnDestroy(): void;
    watchAll(offset: number, size: number, sortBy?: string, sortDirection?: SortDirection, filter?: Partial<F>): Observable<LoadResult<T>>;
    protected updateDatasourceFromRows(rows: R[]): void;
    save(): Promise<boolean>;
    updateDatasource(data: T[], opts?: {
        emitEvent: boolean;
    }): void;
    connect(collectionViewer: CollectionViewer): Observable<R[] | ReadonlyArray<R>>;
    /**
     * Disconnects the data source, cleaning up any resources and subscriptions.
     *
     * @param {CollectionViewer} [collectionViewer] - Optional parameter representing the collection viewer to disconnect from.
     * @return {void} - This method does not return a value.
     */
    disconnect(collectionViewer?: CollectionViewer): void;
    /**
     * Waits for the idle state based on the provided options.
     *
     * @param {number | { debounceTimeMs?: number } & FirstOptions} [opts] Options for controlling the wait behavior.
     *   - If a number is provided, it is treated as the debounce time in milliseconds.
     *   - If an object is provided, it can include the following properties:
     *     - debounceTimeMs: The debounce time in milliseconds. Defaults to 100 if not specified.
     *     - Additional options from `FirstOptions` interface.
     * @return {Promise<any>} A Promise that resolves when the idle state is reached.
     */
    waitIdle(opts?: number | ({
        debounceTimeMs?: number;
    } & FirstOptions)): Promise<any>;
    confirmCreate(row: R): Promise<boolean>;
    confirmEdit(row: R): Promise<boolean>;
    startEdit(row: R): Promise<boolean>;
    handleError(error: any, message: string): Observable<LoadResult<T>>;
    handleServiceError(error: any): void;
    delete(id: number): Promise<boolean>;
    deleteAll(rows: R[]): Promise<any>;
    getRow(id: number): R;
    getRows(): R[];
    getEditingRows(): R[];
    getSingleEditingRow(): R;
    hasSomeEditingRow(): boolean;
    hasSomeDirtyRow(): boolean;
    createNew(insertAt?: number, opts?: {
        editing: boolean;
    }): Promise<R | undefined>;
    getData(): T[];
    fetchMore(opts?: {
        emitEvent: boolean;
    }): Promise<boolean>;
    markAsLoading(): void;
    markAsLoaded(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<EntitiesAsyncTableDataSource<any, any, any, any, any, any, any, any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<EntitiesAsyncTableDataSource<any, any, any, any, any, any, any, any>, never, never, {}, {}, never, never, false, never>;
}
