import { AfterViewInit, ChangeDetectorRef, EventEmitter, Injector, OnDestroy, OnInit } from '@angular/core';
import { MatSort, MatSortable, SortDirection } from '@angular/material/sort';
import { BehaviorSubject, Observable, Subject, Subscription } from 'rxjs';
import { TableElement } from '@e-is/ngx-material-table';
import { EntitiesTableDataSource } from './entities-table-datasource.class';
import { SelectionModel } from '@angular/cdk/collections';
import { IEntity } from '../services/model/entity.model';
import { AlertController, ModalController, NavController, ToastController } from '@ionic/angular';
import { ActivatedRoute, Router } from '@angular/router';
import { ColumnItem } from './table-select-columns.component';
import { Location } from '@angular/common';
import { CanSave, IAppForm } from '../form/form.utils';
import { LocalSettingsService } from '../services/local-settings.service';
import { TranslateService } from '@ngx-translate/core';
import { MatAutocompleteConfigHolder, MatAutocompleteFieldAddOptions, MatAutocompleteFieldConfig } from '../../shared/material/autocomplete/material.autocomplete.config';
import { CompletableEvent } from '../../shared/events';
import { WaitForOptions } from '../../shared/observables';
import { ShowToastOptions } from '../../shared/toast/toasts';
import { CdkColumnDef } from '@angular/cdk/table';
import { LoadResult } from '../../shared/services/entity-service.class';
import { FormErrorTranslateOptions, FormErrorTranslator, IFormPathTranslator } from '../../shared/validator/form-error-adapter.class';
import { SaveActionType } from './table.model';
import { MatPaginator } from '@angular/material/paginator';
import { MatTable } from '@angular/material/table';
import * as i0 from "@angular/core";
export declare abstract class AppTable<T extends IEntity<T, ID>, F = any, ID = number> implements OnInit, OnDestroy, AfterViewInit, IAppForm, CanSave, IFormPathTranslator {
    protected columns: string[];
    protected _dataSource?: EntitiesTableDataSource<T, F, ID>;
    private _filter?;
    private _initialized;
    private _openingRow;
    private _subscription;
    private _dataSourceLoadingSubscription;
    private _cellValueChangesDefs;
    protected _enabled: boolean;
    protected _autocompleteConfigHolder: MatAutocompleteConfigHolder;
    protected allowRowDetail: boolean;
    protected readonly cd: ChangeDetectorRef;
    protected route: ActivatedRoute;
    protected router: Router;
    protected navController: NavController;
    protected location: Location;
    protected settings: LocalSettingsService;
    protected translate: TranslateService;
    protected modalCtrl: ModalController;
    protected alertCtrl: AlertController;
    protected toastController: ToastController;
    protected previouslyEditedRowId: number;
    protected formErrorAdapter: FormErrorTranslator;
    protected readonly destroySubject: Subject<void>;
    excludesColumns: string[];
    displayedColumns: string[];
    totalRowCount: number | null;
    visibleRowCount: number;
    errorTranslateOptions: FormErrorTranslateOptions;
    readonly readySubject: BehaviorSubject<boolean>;
    readonly loadingSubject: BehaviorSubject<boolean>;
    readonly savingSubject: BehaviorSubject<boolean>;
    readonly touchedSubject: BehaviorSubject<boolean>;
    readonly dirtySubject: BehaviorSubject<boolean>;
    readonly errorSubject: BehaviorSubject<string>;
    get error(): string;
    set error(error: string);
    /**
     * @deprecated
     */
    get error$(): Observable<string>;
    selection: SelectionModel<TableElement<T>>;
    permanentSelection: SelectionModel<T>;
    permanentSelectionChangedPrevented: boolean;
    editedRow: TableElement<T>;
    autocompleteFields: {
        [key: string]: MatAutocompleteFieldConfig;
    };
    readonly mobile: boolean;
    settingsId: string;
    debug: boolean;
    i18nColumnPrefix: string;
    i18nColumnSuffix: string;
    autoLoad: boolean;
    readOnly: boolean;
    inlineEdition: boolean;
    focusFirstColumn: boolean;
    confirmBeforeDelete: boolean;
    confirmBeforeCancel: boolean;
    undoableDeletion: boolean;
    saveBeforeDelete: boolean;
    keepEditedRowOnSave: boolean;
    saveBeforeSort: boolean;
    saveBeforeFilter: boolean;
    propagateRowError: boolean;
    permanentSelectionAllowed: boolean;
    openRowThrottleTime: number;
    defaultSortBy: string;
    defaultSortDirection: SortDirection;
    defaultPageSize: number;
    defaultPageSizeOptions: number[];
    focusColumn: string;
    get firstUserColumn(): string;
    get lastUserColumn(): string;
    set dataSource(value: EntitiesTableDataSource<T, F, ID>);
    get dataSource(): EntitiesTableDataSource<T, F, ID>;
    set filter(value: F);
    get filter(): F;
    get empty(): boolean;
    get selectedEntities(): T[];
    onRefresh: EventEmitter<any>;
    onClickRow: EventEmitter<TableElement<T>>;
    onOpenRow: EventEmitter<TableElement<T>>;
    onNewRow: EventEmitter<any>;
    onStartEditingRow: EventEmitter<TableElement<T>>;
    onConfirmEditCreateRow: EventEmitter<TableElement<T>>;
    onCancelOrDeleteRow: EventEmitter<TableElement<T>>;
    onBeforeDeleteRows: EventEmitter<import("../../shared/events").PromiseEvent<boolean, {
        rows: TableElement<T>[];
    }>>;
    onBeforeCancelRows: EventEmitter<import("../../shared/events").PromiseEvent<boolean, {
        rows: TableElement<T>[];
    }>>;
    onBeforeSave: EventEmitter<import("../../shared/events").PromiseEvent<{
        confirmed: boolean;
        save: boolean;
    }, {
        action: SaveActionType;
        valid: boolean;
    }>>;
    onAfterDeletedRows: EventEmitter<TableElement<T>[]>;
    onSort: EventEmitter<any>;
    onDirty: EventEmitter<boolean>;
    onError: EventEmitter<string>;
    get dirty(): boolean;
    get valid(): boolean;
    get invalid(): boolean;
    get pending(): boolean;
    get touched(): boolean;
    get untouched(): boolean;
    disable(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    enable(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    get enabled(): boolean;
    set disabled(value: boolean);
    get disabled(): boolean;
    markAsDirty(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    markAsPristine(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    markAsUntouched(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    /**
     * @deprecated prefer to use markAllAsTouched()
     * @param opts
     */
    markAsTouched(opts?: {
        onlySelf?: boolean;
        emitEvent?: boolean;
    }): void;
    markAllAsTouched(opts?: {
        emitEvent?: boolean;
    }): void;
    markAsSaving(opts?: {
        emitEvent?: boolean;
    }): void;
    markAsSaved(opts?: {
        emitEvent?: boolean;
    }): void;
    markAsLoading(opts?: {
        emitEvent?: boolean;
    }): void;
    markAsLoaded(opts?: {
        emitEvent?: boolean;
    }): void;
    markAsReady(opts?: {
        emitEvent?: boolean;
    }): void;
    get loading(): boolean;
    get loaded(): boolean;
    enableSort(): void;
    disableSort(): void;
    set pageSize(value: number);
    get pageSize(): number;
    get pageOffset(): number;
    get sortActive(): string;
    set sortActive(sortBy: string);
    get sortDirection(): SortDirection;
    set sortDirection(value: SortDirection);
    private _paginator;
    set paginator(value: MatPaginator);
    get paginator(): MatPaginator;
    get destroyed(): boolean;
    table: MatTable<T>;
    childPaginator: MatPaginator;
    sort: MatSort;
    protected constructor(injector: Injector, columns: string[], _dataSource?: EntitiesTableDataSource<T, F, ID>, _filter?: F);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    updateView(res: LoadResult<T> | undefined, opts?: {
        emitEvent?: boolean;
    }): Promise<void>;
    setDatasource(datasource: EntitiesTableDataSource<T, F, ID>): void;
    resetDataSource(): void;
    addColumnDef(column: CdkColumnDef): void;
    removeColumnDef(column: CdkColumnDef): void;
    setFilter(filter: F, opts?: {
        emitEvent?: boolean;
        permanentSelectionChangedPrevented?: boolean;
    }): void;
    confirmAndAdd(event?: Event, row?: TableElement<T>): Promise<boolean>;
    confirmAndBackward(event?: Event, row?: TableElement<T>): boolean | Promise<boolean>;
    confirmAndForward(event?: Event, row?: TableElement<T>): boolean | Promise<boolean>;
    /**
     * Confirm the creation of the given row, or if not specified the currently edited row
     *
     * @param event
     * @param row
     */
    confirmEditCreate(event?: Event, row?: TableElement<T>): boolean;
    cancelOrDelete(event: Event, row: TableElement<T>, opts?: {
        interactive?: boolean;
        keepEditing?: boolean;
    }): void;
    addRow(event?: Event, insertAt?: number, opts?: {
        focusColumn?: string;
        editing?: boolean;
    }): Promise<boolean>;
    save(opts?: {
        keepEditing?: boolean;
    }): Promise<boolean>;
    cancel(event?: Event, opts?: {
        interactive?: boolean;
    }): void;
    duplicateRow(event?: Event, row?: TableElement<T>, opts?: {
        includedProperties?: string[];
        excludedProperties?: string[];
    }): Promise<boolean>;
    /** Whether the number of selected elements matches the total number of rows. */
    isAllSelected(): boolean;
    /** Selects all rows if they are not all selected; otherwise clear selection. */
    masterToggle(): Promise<void>;
    deleteSelection(event: Event, opts?: {
        interactive?: boolean;
    }): Promise<number>;
    /**
     *
     * @param event
     * @param row
     * @param opts Use interactive=false to avoid user interaction (e.g. user confirmation)
     *  And to force deletion even if table is busy
     */
    deleteRow(event: Event | null, row: TableElement<T>, opts?: {
        interactive?: boolean;
    }): Promise<boolean>;
    /**
     *
     * @param event
     * @param rows
     * @param opts Use interactive=false to avoid user interaction (e.g. user confirmation)
     *    And to force deletion even if table is busy
     */
    deleteRows(event: Event | null, rows: TableElement<T>[], opts?: {
        interactive?: boolean;
    }): Promise<number>;
    selectRowById(id: number): Promise<boolean>;
    /**
     * Try to select row by data. Will use equals() to find same row's data
     *
     * @param data
     */
    selectRowByData(data: T): Promise<boolean>;
    toggleSelectRow(event: Event | undefined, row: TableElement<T>): void;
    clickRow(event: Event | undefined, row: TableElement<T>): boolean;
    moveRow(id: number, direction: number): void;
    ready(opts?: WaitForOptions): Promise<void>;
    waitIdle(opts?: WaitForOptions): Promise<void>;
    openSelectColumnsModal(event?: Event): Promise<any>;
    trackByFn(index: number, row: TableElement<T>): any;
    doRefresh(event?: CompletableEvent): void;
    getCurrentColumns(): ColumnItem[];
    escapeEditingRow(event?: Event, row?: TableElement<T>): void;
    translateFormPath(path: string): string;
    protected editRow(event: Event | undefined, row: TableElement<T>, opts?: {
        focusColumn?: string;
    }): boolean;
    /**
     * Try to select row, by row.id, or by data. WIll use EntityUtils.equals()
     *
     * @param id
     * @param data
     * @protected
     */
    protected selectRowByIdOrData(id: number, data?: T): Promise<boolean>;
    /**
     * return the selected row if unique in selection
     */
    protected get singleSelectedRow(): TableElement<T>;
    protected canDeleteRows(rows: TableElement<T>[], opts?: {
        interactive?: boolean;
    }): Promise<boolean>;
    protected canCancelRows(rows?: TableElement<T>[], opts?: {
        interactive?: boolean;
    }): Promise<boolean>;
    protected saveBeforeAction(saveAction: SaveActionType): Promise<boolean>;
    /**
     * Open a row detail view. By default, will to open row detail page.
     * Can be overridden by subclasses, BUT prefer to subscribe on onOpenRow
     *
     * @param id
     * @param row
     * @protected
     */
    protected openRow(id: ID, row: TableElement<T>): Promise<boolean>;
    protected openNewRowDetail(event?: any): Promise<boolean>;
    protected getRequiredColumns(): string[];
    protected getUserColumns(): string[];
    protected getSortedColumn(): MatSortable;
    protected getPageSize(): number;
    protected getDisplayColumns(): string[];
    /**
     * Recompute display columns
     *
     * @protected
     */
    protected updateColumns(): void;
    protected registerSubscription(sub: Subscription): void;
    protected unregisterSubscription(sub: Subscription): void;
    protected registerAutocompleteField<E = any, EF = any>(fieldName: string, options?: MatAutocompleteFieldAddOptions<E, EF>): MatAutocompleteFieldConfig<E, EF>;
    protected getI18nColumnName(columnName: string): string;
    protected generateTableId(): string;
    protected addRowToTable(insertAt?: number, opts?: {
        focusColumn?: string;
        editing?: boolean;
        emitEvent?: boolean;
    }): Promise<TableElement<T> | undefined>;
    protected registerCellValueChanges(name: string, formPath?: string, emitInitialValue?: boolean): Observable<any>;
    protected setShowColumn(columnName: string, show: boolean, opts?: {
        emitEvent?: boolean;
    }): void;
    protected getShowColumn(columnName: string): boolean;
    protected startsWithUpperCase(input: string, search: string): boolean;
    protected markForCheck(): void;
    protected detectChanges(): void;
    protected askDeleteConfirmation(event?: Event, rows?: TableElement<T>[]): Promise<boolean>;
    protected askCancelConfirmation(event?: Event, rows?: TableElement<T>[]): Promise<boolean>;
    protected askRestoreConfirmation(event?: Event): Promise<boolean>;
    protected showToast(opts: ShowToastOptions): Promise<import("@ionic/core").OverlayEventDetail<any>>;
    protected resetError(opts?: {
        emitEvent?: boolean;
    }): void;
    protected getRowError(row?: TableElement<T>, opts?: FormErrorTranslateOptions): string;
    protected setError(value: string, opts?: {
        emitEvent?: boolean;
    }): void;
    /**
     * Compare data equality (default by id, using EntityUtils.equals())
     * Can be overridden to add additional properties to compare
     *
     * @param d1
     * @param d2
     * @protected
     */
    protected equals(d1: T, d2: T): boolean;
    protected markRowAsDirty(row?: TableElement<T>, opts?: {
        onlySelf?: boolean;
        emitEVent?: boolean;
    }): void;
    protected getPageSettings<T = any>(propertyName?: string): T;
    protected savePageSettings(value: any, propertyName?: string): Promise<void>;
    protected emitRefresh(value?: any): void;
    /**
     * Initialize the permanent selection model
     *
     * @protected
     */
    protected initPermanentSelection(): void;
    private listenSortAndPaginationEvents;
    private editRowById;
    private setLoading;
    private deleteNewRow;
    private deleteExistingRow;
    private cancelExistingRow;
    private checkIfRowPristine;
    private checkIfPristine;
    private applyFilter;
    private listenDataSourceLoading;
    private startCellValueChanges;
    private stopCellValueChanges;
    static ɵfac: i0.ɵɵFactoryDeclaration<AppTable<any, any, any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<AppTable<any, any, any>, never, never, { "settingsId": { "alias": "settingsId"; "required": false; }; "debug": { "alias": "debug"; "required": false; }; "i18nColumnPrefix": { "alias": "i18nColumnPrefix"; "required": false; }; "i18nColumnSuffix": { "alias": "i18nColumnSuffix"; "required": false; }; "autoLoad": { "alias": "autoLoad"; "required": false; }; "readOnly": { "alias": "readOnly"; "required": false; }; "inlineEdition": { "alias": "inlineEdition"; "required": false; }; "focusFirstColumn": { "alias": "focusFirstColumn"; "required": false; }; "confirmBeforeDelete": { "alias": "confirmBeforeDelete"; "required": false; }; "confirmBeforeCancel": { "alias": "confirmBeforeCancel"; "required": false; }; "undoableDeletion": { "alias": "undoableDeletion"; "required": false; }; "saveBeforeDelete": { "alias": "saveBeforeDelete"; "required": false; }; "keepEditedRowOnSave": { "alias": "keepEditedRowOnSave"; "required": false; }; "saveBeforeSort": { "alias": "saveBeforeSort"; "required": false; }; "saveBeforeFilter": { "alias": "saveBeforeFilter"; "required": false; }; "propagateRowError": { "alias": "propagateRowError"; "required": false; }; "permanentSelectionAllowed": { "alias": "permanentSelectionAllowed"; "required": false; }; "openRowThrottleTime": { "alias": "openRowThrottleTime"; "required": false; }; "defaultSortBy": { "alias": "defaultSortBy"; "required": false; }; "defaultSortDirection": { "alias": "defaultSortDirection"; "required": false; }; "defaultPageSize": { "alias": "defaultPageSize"; "required": false; }; "defaultPageSizeOptions": { "alias": "defaultPageSizeOptions"; "required": false; }; "focusColumn": { "alias": "focusColumn"; "required": false; }; "dataSource": { "alias": "dataSource"; "required": false; }; "filter": { "alias": "filter"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "paginator": { "alias": "paginator"; "required": false; }; }, { "onRefresh": "onRefresh"; "onClickRow": "onClickRow"; "onOpenRow": "onOpenRow"; "onNewRow": "onNewRow"; "onStartEditingRow": "onStartEditingRow"; "onConfirmEditCreateRow": "onConfirmEditCreateRow"; "onCancelOrDeleteRow": "onCancelOrDeleteRow"; "onBeforeDeleteRows": "onBeforeDeleteRows"; "onBeforeCancelRows": "onBeforeCancelRows"; "onBeforeSave": "onBeforeSave"; "onAfterDeletedRows": "onAfterDeletedRows"; "onSort": "onSort"; "onDirty": "onDirty"; "onError": "onError"; }, never, never, false, never>;
}
