import * as momentImported from 'moment';
import { Duration, DurationInputArg1, DurationInputArg2, Moment, MomentFormatSpecification, MomentInput, unitOfTime } from 'moment/moment';
declare type MomentFn = {
    (inp?: MomentInput, strict?: boolean): Moment;
    (inp?: MomentInput, format?: MomentFormatSpecification, strict?: boolean): Moment;
    (inp?: MomentInput, format?: MomentFormatSpecification, language?: string, strict?: boolean): Moment;
    duration: (inp?: DurationInputArg1, unit?: DurationInputArg2) => Duration;
};
export declare const DATE_UNIX_TIMESTAMP = "X";
export declare const DATE_UNIX_MS_TIMESTAMP = "x";
export declare const MOMENT_NO_TIME_PROPERTY = "_hasNoTime";
export declare class DateUtils {
    static moment: MomentFn;
    static toDateISOString: typeof toDateISOString;
    static fromDateISOString: typeof fromDateISOString;
    static toDuration: typeof toDuration;
    static min(date1: Moment, date2: Moment): Moment;
    static max(date1: Moment | string, date2: Moment | string): Moment;
    static equals(date1: Moment | string, date2: Moment | string): boolean;
    static isSame(date1: Moment | string, date2: Moment | string, granularity?: unitOfTime.StartOf): boolean;
    static compare(date1: Moment | string, date2: Moment | string, granularity?: unitOfTime.StartOf): number;
    /**
     * Calculates the absolute difference between two dates in the specified units.
     *
     * @param {Moment | string} date1 - The first date to compare.
     * @param {Moment | string} date2 - The second date to compare.
     * @param {unitOfTime.Base} [durationUnit='seconds'] - The unit of time to express the difference in (default is 'seconds').
     * @return {number} The absolute difference between the two dates expressed in the specified units.
     */
    static diffAbs(date1: Moment | string, date2: Moment | string, durationUnit?: unitOfTime.Base): number;
    /**
     * Create a copy of a date, without time fields (always return a new Moment object, or undefined).
     * Same implementation as the Java class Dates.resetTime() (see any SUMARiS like Pod)
     *
     * @param value
     * @param timezone a timezone (see https://momentjs.com/timezone/)
     * @param keepLocalTime if true, only the timezone (and offset) is updated, keeping the local time same. Consequently, it will now point to a different point in time if the offset has changed.
     */
    static resetTime(value: Moment | string, timezone?: string, keepLocalTime?: boolean): Moment | undefined;
    static markNoTime(value: Moment): Moment | undefined;
    static markTime(value: Moment): Moment | undefined;
    static isNoTime(value: Moment): boolean;
    /**
     * Test if a date is on the given day of week
     *
     * @param date
     * @param weekday
     * @param timezone
     */
    static isAtDay(date: string | Moment, weekday: number, timezone?: string): boolean;
    static durationToString(value: number, dayUnit: string, opts?: unitOfTime.DurationConstructor | {
        unit?: unitOfTime.DurationConstructor;
        seconds?: boolean;
    } | any): string;
}
export declare function toDateISOString(value: any): string | undefined;
export declare function fromDateISOString(value: any): Moment | undefined;
export declare function fromUnixTimestamp(timeInSec: number): momentImported.Moment;
export declare function fromUnixMsTimestamp(timeInMs: number): momentImported.Moment;
export declare function toDuration(value: number, unit?: unitOfTime.DurationConstructor): Duration | undefined;
export {};
