import { EventEmitter } from '@angular/core';
import { Observable } from 'rxjs';
export interface PromiseEventPayload<R = any> {
    success: (value?: R) => void;
    error: (reason?: any) => void;
}
export type PromiseEvent<R = any, D = void> = CustomEvent<PromiseEventPayload<R> & D>;
export declare function createPromiseEventEmitter<R = any, D = void>(): EventEmitter<PromiseEvent<R, D>>;
export declare function createPromiseEvent<T = void, D = void>(eventType: string, promise: PromiseEventPayload<T>, initArg?: CustomEventInit<D>): PromiseEvent<T, D>;
export declare function emitPromiseEvent<R = any, D = void>(emitter: EventEmitter<PromiseEvent<R, D>>, eventType: string, initArg?: CustomEventInit<D>): Promise<R>;
export interface CompletableEvent extends Event {
    target: EventTarget & {
        complete?: () => void;
    };
}
/**
 * Listen end of scroll.
 * <p>
 *   The threshold distance from the bottom of the content to call the infinite output event when scrolled.
 *   The threshold value can be either a percent, or in pixels.
 *   For example, use the value of 10% for the infinite output event to get called when the user has scrolled
 *   10% from the bottom of the page. Use the value 100px when the scroll is within 100 pixels from the bottom of the page.
 * </p>
 *
 * @param element
 * @param threshold default to '15%'
 * @param dueTime
 */
export declare function fromScrollEndEvent(element: HTMLElement, threshold?: string, dueTime?: number): Observable<any>;
