import { ChangeDetectorRef, ElementRef, EventEmitter, Injector, OnInit } from '@angular/core';
import { ControlValueAccessor, FormGroupDirective, UntypedFormControl } from '@angular/forms';
import { AppFloatLabelType, DisplayFn, FormFieldDefinition, FormFieldType } from './field.model';
import { TranslateService } from '@ngx-translate/core';
import { filterNumberInput, selectInputContentFromEvent } from '../inputs';
import { Property } from '../types';
import { ThemePalette } from '@angular/material/core';
import { PredefinedColors } from '@ionic/core';
import { MatAutocompleteField } from '../material/autocomplete/material.autocomplete';
import { MatFormFieldAppearance, SubscriptSizing } from '@angular/material/form-field';
import * as i0 from "@angular/core";
export declare class AppFormField implements OnInit, ControlValueAccessor {
    protected translate: TranslateService;
    protected cd: ChangeDetectorRef;
    protected injector: Injector;
    private formGroupDir;
    private _onChangeCallback;
    private _onTouchedCallback;
    private _definition;
    protected _values: Property[];
    protected type: FormFieldType;
    protected numberInputStep: string;
    set definition(value: FormFieldDefinition);
    get definition(): FormFieldDefinition;
    readonly: boolean;
    disabled: boolean;
    formControl: UntypedFormControl;
    formControlName: string;
    placeholder: string;
    compact: boolean;
    required: boolean;
    hideRequiredMarker: boolean;
    floatLabel: AppFloatLabelType;
    label: string;
    appearance: MatFormFieldAppearance;
    subscriptSizing: SubscriptSizing;
    tabindex: number;
    autofocus: boolean;
    clearable: boolean;
    chipColor: ThemePalette | PredefinedColors;
    classList: string;
    debug: boolean;
    panelClass: string;
    panelWidth: string;
    onKeyupEnter: EventEmitter<any>;
    get value(): any;
    matInput: ElementRef;
    autocompleteField: MatAutocompleteField;
    constructor(translate: TranslateService, cd: ChangeDetectorRef, injector: Injector, formGroupDir: FormGroupDirective);
    ngOnInit(): void;
    writeValue(obj: any): void;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    setDisabledState(isDisabled: boolean): void;
    markAsTouched(): void;
    filterAlphanumericalInput(event: KeyboardEvent): void;
    focus(): void;
    filterNumberInput: typeof filterNumberInput;
    selectInputContentFromEvent: typeof selectInputContentFromEvent;
    getDisplayValueFn(definition: FormFieldDefinition): DisplayFn;
    getColorContrast(color: string): string | undefined;
    /**
     * Allow to reload values, if not detected
     *
     * @param value
     */
    reloadItems(value?: any): void;
    protected computeNumberInputStep(definition: FormFieldDefinition): string;
    protected checkAndResolveFormControl(): void;
    protected _onDefinitionChanged(definition: FormFieldDefinition, opts?: {
        emitEvent?: boolean;
    }): void;
    protected updateTabIndex(timeout?: number): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AppFormField, [null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AppFormField, "app-form-field", never, { "definition": { "alias": "definition"; "required": false; }; "readonly": { "alias": "readonly"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "formControl": { "alias": "formControl"; "required": false; }; "formControlName": { "alias": "formControlName"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "compact": { "alias": "compact"; "required": false; }; "required": { "alias": "required"; "required": false; }; "hideRequiredMarker": { "alias": "hideRequiredMarker"; "required": false; }; "floatLabel": { "alias": "floatLabel"; "required": false; }; "label": { "alias": "label"; "required": false; }; "appearance": { "alias": "appearance"; "required": false; }; "subscriptSizing": { "alias": "subscriptSizing"; "required": false; }; "tabindex": { "alias": "tabindex"; "required": false; }; "autofocus": { "alias": "autofocus"; "required": false; }; "clearable": { "alias": "clearable"; "required": false; }; "chipColor": { "alias": "chipColor"; "required": false; }; "classList": { "alias": "class"; "required": false; }; "debug": { "alias": "debug"; "required": false; }; "panelClass": { "alias": "panelClass"; "required": false; }; "panelWidth": { "alias": "panelWidth"; "required": false; }; }, { "onKeyupEnter": "keyup.enter"; }, never, ["[matSuffix]", "[matSuffix]", "[matSuffix]", "[matSuffix]", "[matSuffix]", "[matSuffix]", "[matPrefix]", "[matSuffix]", "[matSuffix]", "[matPrefix]", "[matSuffix]", "[matPrefix]", "[matSuffix]", "[matSuffix]"], false, never>;
    static ngAcceptInputType_readonly: unknown;
    static ngAcceptInputType_disabled: unknown;
    static ngAcceptInputType_compact: unknown;
    static ngAcceptInputType_required: unknown;
    static ngAcceptInputType_hideRequiredMarker: unknown;
    static ngAcceptInputType_tabindex: unknown;
    static ngAcceptInputType_autofocus: unknown;
    static ngAcceptInputType_clearable: unknown;
    static ngAcceptInputType_debug: unknown;
}
