import { KeysEnum, KeyValueType } from './types';
import { RegExpUtils } from './regexps';
export declare function isNil<T>(obj: T | null | undefined): boolean;
export declare function isNilOrBlank<T>(obj: T | null | undefined): boolean;
export declare function isNotNil<T>(obj: T | null | undefined): boolean;
export declare function isNotNilOrBlank<T>(obj: T | null | undefined): boolean;
export declare function isNotNilOrNaN<T>(obj: T | null | undefined): boolean;
export declare function isNilOrNaN<T>(obj: T | null | undefined): boolean;
export declare function isNotEmptyArray<T>(obj: T[] | null | undefined): boolean;
export declare function firstArrayValue<T>(obj: T[] | null | undefined): T | undefined;
export declare function lastArrayValue<T>(obj: T[] | null | undefined): T | undefined;
export declare function isEmptyArray<T>(obj: T[] | null | undefined): boolean;
export declare function arrayResize<T>(array: T[] | null | undefined, size: number, defaultValue?: T): T[];
export declare function newArray<T>(size: number, defaultValue?: T): T[];
export declare function isNotNilBoolean(obj: any | null | undefined): obj is boolean;
export declare function isNotNilString(obj: any | null | undefined): obj is string;
export declare function isNotNilObject(obj: any | null | undefined): obj is object;
export declare function isBlankString(obj: any | null | undefined): obj is string;
export declare function notNilOrDefault<T>(obj: T | null | undefined, defaultValue: T): T;
export declare function arraySize<T>(obj: T[] | null | undefined): number;
/**
 * Remove duplicated value, in array. Will compute a unique key (from given properties, or given function).
 * If propertiesOrKeyFn is nil or undefined, will use all object properties
 *
 * @param values
 * @param propertiesOrKeyFn
 */
export declare function arrayDistinct<T = any>(values: T[], propertiesOrKeyFn?: string | string[] | ((obj: T) => string)): T[];
export declare function nullIfUndefined<T>(obj: T | null | undefined): T | null;
export declare function nullIfNilOrBlank<T>(obj: T | null | undefined): T | null;
export declare function undefinedIfNull<T>(obj: T | null | undefined): T | undefined;
export declare function trimEmptyToNull<T>(str: string | null | undefined): string | null;
export declare function toBoolean(obj: boolean | null | undefined | string, defaultValue?: boolean): boolean;
export declare function toNumber(obj: number | null | undefined | string, defaultValue?: number): number;
export declare function toFloat(obj: string | null | undefined, defaultValue?: number): number | null;
export declare function toInt(obj: string | null | undefined, defaultValue?: number): number | null;
export declare function toNotNil<T = any>(obj: T, defaultValue?: T): any | null;
export declare function removeDuplicatesFromArray<T>(obj: T[] | null | undefined, property?: string): T[] | null | undefined;
export declare function startsWithUpperCase(input: string, search: string): boolean;
/**
 * @deprecated Use Regexps.matchUpperCase instead
 */
export declare const matchUpperCase: typeof RegExpUtils.matchUpperCase;
/**
 * Remove trailing slash if any. Examples :
 * - '/test/' -> '/test'
 * - '/' -> undefined
 */
export declare function noTrailingSlash(path: string): string;
export declare function replaceAll(value: string, searchString: any, replacement: any): string | undefined;
export declare function escapeRegExp(value: string): string;
export declare function removeEnd(value: string, end: string): string;
/**
 * Replace case change by an underscore (.e.g 'myString' becomes 'my_string')
 *
 * @param value
 */
export declare function changeCaseToUnderscore(value: string): string;
/**
 * Replace underscore by a change case (.e.g 'MY_STRING' becomes 'MyString')
 *
 * @param value
 */
export declare function underscoreToChangeCase(value: string): string;
export declare function removeDiacritics(text: string): string;
export declare function suggestFromStringArray(values: string[], searchText: any, opts?: {
    anySearch?: boolean;
}): string[];
export declare function joinPropertiesPath<T = any>(obj: T, properties: string[], separator?: string): string | undefined;
export declare function joinProperties<T = any, K extends keyof T = any>(obj: T, keys: K[], separator?: string): string | undefined;
export declare function propertyPathComparator<T = any>(path: string | string[]): (a: T, b: T) => number;
export declare function propertyComparator<T = any, K extends keyof T = any>(key: K, defaultValue?: any): (a: T, b: T) => number;
export declare function propertiesPathComparator<T = any>(keys: string[], defaultValues?: any[]): (a: T, b: T) => number;
export declare function sort<T>(array: T[], attribute?: string, opts?: Intl.CollatorOptions): T[];
export declare function isInt(value: string): boolean;
export declare function isNumber(value: string): boolean;
export declare function isNumberRange(value: string): boolean;
export declare function getPropertyByPath(obj: any, path: string | Array<string | number>, defaultValue?: any): any;
export declare function getProperty<T = any, K extends keyof T = any>(obj: T, key: K): T[K];
export declare function getPropertyByPathAsString(obj: any, path: string | string[], defaultValue?: string): string | undefined;
/**
 * Update an object's property, using a path (like '<property_1>.<sub_property_1>')
 * @param obj
 * @param path
 * @param value
 * @return the given obj
 */
export declare function setPropertyByPath<T = any>(obj: T, path: string | string[], value: any): T;
export declare function sleep(ms: number): Promise<void>;
export declare function isPromise<T>(value: T | Promise<T>): value is Promise<T>;
/**
 * Rounds a numeric value to two decimal places.
 *
 * @param {number | undefined | null} value - The value to be rounded. Can be a number, undefined, or null.
 * @param nbDecimal the number of decimal (default: 2)
 * @return {number} The rounded value with two decimal places if the input value is a valid number; otherwise, returns the input value.
 */
export declare function round(value: number | undefined | null, nbDecimal?: number): number;
export declare function equalsOrNil(value1: any, value2: any): boolean;
/**
 * remove elements from an array
 *
 * @return the removed elements
 * @param array the array on which elements will be removed
 * @param predicate the selection predicate
 */
export declare function removeAll<T>(array: T[], predicate: (value: T) => boolean): T[];
/**
 * remove the first element from an array
 *
 * @return the removed element
 * @param array the array on which the element will be removed
 * @param predicate the selection predicate
 */
export declare function remove<T>(array: T[], predicate: (value: T) => boolean): T;
export declare function capitalizeFirstLetter(value: string): string;
export declare function uncapitalizeFirstLetter(value: string): string;
export declare function booleanToString(value: any, opts?: {
    yesLabel: string;
    noLabel: string;
}): string;
export declare function splitByProperty<T, M extends KeyValueType<T> = KeyValueType<T>>(array: T[] | readonly T[], propertyName: keyof T | string): M;
export declare function splitById<T, M extends KeyValueType<T> = KeyValueType<T>>(array: T[] | readonly T[]): M;
/**
 * Split an array, into a map of array, group by property
 */
export declare function collectByProperty<T>(values: T[], propertyName: keyof T): KeyValueType<T[]>;
/**
 * Split an array into chunks with fixed size
 */
export declare function splitArrayInChunks<T = any>(value: T[], chunkSize: number): T[][];
/**
 * Determines if two objects or two values are equivalent.
 *
 * Two objects or values are considered equivalent if at least one of the following is true:
 *
 * * Both objects or values pass `===` comparison.
 * * Both objects or values are of the same type and all of their properties are equal by
 *   comparing them with `equals`.
 *
 * @param o1 Object or value to compare.
 * @param o2 Object or value to compare.
 * @returns true if arguments are equal.
 */
export declare function equals(o1: any, o2: any): boolean;
export declare class Beans {
    /**
     * Deep clone.
     * See https://github.com/pvorb/clone
     */
    static clone: any;
    /**
     * Copy a source object, by including only properties of the given dataType.
     * IMPORTANT: extra properties that are NOT in the targetClass are NOT copied.
     *
     * @param source The source object to copy
     * @param dataType the class to use as target class
     * @param keys The keys to copy. If empty, will copy only NOT optional properties from the dataType
     */
    static copy<T>(source: T, dataType: new () => T, keys?: KeysEnum<T>): T;
    /**
     * Says if an object all all properties to nil
     */
    static isEmpty<T>(data: T, keys?: KeysEnum<T> | string[], opts?: {
        blankStringLikeEmpty?: boolean;
    }): boolean;
    static collectById<T>(array: T[]): KeyValueType<T[]>;
    static collectByProperty: typeof collectByProperty;
}
export declare function findParentWithClass(elem: HTMLElement, className: string): HTMLElement;
export declare function intersectArrays<T = any>(values: T[][]): T[];
export declare function noHtml(value: string): string;
/**
 * Interpolates a string by replacing placeholders with corresponding values from the provided object.
 *
 * @param {string} message - The string containing placeholders enclosed in double curly braces (e.g., {{key}}).
 * @param {Record<string, any>} interpolateParams - An object containing key-value pairs for interpolation.
 * @return {string} The interpolated string with placeholders replaced by corresponding values, or the original string if no placeholders are matched.
 */
export declare function interpolateString(message: string, interpolateParams: Record<string, any>): string;
/**
 *
 * Transforms a value (typically a string) to a number.
 * Intended to be used as a transform function of an input.
 * Should return n=undefined when for a nil input
 * @param value Value to be transformed.
 * @param fallbackValue Value to use if the provided value can't be parsed as a number.
 *
 *  @usageNotes
 *  ```ts
 *  @Input({ transform: numberAttribute }) id!: number;
 *  ```
 *
 * @publicApi
 */
export declare function numberOrNilAttribute(value: unknown, fallbackValue?: number): number | undefined | null;
/**
 * Formats a given number according to the specified options.
 *
 * @param {number} val - The number to be formatted.
 * @param {Intl.NumberFormatOptions & { fixedDecimals?: number }} [opts] - An optional object containing formatting options. It can include standard `Intl.NumberFormatOptions` properties and an additional `fixedDecimals` property to specify the number of fixed decimal places.
 * @return {string} The formatted number as a string, based on the provided options.
 */
export declare function numberToString(val: number, opts?: Intl.NumberFormatOptions & {
    fixedDecimals?: number;
}): string;
