import { PredefinedColors } from '@ionic/core';
export declare type ColorName = PredefinedColors | 'white' | 'red' | 'green' | 'blue';
/**
 * Useful class for color conversion
 */
export declare class Color {
    private _rgbArray;
    private _opacity?;
    private _name;
    static get(name: ColorName): Color;
    static parseRgba(rgba: string): Color | null;
    static transparent: () => Color;
    constructor(_rgbArray: number[], _opacity?: number, _name?: string);
    get name(): string;
    get opacity(): number;
    get rgb(): number[];
    get r(): number;
    get g(): number;
    get b(): number;
    rgba(opacity?: number): string;
}
export declare interface ColorGradientOptions {
    startColor?: number[];
    mainColor?: number[];
    mainColorIndex?: number;
    endColor?: number[];
}
export declare interface ColorScaleOptions extends ColorGradientOptions {
    opacity?: number;
    min?: number;
    max?: number;
    upperMax?: boolean;
}
export declare interface ColorScaleLegendItem {
    label: string | number[];
    color: Color;
}
export declare interface ColorScaleLegend {
    items: ColorScaleLegendItem[];
}
/**
 * Helper class for colors scale
 */
export declare class ColorScale {
    static custom: (count: number, options?: ColorScaleOptions) => ColorScale;
    static default(): ColorScale;
    /**
     * Create an array with the given color
     **/
    static fix(length?: number, colorName?: ColorName): string[];
    private _min;
    private _max;
    private _rangeSize;
    private _legendItems;
    get min(): number;
    get max(): number;
    constructor(colorArray: number[][], options?: ColorScaleOptions);
    get legend(): ColorScaleLegend;
    getValueColor(value: number): Color;
    getLegendForValue(value: number): ColorScaleLegendItem;
    getLegendAtIndex(index: number): ColorScaleLegendItem;
    protected computeLegendItems(colorArray: number[][]): ColorScaleLegendItem[];
}
