import { AfterContentChecked, ChangeDetectorRef, ElementRef, EventEmitter, OnDestroy, OnInit, TemplateRef } from '@angular/core';
import { BehaviorSubject, Subject, Subscription } from 'rxjs';
import { TableDataSource, TableElement } from '@e-is/ngx-material-table';
import { Environment } from '../../../../environments/environment.class';
import { ImageService } from '../image.service';
import { Image, ImageSize } from '../image.model';
import { AlertController, IonModal, IonPopover, Platform } from '@ionic/angular';
import { CollectionViewer, ListRange } from '@angular/cdk/collections';
import { TranslateService } from '@ngx-translate/core';
import { AppColors } from '../../types';
import { FormGroup } from '@angular/forms';
import { PredefinedColors } from '@ionic/core';
import { Swiper } from 'swiper/types';
import { ImageOptions } from '@capacitor/camera';
import * as i0 from "@angular/core";
export declare type GalleryMode = 'mosaic' | 'list';
export interface ISwiper extends Swiper {
    activeIndex: number;
    imagesLoaded: number;
}
export interface ImageGallerySizes {
    mosaic: ImageSize | string;
    list: ImageSize | string;
    modal: ImageSize | string;
}
export declare class AppImageGalleryComponent<T extends Image> implements OnInit, OnDestroy, CollectionViewer, AfterContentChecked {
    protected imageService: ImageService;
    protected platform: Platform;
    protected alterCtrl: AlertController;
    protected translate: TranslateService;
    protected cd: ChangeDetectorRef;
    protected _destroySubject: Subject<void>;
    protected _renderChangeSubscription: Subscription;
    protected _subscription: Subscription;
    protected _dataSource: TableDataSource<T>;
    protected _data$: BehaviorSubject<readonly TableElement<T>[] | TableElement<T>[]>;
    protected _colSize: number;
    protected _selectedRowIndex: number;
    protected _presentingElement: Element;
    protected _titleForm: FormGroup;
    protected _titleAutofocus: boolean;
    protected _slidesSubscription: Subscription;
    protected _swiper: Swiper;
    protected swiperModules: ((opts: any) => void)[];
    protected zoomActive: boolean;
    protected zoomScale: number;
    viewChange: BehaviorSubject<ListRange>;
    cardColor: string | PredefinedColors;
    debug: boolean;
    disabled: boolean;
    readOnly: boolean;
    mobile: boolean;
    mode: GalleryMode;
    confirmBeforeDelete: boolean;
    showToolbar: boolean;
    showFabButton: boolean;
    showTitle: boolean;
    showAddToolbarButton: boolean;
    showAddTextButton: boolean;
    showAddCardButton: boolean;
    showCardToolbar: boolean;
    addButtonColor: AppColors;
    addButtonText: string;
    cardTemplate: TemplateRef<{
        $implicit: TableElement<T>;
        image: T;
        mode: GalleryMode;
    }>;
    imageSizes: ImageGallerySizes;
    imageSizeQueryParam: string;
    set dataSource(dataSource: TableDataSource<T, any, any, any>);
    get dataSource(): TableDataSource<T, any, any, any>;
    get enabled(): boolean;
    get rows(): TableElement<T>[] | ReadonlyArray<TableElement<T>>;
    get rowCount(): number;
    get activeIndex(): number;
    zoomModal: IonModal;
    titlePopover: IonPopover;
    swiperRef: ElementRef;
    onBeforeDeleteRows: EventEmitter<import("../../events").PromiseEvent<boolean, {
        rows: TableElement<T>[];
    }>>;
    onAfterAddRows: EventEmitter<TableElement<T>[]>;
    onAfterEditRow: EventEmitter<TableElement<T>>;
    click: EventEmitter<T>;
    constructor(imageService: ImageService, platform: Platform, alterCtrl: AlertController, translate: TranslateService, cd: ChangeDetectorRef, environment?: Environment);
    ngOnInit(): void;
    ngAfterContentChecked(): void;
    ngOnDestroy(): void;
    add(event?: Event, opts?: {
        maxHeight?: number;
        mawWidth?: number;
        quality?: number;
        multiple?: boolean;
        autoHideDropArea?: boolean;
    } & Omit<ImageOptions, 'resultType'>): Promise<void>;
    delete(event: Event, row: TableElement<T>, opts?: {
        interactive?: boolean;
    }): Promise<boolean>;
    toggleViewMode(_?: Event): void;
    trackByFn(index: number, row: TableElement<T>): number;
    editTitle(event: MouseEvent, row: TableElement<T>, cardToolbar: any): Promise<void>;
    protected focusCardToolbar(cardToolbar: any): void;
    protected hideCardToolbar(cardToolbar: any): void;
    protected _switchDataSource(dataSource: TableDataSource<T>): void;
    protected _observeRenderChanges(): void;
    protected getTableUnknownDataSourceError(): Error;
    protected clickRow(row: TableElement<T>, index: number): Promise<void>;
    protected activeSlideIndex: number;
    protected getSwiper(swiperElement?: any): Swiper;
    protected onSlideChange(swiperElement: any): void;
    protected initModalSlides(swiperElement: any): void;
    protected zoom(swiperElement: any, zoomIn: boolean): Promise<void>;
    protected deleteFromModal(event: any, swiperElement: any): Promise<boolean>;
    protected slidePrev(swiperElement: any): Promise<void>;
    protected slideNext(swiperElement: any): Promise<void>;
    protected canDeleteRows(rows: TableElement<T>[], opts?: {
        interactive?: boolean;
    }): Promise<boolean>;
    protected getImageSizeQueryParams(mode?: GalleryMode | 'modal'): {
        [key: string]: any;
    };
    protected markForCheck(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AppImageGalleryComponent<any>, [null, null, null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AppImageGalleryComponent<any>, "app-image-gallery", never, { "cardColor": { "alias": "cardColor"; "required": false; }; "debug": { "alias": "debug"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "readOnly": { "alias": "readOnly"; "required": false; }; "mobile": { "alias": "mobile"; "required": false; }; "mode": { "alias": "mode"; "required": false; }; "confirmBeforeDelete": { "alias": "confirmBeforeDelete"; "required": false; }; "showToolbar": { "alias": "showToolbar"; "required": false; }; "showFabButton": { "alias": "showFabButton"; "required": false; }; "showTitle": { "alias": "showTitle"; "required": false; }; "showAddToolbarButton": { "alias": "showAddToolbarButton"; "required": false; }; "showAddTextButton": { "alias": "showAddTextButton"; "required": false; }; "showAddCardButton": { "alias": "showAddCardButton"; "required": false; }; "showCardToolbar": { "alias": "showCardToolbar"; "required": false; }; "addButtonColor": { "alias": "addButtonColor"; "required": false; }; "addButtonText": { "alias": "addButtonText"; "required": false; }; "cardTemplate": { "alias": "cardTemplate"; "required": false; }; "imageSizes": { "alias": "imageSizes"; "required": false; }; "imageSizeQueryParam": { "alias": "imageSizeQueryParam"; "required": false; }; "dataSource": { "alias": "dataSource"; "required": false; }; }, { "onBeforeDeleteRows": "onBeforeDeleteRows"; "onAfterAddRows": "onAfterAddRows"; "onAfterEditRow": "onAfterEditRow"; "click": "click"; }, never, ["ion-buttons[slot=start]", "ion-buttons[slot=end]"], false, never>;
    static ngAcceptInputType_debug: unknown;
    static ngAcceptInputType_disabled: unknown;
    static ngAcceptInputType_readOnly: unknown;
    static ngAcceptInputType_mobile: unknown;
    static ngAcceptInputType_showToolbar: unknown;
    static ngAcceptInputType_showFabButton: unknown;
    static ngAcceptInputType_showTitle: unknown;
    static ngAcceptInputType_showAddToolbarButton: unknown;
    static ngAcceptInputType_showAddTextButton: unknown;
    static ngAcceptInputType_showAddCardButton: unknown;
    static ngAcceptInputType_showCardToolbar: unknown;
}
