import { LogLevel } from './log-level.model';
import { Moment } from 'moment';
import { LoggingServiceConfig } from './logging-service.config';
import { AppColors } from '../types';
export interface ILoggingService {
    configure(configuration: LoggingServiceConfig): Promise<void>;
    getLogger(loggerName: string): ILogger;
}
export interface ILoggingAppender {
    append(loggerName: string, level: LogLevel, message: string): any;
}
export interface ILogger {
    /**
     * Logs a message at level TRACE.
     *
     * @param methodName name of the method
     * @param params optional parameters to be logged; objects will be formatted as JSON
     */
    trace(methodName: string, ...params: any[]): void;
    /**
     * Logs a message at level DEBUG.
     *
     * @param methodName name of the method
     * @param params optional parameters to be logged; objects will be formatted as JSON
     */
    debug(methodName: string, ...params: any[]): void;
    /**
     * Logs a message at level INFO.
     *
     * @param methodName name of the method
     * @param params optional parameters to be logged; objects will be formatted as JSON
     */
    info(methodName: string, ...params: any[]): void;
    /**
     * Logs a message at level WARN.
     *
     * @param methodName name of the method
     * @param params optional parameters to be logged; objects will be formatted as JSON
     */
    warn(methodName: string, ...params: any[]): void;
    /**
     * Logs a message at level ERROR.
     *
     * @param methodName name of the method
     * @param params optional parameters to be logged; objects will be formatted as JSON
     */
    error(methodName: string, ...params: any[]): any;
    /**
     * Logs a message at level FATAL.
     *
     * @param methodName name of the method
     * @param params optional parameters to be logged; objects will be formatted as JSON
     */
    fatal(methodName: string, ...params: any[]): any;
}
export interface Log {
    loggerName: string;
    level: LogLevel;
    message: string;
    date: Moment;
}
export declare class LogUtils {
    static fromObject(source: any): Log;
    static asObject(source: Log): any;
    static fromObjects(sources: any[]): Log[];
    static levelToString(level: LogLevel): string;
    static levelToColor(level: LogLevel): AppColors;
}
