export declare class MarkdownUtils {
    static readonly HTML_ENTITIES_MAP: {
        [entity: string]: string;
    };
    /**
     * Converts the given text into a valid anchor-compatible format.
     *
     * @param {string} text - The input text to be transformed into an anchor.
     * @return {string} The formatted string suitable for use as an anchor.
     */
    static textToAnchor(text: string): string;
    /**
     * Adjusts the given anchor ID by replacing underscores with hyphens and converting to lowercase.
     *
     * @param {string} anchorId - The anchor ID string to be fixed.
     * @return {string} The modified anchor ID with underscores replaced by hyphens and converted to lowercase, or the original anchor ID if it is falsy.
     */
    static fixAnchor(anchorId: string): string;
    static isMarkdownFile(url: string): boolean;
    static resolveRelativeUrl(baseUrl: string, relativePath: string, opts?: {
        absoluteByDefault: boolean;
    }): string;
    static isGitlabUrl(url: string): boolean;
    static fixGitlabUrlToRaw(url: string): string;
    static getRootUrl(url: string): string;
}
