import { SuggestFn, SuggestService } from '../../services/entity-service.class';
import { Observable } from 'rxjs';
import { DisplayFn, EqualsFn } from '../../form/field.model';
export declare interface MatAutocompleteFieldConfig<T = any, F = any> {
    attributes?: string[];
    suggestFn?: SuggestFn<T, F>;
    filter?: Partial<F>;
    items?: Observable<T[]> | T[];
    columnSizes?: (number | 'auto' | undefined)[];
    columnNames?: (string | undefined)[];
    multiple?: boolean;
    displayWith?: DisplayFn;
    displayWithSeparator?: string;
    splitSearchText?: boolean;
    trimSearchText?: boolean;
    clearInvalidSearchTextOnBlur?: boolean;
    equals?: EqualsFn;
    showAllOnFocus?: boolean;
    showPanelOnFocus?: boolean;
    reloadItemsOnFocus?: boolean;
    mobile?: boolean;
    debounceTime?: number;
    suggestLengthThreshold?: number;
    highlightAccent?: boolean;
    applyImplicitValue?: boolean;
    /**
     * Should select input content (desktop only)
     */
    selectInputContentOnFocus?: boolean;
    /**
     * Add a delay (ms) before trying to select input content (desktop only)
     */
    selectInputContentOnFocusDelay?: number;
    /**
     * If true, any invalid value entered in the input field will be cleared when the input loses focus.
     * This helps in preventing invalid data to be displayed on the field
     */
    clearInvalidValueOnBlur?: boolean;
    /**
     * Determines whether the implicit value is preview in the input text field or not (desktop only).
     *
     * If not specified, the default behavior is to not preview implicit values (`false`).
     *
     * @type {boolean}
     */
    previewImplicitValue?: boolean;
    /**
     * Class to apply to the `div.mat-mdc-select-panel`
     */
    panelClass?: string;
    /**
     * Allow to fix panel width (e.g. '500px' or '100vw')
     */
    panelWidth?: string;
    /**
     * @deprecated use `panelClass` instead
     */
    class?: string;
}
export declare interface MatAutocompleteFieldAddOptions<T = any, F = any> extends Partial<MatAutocompleteFieldConfig<T, F>> {
    service?: SuggestService<T, F>;
}
export declare class MatAutocompleteConfigHolder {
    private options?;
    fields: {
        [key: string]: MatAutocompleteFieldConfig;
    };
    getUserAttributes: (fieldName: string, defaultAttributes?: string[]) => string[];
    constructor(options?: {
        getUserAttributes: (fieldName: string, defaultAttributes?: string[]) => string[];
    });
    add<T = any, F = any>(fieldName: string, options?: MatAutocompleteFieldAddOptions<T, F>): MatAutocompleteFieldConfig<T, F>;
    get<T = any>(fieldName: string): MatAutocompleteFieldConfig<T>;
}
