import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, Injector, OnDestroy, OnInit, Renderer2 } from '@angular/core';
import { ControlValueAccessor, FormGroupDirective, UntypedFormControl } from '@angular/forms';
import { BehaviorSubject, Observable } from 'rxjs';
import { SuggestFn } from '../../services/entity-service.class';
import { InputElement } from '../../inputs';
import { AppFloatLabelType, DisplayFn, EqualsFn } from '../../form/field.model';
import { MatFormFieldAppearance, SubscriptSizing } from '@angular/material/form-field';
import { MatSelect, MatSelectChange } from '@angular/material/select';
import { MatAutocomplete, MatAutocompleteSelectedEvent, MatAutocompleteTrigger } from '@angular/material/autocomplete';
import { IonSearchbar, ModalController } from '@ionic/angular';
import { MatAutocompleteFieldConfig } from './material.autocomplete.config';
import * as i0 from "@angular/core";
export interface MatAutocompleteFieldSelectChange {
    source: MatSelect | MatAutocomplete;
    value: any;
}
export interface MatAutocompleteFieldToggleFavorite {
    source: MatSelect | MatAutocomplete;
    value: any;
}
export declare class MatAutocompleteField implements OnInit, AfterViewInit, OnDestroy, InputElement, ControlValueAccessor {
    protected injector: Injector;
    protected el: ElementRef<HTMLElement>;
    protected cd: ChangeDetectorRef;
    protected modalController: ModalController;
    protected renderer: Renderer2;
    private formGroupDir;
    private _onChangeCallback;
    private _onTouchedCallback;
    private _onFetchMoreCallback;
    private _implicitValue;
    private _subscription;
    private _itemsSubscription;
    private _openedSubscription;
    private _$filter;
    private _itemCount;
    private _suggestExecutionId;
    private _reload$;
    private _destroy$;
    protected _readonly: boolean;
    protected _tabindex: number;
    protected _$inputItems: BehaviorSubject<any[]>;
    protected _$filteredItems: BehaviorSubject<any[]>;
    protected _selectedItem: any;
    protected _displayValue: string;
    protected _moreItemsCount: number;
    protected _fetchMore$: EventEmitter<Event>;
    protected _defaultPanelWidth: string;
    protected _focused: boolean;
    protected get searchText(): string | undefined;
    equals: EqualsFn;
    logPrefix: string;
    formControl: UntypedFormControl;
    formControlName: string;
    floatLabel: AppFloatLabelType;
    label: string;
    appearance: MatFormFieldAppearance;
    subscriptSizing: SubscriptSizing;
    placeholder: string;
    suggestFn: SuggestFn<any, any>;
    required: boolean;
    hideRequiredMarker: boolean;
    mobile: boolean;
    clearable: boolean;
    debounceTime: number;
    displaySeparator: string | null;
    displayWith: DisplayFn | null;
    displayAttributes: string[];
    displayColumnSizes: (number | 'auto' | undefined)[];
    displayColumnNames: string[];
    highlightAccent: boolean;
    showAllOnFocus: boolean;
    showPanelOnFocus: boolean;
    reloadItemsOnFocus: boolean;
    clearInvalidValueOnBlur: boolean;
    autofocus: boolean;
    config: MatAutocompleteFieldConfig;
    i18nPrefix: string;
    noResultMessage: string;
    panelClass: string;
    panelWidth: string;
    disableRipple: boolean;
    matAutocompletePosition: 'auto' | 'above' | 'below';
    multiple: boolean;
    fetchMoreThreshold: string;
    suggestLengthThreshold: number;
    showLoadingSpinner: boolean;
    debug: boolean;
    showSearchBar: boolean;
    stickySearchBar: boolean;
    applyImplicitValue: boolean | ((value: any) => boolean);
    dropButtonTitle: string;
    clearButtonTitle: string;
    trimSearchText: boolean;
    splitSearchText: boolean;
    selectInputContentOnFocus: boolean;
    selectInputContentOnFocusDelay: number;
    previewImplicitValue: boolean;
    showFavorites: boolean;
    toggleFavoriteTitle: string;
    favoriteItems: any[];
    colSizes: [number | 'auto', number | 'auto'];
    /**
     * @deprecated Use panelClass instead
     */
    set classList(value: string);
    get classList(): string;
    clicked: EventEmitter<MouseEvent>;
    blurred: EventEmitter<FocusEvent>;
    focused: EventEmitter<FocusEvent>;
    dropButtonClick: EventEmitter<Event>;
    keydownEscape: EventEmitter<Event>;
    keydownBackspace: EventEmitter<Event>;
    keyupEnter: EventEmitter<Event>;
    selectionChange: EventEmitter<MatAutocompleteFieldSelectChange>;
    openedChange: EventEmitter<boolean>;
    toggleFavorite: EventEmitter<MatAutocompleteFieldToggleFavorite>;
    matSelect: MatSelect;
    ionSearchbar: IonSearchbar;
    matInputText: ElementRef<HTMLInputElement>;
    autocomplete: MatAutocomplete;
    autocompleteTrigger: MatAutocompleteTrigger;
    constructor(injector: Injector, el: ElementRef<HTMLElement>, cd: ChangeDetectorRef, modalController: ModalController, renderer: Renderer2, formGroupDir: FormGroupDirective);
    get itemCount(): number;
    get canFetchMore(): boolean;
    set filter(value: any);
    get filter(): any;
    set readonly(value: boolean);
    get readonly(): boolean;
    set tabindex(value: number);
    get tabindex(): number;
    set items(value: Observable<any[]> | any[]);
    get items(): Observable<any[]> | any[];
    get value(): any;
    get disabled(): boolean;
    get enabled(): boolean;
    get loading(): boolean;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    /**
     * Allow to reload content. Useful when filter has been changed but not detected
     */
    reloadItems(value?: any): void;
    writeValue(value: any): void;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    setDisabledState(isDisabled: boolean): void;
    focus(): void;
    filterInputTextFocusEvent(event: FocusEvent): boolean;
    protected filterInputTextBlurEvent(event: FocusEvent): void;
    protected ionSearchBarChanged(event: Event): void;
    filterMatSelectFocusEvent(event: FocusEvent): void;
    filterMatSelectBlurEvent(event: FocusEvent): boolean;
    clearValue(event?: Event): void;
    _initAutocompleteInfiniteScroll(threshold?: string): void;
    _initMatSelectInfiniteScroll(threshold?: string): void;
    get isOpen(): boolean;
    closePanel(): void;
    protected markAsLoading(): void;
    protected onSelectionChange(event: MatSelectChange): void;
    protected onOptionSelected(event: MatAutocompleteSelectedEvent): void;
    protected toggleShowPanel(event: Event): void;
    private suggest;
    private fetchMore;
    private updateImplicitValue;
    private checkIfTouched;
    private getAutocompletePanel;
    private getMatSelectPanel;
    private markForCheck;
    private _fixMatSelectPositionAndSearchbar;
    private _fixMatSelectPanelPosition;
    /**
     * Hack : if we are in a IonModal, it's necessary to move the CdkOverlay container
     *     in the IonModal to might keep focus in IonSearchbar.
     *
     * @param panelElement
     * @param overlayPane
     * @private
     */
    private _fixSearchbarOverlay;
    private setInputTextValue;
    protected onBackspace(event: Event): void;
    protected toggleFavoriteClick(event: UIEvent, value: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<MatAutocompleteField, [null, null, null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatAutocompleteField, "mat-autocomplete-field", never, { "equals": { "alias": "equals"; "required": false; }; "logPrefix": { "alias": "logPrefix"; "required": false; }; "formControl": { "alias": "formControl"; "required": false; }; "formControlName": { "alias": "formControlName"; "required": false; }; "floatLabel": { "alias": "floatLabel"; "required": false; }; "label": { "alias": "label"; "required": false; }; "appearance": { "alias": "appearance"; "required": false; }; "subscriptSizing": { "alias": "subscriptSizing"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "suggestFn": { "alias": "suggestFn"; "required": false; }; "required": { "alias": "required"; "required": false; }; "hideRequiredMarker": { "alias": "hideRequiredMarker"; "required": false; }; "mobile": { "alias": "mobile"; "required": false; }; "clearable": { "alias": "clearable"; "required": false; }; "debounceTime": { "alias": "debounceTime"; "required": false; }; "displaySeparator": { "alias": "displaySeparator"; "required": false; }; "displayWith": { "alias": "displayWith"; "required": false; }; "displayAttributes": { "alias": "displayAttributes"; "required": false; }; "displayColumnSizes": { "alias": "displayColumnSizes"; "required": false; }; "displayColumnNames": { "alias": "displayColumnNames"; "required": false; }; "highlightAccent": { "alias": "highlightAccent"; "required": false; }; "showAllOnFocus": { "alias": "showAllOnFocus"; "required": false; }; "showPanelOnFocus": { "alias": "showPanelOnFocus"; "required": false; }; "reloadItemsOnFocus": { "alias": "reloadItemsOnFocus"; "required": false; }; "clearInvalidValueOnBlur": { "alias": "clearInvalidValueOnBlur"; "required": false; }; "autofocus": { "alias": "autofocus"; "required": false; }; "config": { "alias": "config"; "required": false; }; "i18nPrefix": { "alias": "i18nPrefix"; "required": false; }; "noResultMessage": { "alias": "noResultMessage"; "required": false; }; "panelClass": { "alias": "panelClass"; "required": false; }; "panelWidth": { "alias": "panelWidth"; "required": false; }; "disableRipple": { "alias": "disableRipple"; "required": false; }; "matAutocompletePosition": { "alias": "matAutocompletePosition"; "required": false; }; "multiple": { "alias": "multiple"; "required": false; }; "fetchMoreThreshold": { "alias": "fetchMoreThreshold"; "required": false; }; "suggestLengthThreshold": { "alias": "suggestLengthThreshold"; "required": false; }; "showLoadingSpinner": { "alias": "showLoadingSpinner"; "required": false; }; "debug": { "alias": "debug"; "required": false; }; "showSearchBar": { "alias": "showSearchBar"; "required": false; }; "stickySearchBar": { "alias": "stickySearchBar"; "required": false; }; "applyImplicitValue": { "alias": "applyImplicitValue"; "required": false; }; "dropButtonTitle": { "alias": "dropButtonTitle"; "required": false; }; "clearButtonTitle": { "alias": "clearButtonTitle"; "required": false; }; "trimSearchText": { "alias": "trimSearchText"; "required": false; }; "splitSearchText": { "alias": "splitSearchText"; "required": false; }; "selectInputContentOnFocus": { "alias": "selectInputContentOnFocus"; "required": false; }; "selectInputContentOnFocusDelay": { "alias": "selectInputContentOnFocusDelay"; "required": false; }; "previewImplicitValue": { "alias": "previewImplicitValue"; "required": false; }; "showFavorites": { "alias": "showFavorites"; "required": false; }; "toggleFavoriteTitle": { "alias": "toggleFavoriteTitle"; "required": false; }; "favoriteItems": { "alias": "favoriteItems"; "required": false; }; "colSizes": { "alias": "colSizes"; "required": false; }; "classList": { "alias": "class"; "required": false; }; "filter": { "alias": "filter"; "required": false; }; "readonly": { "alias": "readonly"; "required": false; }; "tabindex": { "alias": "tabindex"; "required": false; }; "items": { "alias": "items"; "required": false; }; }, { "clicked": "click"; "blurred": "blur"; "focused": "focus"; "dropButtonClick": "dropButtonClick"; "keydownEscape": "keydown.escape"; "keydownBackspace": "keydown.backspace"; "keyupEnter": "keyup.enter"; "selectionChange": "selectionChange"; "openedChange": "openedChange"; "toggleFavorite": "toggleFavorite"; }, never, ["[matAfter]", "[matPrefix]", "[matSuffix]", "mat-error,[matError]", "mat-hint:not([align='end']),[matHint]", "mat-hint[align='end']"], false, never>;
    static ngAcceptInputType_required: unknown;
    static ngAcceptInputType_hideRequiredMarker: unknown;
    static ngAcceptInputType_mobile: unknown;
    static ngAcceptInputType_clearable: unknown;
    static ngAcceptInputType_debounceTime: unknown;
    static ngAcceptInputType_highlightAccent: unknown;
    static ngAcceptInputType_showAllOnFocus: unknown;
    static ngAcceptInputType_showPanelOnFocus: unknown;
    static ngAcceptInputType_reloadItemsOnFocus: unknown;
    static ngAcceptInputType_clearInvalidValueOnBlur: unknown;
    static ngAcceptInputType_autofocus: unknown;
    static ngAcceptInputType_disableRipple: unknown;
    static ngAcceptInputType_multiple: unknown;
    static ngAcceptInputType_suggestLengthThreshold: unknown;
    static ngAcceptInputType_showLoadingSpinner: unknown;
    static ngAcceptInputType_debug: unknown;
    static ngAcceptInputType_showSearchBar: unknown;
    static ngAcceptInputType_stickySearchBar: unknown;
    static ngAcceptInputType_trimSearchText: unknown;
    static ngAcceptInputType_splitSearchText: unknown;
    static ngAcceptInputType_selectInputContentOnFocus: unknown;
    static ngAcceptInputType_selectInputContentOnFocusDelay: unknown;
    static ngAcceptInputType_previewImplicitValue: unknown;
    static ngAcceptInputType_readonly: unknown;
}
