import { ChangeDetectorRef, ElementRef, EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { ControlValueAccessor, FormGroupDirective, UntypedFormControl } from '@angular/forms';
import { BehaviorSubject, Observable } from 'rxjs';
import { InputElement } from '../../inputs';
import { SuggestFn } from '../../services/entity-service.class';
import { AppFloatLabelType, DisplayFn, EqualsFn } from '../../form/field.model';
import { ErrorStateMatcher, ThemePalette } from '@angular/material/core';
import { MatAutocompleteFieldConfig } from '../autocomplete/material.autocomplete.config';
import { MatFormFieldAppearance, MatFormFieldDefaultOptions, SubscriptSizing } from '@angular/material/form-field';
import { MatAutocomplete, MatAutocompleteTrigger } from '@angular/material/autocomplete';
import * as i0 from "@angular/core";
export declare class MatChipsField implements OnInit, OnDestroy, InputElement, ControlValueAccessor {
    protected cd: ChangeDetectorRef;
    private formGroupDir;
    private _onChangeCallback;
    private _onTouchedCallback;
    private _onFetchMoreCallback;
    private _implicitValue;
    private _subscription;
    private _itemsSubscription;
    private _openedSubscription;
    private _$filter;
    private _itemCount;
    private _suggestExecutionId;
    private _reload$;
    private _appearance;
    private _subscriptSizing;
    private readonly _defaultAppearance;
    private readonly _defaultSubscriptSizing;
    protected _tabindex: number;
    protected _$inputItems: BehaviorSubject<any[]>;
    protected _$filteredItems: BehaviorSubject<any[]>;
    protected _inputControl: UntypedFormControl;
    protected _moreItemsCount: number;
    protected _fetchMore$: EventEmitter<Event>;
    protected _errorStateMatcher: ErrorStateMatcher;
    equals: EqualsFn;
    logPrefix: string;
    formControl: UntypedFormControl;
    formControlName: string;
    floatLabel: AppFloatLabelType;
    placeholder: string;
    suggestFn: SuggestFn<any, any>;
    required: boolean;
    mobile: boolean;
    readonly: boolean;
    clearable: boolean;
    debounceTime: number;
    displaySeparator: string | null;
    displayWith: DisplayFn | null;
    displayAttributes: string[];
    displayColumnSizes: (number | 'auto' | undefined)[];
    displayColumnNames: string[];
    highlightAccent: boolean;
    showAllOnFocus: boolean;
    showPanelOnFocus: boolean;
    autofocus: boolean;
    config: MatAutocompleteFieldConfig;
    i18nPrefix: string;
    noResultMessage: string;
    panelClass: string;
    panelWidth: string;
    disableRipple: boolean;
    matAutocompletePosition: 'auto' | 'above' | 'below';
    itemSize: string;
    fetchMoreThreshold: string;
    suggestLengthThreshold: number;
    showLoadingSpinner: boolean;
    chipColor: ThemePalette;
    debug: boolean;
    applyImplicitValue: boolean | ((value: any) => boolean);
    dropButtonTitle: string;
    clearButtonTitle: string;
    trimSearchText: boolean;
    hideRequiredMarker: boolean;
    colSizes: [number | 'auto', number | 'auto'];
    separatorKeysCodes: number[];
    set appearance(value: MatFormFieldAppearance);
    get appearance(): MatFormFieldAppearance;
    set subscriptSizing(value: SubscriptSizing);
    get subscriptSizing(): SubscriptSizing;
    /**
     * @deprecated Use panelClass instead
     */
    set classList(value: string);
    get classList(): string;
    clicked: EventEmitter<MouseEvent>;
    blurred: EventEmitter<FocusEvent>;
    focused: EventEmitter<FocusEvent>;
    dropButtonClick: EventEmitter<Event>;
    keydownEscape: EventEmitter<Event>;
    keyupEnter: EventEmitter<Event>;
    matInputText: ElementRef;
    autocomplete: MatAutocomplete;
    autocompleteTrigger: MatAutocompleteTrigger;
    constructor(cd: ChangeDetectorRef, formGroupDir: FormGroupDirective, defaultOptions?: MatFormFieldDefaultOptions);
    get itemCount(): number;
    get canFetchMore(): boolean;
    set filter(value: any);
    get filter(): any;
    set tabindex(value: number);
    get tabindex(): number;
    set items(value: Observable<any[]> | any[]);
    get items(): Observable<any[]> | any[];
    get value(): any[];
    get disabled(): boolean;
    get enabled(): boolean;
    get loading(): boolean;
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * Add item to chips
     *
     * @param item
     */
    add(item: any): void;
    /**
     * Remove item from chips
     *
     * @param item
     */
    remove(item: any): void;
    /**
     * Allow to reload content. Useful when filter has been changed but not detected
     */
    reloadItems(value?: any): void;
    writeValue(value: any[]): void;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    setDisabledState(isDisabled: boolean): void;
    focus(): void;
    filterInputTextFocusEvent(event: FocusEvent): boolean;
    protected filterInputTextBlurEvent(event: FocusEvent): void;
    filterChipsFocusEvent(event: FocusEvent): void;
    clearValue(event: Event): void;
    _initAutocompleteInfiniteScroll(threshold?: string): void;
    get isOpen(): boolean;
    closePanel(): void;
    protected toggleShowPanel(event: Event): void;
    private suggest;
    private fetchMore;
    private updateImplicitValue;
    private checkIfTouched;
    private getAutocompletePanel;
    private markForCheck;
    private markAsLoading;
    static ɵfac: i0.ɵɵFactoryDeclaration<MatChipsField, [null, { optional: true; }, null]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MatChipsField, "mat-chips-field", never, { "equals": { "alias": "equals"; "required": false; }; "logPrefix": { "alias": "logPrefix"; "required": false; }; "formControl": { "alias": "formControl"; "required": false; }; "formControlName": { "alias": "formControlName"; "required": false; }; "floatLabel": { "alias": "floatLabel"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "suggestFn": { "alias": "suggestFn"; "required": false; }; "required": { "alias": "required"; "required": false; }; "mobile": { "alias": "mobile"; "required": false; }; "readonly": { "alias": "readonly"; "required": false; }; "clearable": { "alias": "clearable"; "required": false; }; "debounceTime": { "alias": "debounceTime"; "required": false; }; "displaySeparator": { "alias": "displaySeparator"; "required": false; }; "displayWith": { "alias": "displayWith"; "required": false; }; "displayAttributes": { "alias": "displayAttributes"; "required": false; }; "displayColumnSizes": { "alias": "displayColumnSizes"; "required": false; }; "displayColumnNames": { "alias": "displayColumnNames"; "required": false; }; "highlightAccent": { "alias": "highlightAccent"; "required": false; }; "showAllOnFocus": { "alias": "showAllOnFocus"; "required": false; }; "showPanelOnFocus": { "alias": "showPanelOnFocus"; "required": false; }; "autofocus": { "alias": "autofocus"; "required": false; }; "config": { "alias": "config"; "required": false; }; "i18nPrefix": { "alias": "i18nPrefix"; "required": false; }; "noResultMessage": { "alias": "noResultMessage"; "required": false; }; "panelClass": { "alias": "panelClass"; "required": false; }; "panelWidth": { "alias": "panelWidth"; "required": false; }; "disableRipple": { "alias": "disableRipple"; "required": false; }; "matAutocompletePosition": { "alias": "matAutocompletePosition"; "required": false; }; "itemSize": { "alias": "itemSize"; "required": false; }; "fetchMoreThreshold": { "alias": "fetchMoreThreshold"; "required": false; }; "suggestLengthThreshold": { "alias": "suggestLengthThreshold"; "required": false; }; "showLoadingSpinner": { "alias": "showLoadingSpinner"; "required": false; }; "chipColor": { "alias": "chipColor"; "required": false; }; "debug": { "alias": "debug"; "required": false; }; "applyImplicitValue": { "alias": "applyImplicitValue"; "required": false; }; "dropButtonTitle": { "alias": "dropButtonTitle"; "required": false; }; "clearButtonTitle": { "alias": "clearButtonTitle"; "required": false; }; "trimSearchText": { "alias": "trimSearchText"; "required": false; }; "hideRequiredMarker": { "alias": "hideRequiredMarker"; "required": false; }; "colSizes": { "alias": "colSizes"; "required": false; }; "separatorKeysCodes": { "alias": "separatorKeysCodes"; "required": false; }; "appearance": { "alias": "appearance"; "required": false; }; "subscriptSizing": { "alias": "subscriptSizing"; "required": false; }; "classList": { "alias": "class"; "required": false; }; "filter": { "alias": "filter"; "required": false; }; "tabindex": { "alias": "tabindex"; "required": false; }; "items": { "alias": "items"; "required": false; }; }, { "clicked": "click"; "blurred": "blur"; "focused": "focus"; "dropButtonClick": "dropButtonClick"; "keydownEscape": "keydown.escape"; "keyupEnter": "keyup.enter"; }, never, ["[matAfter]", "[matPrefix]", "[matSuffix]", "mat-error,[matError]", "mat-hint:not([align='end']),[matHint]", "mat-hint[align='end']"], false, never>;
    static ngAcceptInputType_required: unknown;
    static ngAcceptInputType_mobile: unknown;
    static ngAcceptInputType_readonly: unknown;
    static ngAcceptInputType_clearable: unknown;
    static ngAcceptInputType_debounceTime: unknown;
    static ngAcceptInputType_highlightAccent: unknown;
    static ngAcceptInputType_showAllOnFocus: unknown;
    static ngAcceptInputType_showPanelOnFocus: unknown;
    static ngAcceptInputType_autofocus: unknown;
    static ngAcceptInputType_disableRipple: unknown;
    static ngAcceptInputType_suggestLengthThreshold: unknown;
    static ngAcceptInputType_showLoadingSpinner: unknown;
    static ngAcceptInputType_debug: unknown;
    static ngAcceptInputType_trimSearchText: unknown;
    static ngAcceptInputType_hideRequiredMarker: unknown;
}
