export declare type LatLongType = 'latitude' | 'longitude';
export declare type LatLongPattern = 'DDMMSS' | 'DDMM' | 'DD';
export declare const LAT_LONG_PATTERNS: LatLongPattern[];
export declare type LatLongSign = '+' | '-';
export declare type LatLongSignValue = 1 | -1;
export interface ILatLongData {
    degrees: number;
    minutes: number;
    seconds: number;
    sign: LatLongSignValue;
}
export declare const MASKS: {
    latitude: {
        DDMMSS: (string | RegExp)[];
        DDMM: (string | RegExp)[];
        DD: (string | RegExp)[];
    };
    longitude: {
        DDMMSS: (string | RegExp)[];
        DDMM: (string | RegExp)[];
        DD: (string | RegExp)[];
    };
};
export declare const MASK_RANGES: {
    latitude: {
        DDMMSS: number[][];
        DDMM: number[][];
        DD: number[][];
    };
    longitude: {
        DDMMSS: number[][];
        DDMM: number[][];
        DD: number[][];
    };
};
export declare class LatLongFormatOptions {
    pattern: LatLongPattern;
    maxDecimals?: number;
    placeholderChar?: string;
    hideSign?: boolean;
    fixLatLong?: boolean;
}
export declare const LAT_LONG_PATTERN_MAX_DECIMALS = 3;
export declare const LAT_LONG_VALUE_MAX_DECIMALS = 7;
export declare function computeDecimalPart(value: number, nbOfDecimals: number): number;
export declare function formatLatLong(value: number, type: LatLongType, opts?: Partial<LatLongFormatOptions>): string;
export declare function formatLatitude(value: number | null, opts?: Partial<LatLongFormatOptions>): string;
export declare function formatLongitude(value: number | null, opts?: Partial<LatLongFormatOptions>): string;
export declare function splitDegreesToDDArray(value: number, opts: LatLongFormatOptions & {
    longitude: boolean;
}): (number | string)[];
export declare function splitDegreesToDDMMArray(value: number, opts: LatLongFormatOptions & {
    longitude: boolean;
}): number[];
export declare function splitDegreesToDDMMSSArray(value: number, opts: LatLongFormatOptions & {
    longitude: boolean;
}): number[];
export declare function parseLatitudeOrLongitude(input: string, pattern: string, maxDecimals?: number, placeholderChar?: string): number | null;
export declare function computeDecimalDegrees(degrees: number, minutes: number, seconds: number, sign: -1 | 1, maxDecimals?: number): number;
