import { ChangeDetectorRef, OnDestroy, PipeTransform } from '@angular/core';
import { SelectionChange, SelectionModel } from '@angular/cdk/collections';
import { Subscription } from 'rxjs';
import * as i0 from "@angular/core";
export declare abstract class AbstractSelectionModelPipe<T, R, O = void> implements PipeTransform, OnDestroy {
    protected _ref: ChangeDetectorRef;
    protected _result: R;
    private _lastSelection;
    private _lastValue;
    private _lastOpts;
    protected _shouldSubscribeToChanges: boolean;
    private _onSelectionChanges;
    protected constructor(_ref: ChangeDetectorRef);
    transform(selection: SelectionModel<any>, value?: T, opts?: O): R;
    ngOnDestroy(): void;
    protected _subscribe(selection: SelectionModel<T>, value: T, opts?: O): Subscription;
    /**
     * Clean any existing subscription to change events
     */
    protected _dispose(): void;
    protected abstract _transform(selection: SelectionModel<T>, value?: T, opts?: O): R;
    protected _filterSelectionChange(selectionChange: SelectionChange<any>, value?: T, opts?: O): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<AbstractSelectionModelPipe<any, any, any>, never>;
    static ɵpipe: i0.ɵɵPipeDeclaration<AbstractSelectionModelPipe<any, any, any>, "abstract-selection", false>;
}
export declare class IsSelectedPipe extends AbstractSelectionModelPipe<any, boolean> implements PipeTransform, OnDestroy {
    constructor(_ref: ChangeDetectorRef);
    protected _transform(selection: SelectionModel<any>, value: any): boolean;
    protected _filterSelectionChange(selectionChange: SelectionChange<any>, value: any): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<IsSelectedPipe, never>;
    static ɵpipe: i0.ɵɵPipeDeclaration<IsSelectedPipe, "isSelected", false>;
}
export declare class IsNotEmptySelectionPipe extends AbstractSelectionModelPipe<void, boolean> implements PipeTransform, OnDestroy {
    constructor(_ref: ChangeDetectorRef);
    protected _transform(selection: SelectionModel<any>): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<IsNotEmptySelectionPipe, never>;
    static ɵpipe: i0.ɵɵPipeDeclaration<IsNotEmptySelectionPipe, "isNotEmptySelection", false>;
}
export declare class IsEmptySelectionPipe extends AbstractSelectionModelPipe<void, boolean> {
    constructor(_ref: ChangeDetectorRef);
    protected _transform(selection: SelectionModel<any>): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<IsEmptySelectionPipe, never>;
    static ɵpipe: i0.ɵɵPipeDeclaration<IsEmptySelectionPipe, "isEmptySelection", false>;
}
export declare class SelectionLengthPipe extends AbstractSelectionModelPipe<void, number> implements PipeTransform, OnDestroy {
    constructor(_ref: ChangeDetectorRef);
    protected _transform(selection: SelectionModel<any>): number;
    static ɵfac: i0.ɵɵFactoryDeclaration<SelectionLengthPipe, never>;
    static ɵpipe: i0.ɵɵPipeDeclaration<SelectionLengthPipe, "selectionLength", false>;
}
export declare class IsMultipleSelectionPipe extends AbstractSelectionModelPipe<void, boolean> implements PipeTransform, OnDestroy {
    constructor(_ref: ChangeDetectorRef);
    protected _transform(selection: SelectionModel<any>): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<IsMultipleSelectionPipe, never>;
    static ɵpipe: i0.ɵɵPipeDeclaration<IsMultipleSelectionPipe, "isMultipleSelection", false>;
}
export declare class IsSingleSelectionPipe extends AbstractSelectionModelPipe<void, boolean> {
    constructor(_ref: ChangeDetectorRef);
    protected _transform(selection: SelectionModel<any>): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<IsSingleSelectionPipe, never>;
    static ɵpipe: i0.ɵɵPipeDeclaration<IsSingleSelectionPipe, "isSingleSelection", false>;
}
