import { PipeTransform } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Pipe permettant d'ajouter des paramètres de requête à une URL.
 *
 * Cette pipe prend une URL de base et un objet contenant des paires clé-valeur
 * représentant les paramètres de requête à ajouter. Elle encode correctement les
 * paramètres et s'assure de les ajouter avec le séparateur approprié ('?' ou '&').
 * Les paramètres avec des valeurs nulles ou undefined sont automatiquement filtrés.
 *
 * @example
 * // Dans un template
 * <a [href]="'https://example.com' | appendQueryParams:{id: 123, name: 'test'}">Lien</a>
 * // Résultat: https://example.com?id=123&name=test
 *
 * @example
 * // Si l'URL contient déjà des paramètres
 * <a [href]="'https://example.com?page=1' | appendQueryParams:{sort: 'asc'}">Lien</a>
 * // Résultat: https://example.com?page=1&sort=asc
 */
export declare class AppendQueryParamsPipePipe implements PipeTransform {
    transform(url: string, queryParams: {
        [key: string]: any;
    }): any;
    static ɵfac: i0.ɵɵFactoryDeclaration<AppendQueryParamsPipePipe, never>;
    static ɵpipe: i0.ɵɵPipeDeclaration<AppendQueryParamsPipePipe, "appendQueryParams", false>;
}
