export declare abstract class RegExpUtils {
    private static _cachedSearchRegexps;
    private static _cachedSearchTexts;
    private static MAX_CACHE_SIZE;
    private static SPECIAL_CHARACTERS_REGEXP;
    private static SPECIAL_CHARACTERS_REPLACEMENT_MAP;
    /**
     * Cleans the provided search text by trimming whitespace and removing or condensing
     * wildcard characters based on the specified options.
     * (e.g. 'a**' becomes 'a', '*' becomes '', etc.)
     *
     * @param {string} searchText - The search text to be cleaned.
     * @param {Object} [opts] - Optional settings for cleaning the search text.
     * @param {boolean} [opts.anySearch] - If true, the search text is cleaned for any match. If false, search as a prefix
     * @return {string} - The cleaned search text.
     */
    static cleanSearchText(searchText: string, opts?: {
        trim?: boolean;
    }): string;
    /**
     * Compiles a regular expression from the provided search text, using a static cache to store
     * previously compiled regular expressions for faster retrieval.
     *
     * @param {string} searchText - The text to compile into a regular expression.
     * @param flags
     * @return {RegExp} - The compiled regular expression.
     */
    static compileSearchRegexp(searchText: string, flags?: string): RegExp;
    static match(input: string, regexp: string | RegExp): boolean;
    static matchUpperCase(input: string, regexp: string | RegExp): boolean;
    static hasWildcardCharacter(input: string): boolean;
}
