import { Observable } from 'rxjs';
import { ProjectValueReducer } from '@rx-angular/state';
export declare function enableRxStateProdMode(): void;
type ObservablePropertyDecorator<T> = <K extends PropertyKey>(target: any, propertyKey: K) => void;
type StatePropertyDecorator<T> = <K extends PropertyKey>(target: any, propertyKey: K) => void;
/**
 * Decorator to register the RxState property in a component
 * Must be used once per class hierarchy
 */
export declare function RxStateRegister(): PropertyDecorator;
/**
 * Decorator for RxState properties with getter/setter access
 * Creates reactive properties that sync with RxState
 */
export declare function RxStateProperty<T = any, K extends keyof T = any, V extends T[K] = any>(statePropertyName?: string | K, projectValueReducer?: ProjectValueReducer<T, K, V>): StatePropertyDecorator<V>;
/**
 * Decorator for RxState observable selectors
 * Creates observable properties that select from RxState
 *
 * ⚠️ IMPORTANT: La propriété décorée DOIT être typée comme Observable<T>
 *
 * @example
 * ```typescript
 * @RxStateSelect()
 * protected pmfms$: Observable<IPmfm[]>; // ✅ Correct
 *
 * @RxStateSelect()
 * protected badProperty: boolean; // ❌ TypeScript Error
 * ```
 */
export declare function RxStateSelect<T = any, R = T[keyof T]>(statePropertyName?: string | keyof T | '$', opts?: {
    stateName?: string;
}): ObservablePropertyDecorator<Observable<R>>;
/**
 * Utility decorator to create computed observables from state
 *
 * ⚠️ IMPORTANT: La propriété décorée DOIT être typée comme Observable<T>
 */
export declare function RxStateComputed<T = any, K extends keyof T = any, R = any>(dependencies: K[], computeFn?: (slice: Pick<T, K>) => R, opts?: {
    stateName?: string;
    keyCompareMap?: any;
}): ObservablePropertyDecorator<Observable<R>>;
export {};
