import { BehaviorSubject, Observable } from 'rxjs';
import { EntitiesServiceLoadOptions, EntitiesServiceWatchOptions, IEntitiesService, LoadResult } from './entity-service.class';
import { SortDirection } from '@angular/material/sort';
import { OnDestroy } from '@angular/core';
import { IEntity } from '../../core/services/model/entity.model';
import { WaitForOptions } from '../observables';
import { StartableObservableService } from './startable-observable-service.class';
import { FilterFn, FilterFnFactory } from '../types';
import * as i0 from "@angular/core";
export interface InMemoryEntitiesServiceOptions<T, F> {
    onSort?: (data: T[], sortBy?: string, sortDirection?: SortDirection) => T[];
    onLoad?: (data: T[]) => T[] | Promise<T[]>;
    onSave?: (data: T[]) => T[] | Promise<T[]>;
    equals?: (d1: T, d2: T) => boolean;
    filterFnFactory?: FilterFnFactory<T, F>;
    filterFn?: FilterFn<T>;
    sortByReplacement?: {
        [key: string]: string;
    };
}
export declare class InMemoryEntitiesService<T extends IEntity<T, ID>, F = any, ID = number, O extends EntitiesServiceWatchOptions = EntitiesServiceWatchOptions> extends StartableObservableService<T[], T[]> implements IEntitiesService<T, F, O>, OnDestroy {
    protected dataType: new () => T;
    protected filterType: new () => F;
    debug: boolean;
    private _hiddenData;
    readonly dirtySubject: BehaviorSubject<boolean>;
    readonly savingSubject: BehaviorSubject<boolean>;
    protected readonly sortByReplacement: {
        [key: string]: string;
    };
    private readonly _sortFn;
    private readonly _onLoad;
    private readonly _onSaveFn;
    private readonly _equalsFn;
    private readonly _filterFnFactory;
    get defaultFetchPolicy(): 'cache-only';
    set value(data: T[]);
    get value(): T[];
    get saving(): boolean;
    get dirty(): boolean;
    constructor(dataType: new () => T, filterType: new () => F, options?: InMemoryEntitiesServiceOptions<T, F>);
    protected ngOnStart(data?: T[]): Promise<T[]>;
    protected ngOnStop(): Promise<void>;
    ngOnDestroy(): void;
    setValue(data: T[]): void;
    loadAll(offset: number, size: number, sortBy?: string, sortDirection?: SortDirection, filter?: F, opts?: EntitiesServiceLoadOptions & {
        updateHiddenData?: boolean;
    }): Promise<LoadResult<T>>;
    watchAll(offset: number, size: number, sortBy?: string, sortDirection?: SortDirection, filterData?: F, options?: any): Observable<LoadResult<T>>;
    saveAll(data: T[], options?: any): Promise<T[]>;
    deleteAll(dataToRemove: T[], options?: any): Promise<any>;
    sort(data: T[], sortBy?: string, sortDirection?: SortDirection): T[];
    asFilter(source: Partial<F>): F;
    addSortByReplacement(source: string, target: string): void;
    equals(d1: T, d2: T): boolean;
    /**
     * Count data stored by the service (without hidden data).
     *
     * @param opts
     */
    /**
     * Count data stored by the service (without hidden data).
     *
     * @param opts
     * @deprecated TODO Please rename this getter into visibleCount (and create count = hiddenCount + visibleCount)
     */
    get count(): number;
    get hiddenCount(): number;
    waitIdle(opts?: WaitForOptions): Promise<void>;
    markAsDirty(): void;
    markAsPristine(): void;
    protected filter(data: T[], _filter: F, hiddenData: T[]): T[];
    protected connect(): Observable<LoadResult<T>>;
    protected waitWhileSaving(opts?: WaitForOptions): Promise<void>;
    protected markAsSaving(): void;
    protected markAsSaved(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<InMemoryEntitiesService<any, any, any, any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<InMemoryEntitiesService<any, any, any, any>, never, never, {}, {}, never, never, false, never>;
}
