import { Observable } from 'rxjs';
import { HttpEvent, HttpEventType, HttpProgressEvent, HttpResponse } from '@angular/common/http';
export declare class UploadFile<T> extends File {
    progress?: number;
    deleting?: boolean;
    error?: string;
    response?: FileResponse<T> | HttpResponse<T>;
}
export type FileUploadFn<T> = (file: File) => Observable<FileEvent<T> | HttpEvent<T>>;
export type FileDeleteFn<T> = (file: UploadFile<T>) => Promise<boolean>;
export interface FileProgressEvent {
    type: HttpEventType.DownloadProgress | HttpEventType.UploadProgress;
    loaded: number;
    total?: number;
    statusText?: string;
}
export declare class FileResponse<T> {
    readonly body: T | null;
    readonly type = HttpEventType.Response;
    readonly status: number;
    readonly statusText: string;
    constructor(init?: {
        body?: T | null;
        statusText?: string;
        status?: number;
    });
}
export declare type FileEvent<T> = HttpProgressEvent | HttpResponse<T> | FileProgressEvent | FileResponse<T>;
export declare function isProgressEvent(event: HttpEvent<any> | FileEvent<any>): event is HttpProgressEvent | FileProgressEvent;
export declare function isResponseEvent<T>(event: HttpEvent<T> | FileEvent<T>): event is HttpResponse<T> | FileResponse<T>;
