import { ChangeDetectorRef, EventEmitter, InjectionToken, OnDestroy, OnInit, QueryList } from '@angular/core';
import { IUserEvent, IUserEventFilter, IUserEventAction } from '../user-event.model';
import { BehaviorSubject, Subscription } from 'rxjs';
import { IonContent, IonItem, PopoverController } from '@ionic/angular';
import { IUserEventService } from '../user-event.service';
import { LocalSettingsService } from '../../../core/services/local-settings.service';
import { FetchMoreFn, LoadResult } from '../../../shared/services/entity-service.class';
import { SortDirection } from '@angular/material/sort';
import * as i0 from "@angular/core";
export declare const APP_USER_EVENT_LIST_INFINITE_SCROLL_THRESHOLD: InjectionToken<string>;
export interface UserEventNotificationListOptions<E extends IUserEvent<any> = IUserEvent<any>, F extends IUserEventFilter<any> = IUserEventFilter<any>> {
    debug?: boolean;
    titleI18n?: string;
    readEvent?: EventEmitter<E>;
    readEvents?: EventEmitter<E[]>;
    filter?: Partial<F>;
    headerActions?: IUserEventAction[];
    footerActions?: IUserEventAction[];
}
export declare class UserEventNotificationList<E extends IUserEvent<any> = IUserEvent<any>, F extends IUserEventFilter<any> = IUserEventFilter<any>> implements OnInit, OnDestroy, UserEventNotificationListOptions<E, F> {
    protected cd: ChangeDetectorRef;
    protected popoverController: PopoverController;
    protected settings: LocalSettingsService;
    userEventService: IUserEventService<E, IUserEventFilter<any>>;
    infiniteScrollThresholdFromToken: string;
    debug: boolean;
    mobile: boolean;
    titleI18n: string;
    sortBy: string;
    sortDirection: SortDirection;
    filter: Partial<F>;
    enableInfiniteScroll: boolean;
    infiniteScrollThreshold: string;
    headerActions: IUserEventAction[];
    footerActions: IUserEventAction[];
    set pageSize(value: number);
    get pageSize(): number;
    readEvent: EventEmitter<E>;
    readEvents: EventEmitter<E[]>;
    ionContent: IonContent;
    ionItems: QueryList<IonItem>;
    get canFetchMore(): boolean;
    fetchingMore: boolean;
    $items: BehaviorSubject<E[]>;
    $itemCount: BehaviorSubject<number>;
    protected _subscriptions: Subscription;
    protected _fetchMoreFn: FetchMoreFn<LoadResult<E>>;
    protected _fetchMoreSubscription: Subscription;
    protected _$pageSize: BehaviorSubject<number>;
    protected _panelElement: HTMLElement;
    constructor(cd: ChangeDetectorRef, popoverController: PopoverController, settings: LocalSettingsService, userEventService: IUserEventService<E, IUserEventFilter<any>>, infiniteScrollThresholdFromToken: string);
    ngOnInit(): void;
    ngOnDestroy(): void;
    click(event: Event, userEvent: E): void;
    isDefaultAction(action: IUserEventAction): boolean;
    markAsRead(event: Event, userEvent: E): void;
    markAllAsRead(event: Event): void;
    executeAction(event: Event, action: IUserEventAction, userEvent: IUserEvent<any>): Promise<void>;
    dismiss(): void;
    fetchMore(event?: CustomEvent & {
        target?: EventTarget & {
            complete?: () => void;
        };
    }): Promise<void>;
    trackByFn(index: number, item: E): number;
    protected initInfiniteScroll(threshold?: string): Promise<void>;
    protected markForCheck(): void;
    protected getPanelElement(): Promise<HTMLElement>;
    static ɵfac: i0.ɵɵFactoryDeclaration<UserEventNotificationList<any, any>, [null, null, { optional: true; }, { optional: true; }, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UserEventNotificationList<any, any>, "app-user-event-notification-list", never, { "debug": { "alias": "debug"; "required": false; }; "mobile": { "alias": "mobile"; "required": false; }; "titleI18n": { "alias": "titleI18n"; "required": false; }; "sortBy": { "alias": "sortBy"; "required": false; }; "sortDirection": { "alias": "sortDirection"; "required": false; }; "filter": { "alias": "filter"; "required": false; }; "enableInfiniteScroll": { "alias": "enableInfiniteScroll"; "required": false; }; "infiniteScrollThreshold": { "alias": "infiniteScrollThreshold"; "required": false; }; "headerActions": { "alias": "headerActions"; "required": false; }; "footerActions": { "alias": "footerActions"; "required": false; }; "pageSize": { "alias": "pageSize"; "required": false; }; }, { "readEvent": "readEvent"; "readEvents": "readEvents"; }, never, never, false, never>;
}
