import { InjectionToken, OnDestroy } from '@angular/core';
import { FetchPolicy } from '@apollo/client/core';
import { AccountService } from '../../core/services/account.service';
import { GraphqlService } from '../../core/graphql/graphql.service';
import { BehaviorSubject, Observable, Subject } from 'rxjs';
import { IUserEvent, IUserEventFilter } from './user-event.model';
import { SortDirection } from '@angular/material/sort';
import { EntitiesServiceLoadOptions, EntitiesServiceWatchOptions, IEntitiesService, LoadResult, Page } from '../../shared/services/entity-service.class';
import { TranslateService } from '@ngx-translate/core';
import { NetworkService } from '../../core/services/network.service';
import { BaseGraphqlService, BaseGraphqlServiceOptions } from '../../core/services/base-graphql-service.class';
import { Moment } from 'moment';
import { IStartableService } from '../../shared/services/startable-service.class';
import { DocumentNode } from 'graphql/index';
import { EntitySaveOptions, MutableWatchQueriesUpdatePolicy } from '../../core/services/base-entity-service.class';
import * as i0 from "@angular/core";
export declare const APP_USER_EVENT_SERVICE: InjectionToken<IUserEventService<any, any, number, UserEventWatchOptions<any>, UserEventLoadOptions<any>>>;
export declare interface UserEventLoadOptions<T> extends EntitiesServiceLoadOptions<T> {
    withContent?: boolean;
}
export declare interface UserEventWatchOptions<T> extends EntitiesServiceWatchOptions<T> {
    withContent?: boolean;
}
export interface IUserEventQueries {
    loadAll: any;
    loadAllWithContent: any;
    count?: any;
}
export interface IUserEventMutations {
    save: any;
    markAsRead?: any;
    deleteByIds: any;
}
export interface IUserEventSubscriptions {
    listenAllChanges: any;
    listenCountChanges?: any;
}
export interface IUserEventListener<E extends IUserEvent<E, ID>, ID = number> {
    accept: (E: any) => boolean;
    onReceived?: (E: any) => Promise<E> | E | undefined;
    onRead?: (E: any) => Promise<void> | void;
}
export interface UserEventServiceOptions<Q extends IUserEventQueries = IUserEventQueries, M extends IUserEventMutations = IUserEventMutations, S extends IUserEventSubscriptions = IUserEventSubscriptions> extends BaseGraphqlServiceOptions {
    queries: Q;
    mutations?: Partial<M>;
    subscriptions?: Partial<S>;
    watchQueriesUpdatePolicy?: MutableWatchQueriesUpdatePolicy;
}
export interface IUserEventService<E extends IUserEvent<E, ID>, F extends IUserEventFilter<E, ID>, ID = number, WO extends UserEventWatchOptions<E> = UserEventWatchOptions<E>, LO extends UserEventLoadOptions<E> = UserEventLoadOptions<E>> extends IEntitiesService<E, F, WO>, IStartableService {
    countSubject: Observable<number>;
    add(entity: E): Promise<E>;
    load(id: ID, opts?: LO): Promise<E>;
    count(filter: Partial<F>, options?: {
        fetchPolicy?: FetchPolicy;
    }): Promise<number>;
    listenCountChanges(filter: Partial<F>, options?: Omit<LO, 'toEntity'> & {
        interval?: number;
    }): Observable<number>;
    listenAllChanges(filter: Partial<F>, options?: LO & {
        interval?: number;
    }): Observable<E[]>;
    save(entity: E, options?: EntitySaveOptions<E>): Promise<E>;
    delete(entity: E): Promise<any>;
    markAllAsRead(entities: E[]): any;
    registerListener(listener: IUserEventListener<E, ID>): any;
    resetCount(): any;
}
export declare abstract class AbstractUserEventService<E extends IUserEvent<E, ID, any>, F extends IUserEventFilter<E, ID, any>, ID = number, WO extends UserEventWatchOptions<E> = UserEventWatchOptions<E>, LO extends UserEventLoadOptions<E> = UserEventLoadOptions<E>, Q extends IUserEventQueries = IUserEventQueries, M extends IUserEventMutations = IUserEventMutations, S extends IUserEventSubscriptions = IUserEventSubscriptions> extends BaseGraphqlService<E, F, ID> implements IUserEventService<E, F, ID, WO, LO>, OnDestroy {
    protected graphql: GraphqlService;
    protected accountService: AccountService;
    protected network: NetworkService;
    protected translate: TranslateService;
    protected options: UserEventServiceOptions<Q, M, S>;
    protected readonly queries: Q;
    protected readonly mutations: Partial<M>;
    protected readonly subscriptions: Partial<S>;
    protected readonly _countSubject: BehaviorSubject<number>;
    protected readonly watchQueriesUpdatePolicy: MutableWatchQueriesUpdatePolicy;
    protected resetCountDate: Moment;
    protected listeners: IUserEventListener<E, ID>[];
    private _subscriptions;
    private _listenSubscription;
    get countSubject(): Subject<number>;
    protected constructor(graphql: GraphqlService, accountService: AccountService, network: NetworkService, translate: TranslateService, options: UserEventServiceOptions<Q, M, S>);
    protected ngOnStart(): Promise<void>;
    ngOnDestroy(): void;
    abstract asFilter(filter: Partial<F>): F;
    abstract fromObject(source: any): E;
    watchAll(offset: number, size: number, sortBy?: string, sortDirection?: SortDirection, filter?: Partial<F>, options?: WO): Observable<LoadResult<E>>;
    watchPage(page: Page, filter?: Partial<F>, opts?: WO): Observable<LoadResult<E>>;
    loadPage(page: Page, filter?: Partial<F>, opts?: LO): Promise<LoadResult<E>>;
    load(id: ID, opts?: LO): Promise<E>;
    add(entity: E): Promise<E>;
    count(filter: Partial<F>, options?: {
        fetchPolicy?: FetchPolicy;
    }): Promise<number>;
    listenCountChanges(filter: Partial<F>, options?: Omit<LO, 'toEntity'> & {
        interval?: number;
    }): Observable<number>;
    listenAllChanges(filter: Partial<F>, opts?: LO & {
        interval?: number;
    }): Observable<E[]>;
    delete(entity: E): Promise<any>;
    deleteAll(entities: E[], opts?: any): Promise<any>;
    save(entity: E, opts?: EntitySaveOptions<E>): Promise<E>;
    saveAll(entities: E[], opts?: EntitySaveOptions<E>): Promise<E[]>;
    markAllAsRead(entities: E[]): Promise<void>;
    registerListener(listener: IUserEventListener<E, ID>): void;
    resetCount(): void;
    protected onLogin(): Promise<void>;
    protected onLogout(): void;
    protected startListenCountChanges(): void;
    protected stopListenCountChanges(): void;
    protected processUserEvent(source: any): Promise<E>;
    protected defaultMarkAsRead(userEvents: E[]): Promise<void>;
    protected defaultFilter(): F;
    protected abstract defaultRecipient(): any;
    protected fillDefaultProperties(entity: E): void;
    protected unreadEvents(events: E[]): number;
    protected copyIdAndUpdateDate(source: E, target: E): void;
    protected getLoadQueries(): DocumentNode[];
    static ɵfac: i0.ɵɵFactoryDeclaration<AbstractUserEventService<any, any, any, any, any, any, any, any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<AbstractUserEventService<any, any, any, any, any, any, any, any>, never, never, {}, {}, never, never, false, never>;
}
